#!/usr/bin/perl -w

use strict;
use DBI;

my %region_name;
my $region_code;
my $region_description;
my $maxlength = 0;
my %tables;
my $cmd;
my $result_code;

&populate_region_names();

# Connect to sqlite databases
my $dbh = DBI->connect("dbi:SQLite:dbname=region_names","","");
my $sth = $dbh->prepare("SELECT name FROM SQLITE_MASTER");

$sth->execute or die "Unable to execute query: $dbh->errstr\n";
foreach ($sth->fetchrow_array) {
	$tables{$_} = $_;
}

if ($tables{'region_names'}) {  }
else {
	print "Creating region_names database\n";
	 
	$cmd = "CREATE TABLE region_names (id INTEGER PRIMARY KEY, region_code VARCHAR(8), region_name VARCHAR(64) );";
	$result_code = $dbh->do($cmd) or die "Unable to prepare execute $cmd : $dbh->errstr\n";
	if (!$result_code) { print "ERROR: $result_code tables were created\n"; }
	
	$cmd = "CREATE INDEX region_index ON region_names ( region_code , region_name )";
	$result_code = $dbh->do($cmd) or die "Unable to do $cmd : $dbh->errstr\n";
	if (!$result_code) { print "ERROR: $result_code indexes were created\n"; }
}

$cmd = "DELETE FROM region_names";
$result_code = $dbh->do($cmd) or die "Unable to do $cmd : $dbh->errstr\n";
if (!$result_code) { print "ERROR: $result_code rows were deleted\n"; }

foreach $region_code (keys %region_name) {
	$region_description = $region_name{$region_code};
	print "INSERTING: $region_code = $region_description\n";
	
	$sth = $dbh->prepare("INSERT INTO region_names VALUES (NULL, ?, ?)");
	$sth->execute($region_code,$region_description) or &die_nice("Unable to do insert\n");

	if (length($region_description) > $maxlength) { $maxlength = length($region_description); }

	

}

print "max length = $maxlength\n";
 
sub populate_region_names {
        $region_name{'CA.1'} = 'Alberta';
        $region_name{'CA.28'} = 'British Columbia';
        $region_name{'CA.313'} = 'Manitoba';
        $region_name{'CA.339'} = 'New Brunswick';
        $region_name{'CA.343'} = 'Newfoundland';
        $region_name{'CA.356'} = 'Nova Scotia';
        $region_name{'CA.358'} = 'Nunavut';
        $region_name{'CA.377'} = 'Ontario';
        $region_name{'CA.394'} = 'Prince Edward Island';
        $region_name{'CA.418'} = 'Quebec';
        $region_name{'CA.478'} = 'Saskatchewan';
        $region_name{'CA.357'} = 'Northwest Territories';
        $region_name{'CA.643'} = 'Yukon Territory';
        $region_name{'US.0'} = 'Armed Forces Americas';
        $region_name{'US.4'} = 'Armed Forces Europe';
        $region_name{'US.10'} = 'Alaska';
        $region_name{'US.11'} = 'Alabama';
        $region_name{'US.15'} = 'Armed Forces Pacific';
        $region_name{'US.17'} = 'Arkansas';
        $region_name{'US.18'} = 'American Samoa';
        $region_name{'US.25'} = 'Arizona';
        $region_name{'US.52'} = 'California';
        $region_name{'US.66'} = 'Colorado';
        $region_name{'US.71'} = 'Connecticut';
        $region_name{'US.80'} = 'District of Columbia';
        $region_name{'US.82'} = 'Delaware';
        $region_name{'US.141'} = 'Florida';
        $region_name{'US.142'} = 'Federated States of Micronesia';
        $region_name{'US.156'} = 'Georgia';
        $region_name{'US.176'} = 'Guam';
        $region_name{'US.190'} = 'Hawaii';
        $region_name{'US.208'} = 'Iowa';
        $region_name{'US.211'} = 'Idaho';
        $region_name{'US.219'} = 'Illinois';
        $region_name{'US.221'} = 'Indiana';
        $region_name{'US.278'} = 'Kansas';
        $region_name{'US.284'} = 'Kentucky';
        $region_name{'US.286'} = 'Louisiana';
        $region_name{'US.312'} = 'Massachusetts';
        $region_name{'US.315'} = 'Maryland';
        $region_name{'US.316'} = 'Maine';
        $region_name{'US.319'} = 'Marshall Islands';
        $region_name{'US.320'} = 'Michigan';
        $region_name{'US.325'} = 'Minnesota';
        $region_name{'US.326'} = 'Missouri';
        $region_name{'US.327'} = 'Northern Mariana Islands';
        $region_name{'US.330'} = 'Mississippi';
        $region_name{'US.331'} = 'Montana';
        $region_name{'US.340'} = 'North Carolina';
        $region_name{'US.341'} = 'North Dakota';
        $region_name{'US.342'} = 'Nebraska';
        $region_name{'US.345'} = 'New Hampshire';
        $region_name{'US.347'} = 'New Jersey';
        $region_name{'US.350'} = 'New Mexico';
        $region_name{'US.359'} = 'Nevada';
        $region_name{'US.362'} = 'New York';
        $region_name{'US.371'} = 'Ohio';
        $region_name{'US.374'} = 'Oklahoma';
        $region_name{'US.381'} = 'Oregon';
        $region_name{'US.390'} = 'Pennsylvania';
        $region_name{'US.407'} = 'Puerto Rico';
        $region_name{'US.412'} = 'Palau';
        $region_name{'US.450'} = 'Rhode Island';
        $region_name{'US.470'} = 'South Carolina';
        $region_name{'US.471'} = 'South Dakota';
        $region_name{'US.507'} = 'Tennessee';
        $region_name{'US.517'} = 'Texas';
        $region_name{'US.539'} = 'Utah';
        $region_name{'US.546'} = 'Virginia';
        $region_name{'US.554'} = 'Virgin Islands';
        $region_name{'US.565'} = 'Vermont';
        $region_name{'US.572'} = 'Washington';
        $region_name{'US.593'} = 'West Virginia';
        $region_name{'US.580'} = 'Wisconsin';
        $region_name{'US.596'} = 'Wyoming';
        $region_name{'AD.2'} = 'Canillo';
        $region_name{'AD.3'} = 'Encamp';
        $region_name{'AD.4'} = 'La Massana';
        $region_name{'AD.5'} = 'Ordino';
        $region_name{'AD.6'} = 'Sant Julia de Loria';
        $region_name{'AD.7'} = 'Andorra la Vella';
        $region_name{'AD.8'} = 'Escaldes-Engordany';
        $region_name{'AE.1'} = 'Abu Dhabi';
        $region_name{'AE.2'} = 'Ajman';
        $region_name{'AE.3'} = 'Dubai';
        $region_name{'AE.4'} = 'Fujairah';
        $region_name{'AE.5'} = 'Ras Al Khaimah';
        $region_name{'AE.6'} = 'Sharjah';
        $region_name{'AE.7'} = 'Umm Al Quwain';
        $region_name{'AF.1'} = 'Badakhshan';
        $region_name{'AF.2'} = 'Badghis';
        $region_name{'AF.3'} = 'Baghlan';
        $region_name{'AF.5'} = 'Bamian';
        $region_name{'AF.6'} = 'Farah';
        $region_name{'AF.7'} = 'Faryab';
        $region_name{'AF.8'} = 'Ghazni';
        $region_name{'AF.9'} = 'Ghowr';
        $region_name{'AF.10'} = 'Helmand';
        $region_name{'AF.11'} = 'Herat';
        $region_name{'AF.13'} = 'Kabol';
        $region_name{'AF.14'} = 'Kapisa';
        $region_name{'AF.15'} = 'Konar';
        $region_name{'AF.16'} = 'Laghman';
        $region_name{'AF.17'} = 'Lowgar';
        $region_name{'AF.18'} = 'Nangarhar';
        $region_name{'AF.19'} = 'Nimruz';
        $region_name{'AF.20'} = 'Oruzgan';
        $region_name{'AF.21'} = 'Paktia';
        $region_name{'AF.22'} = 'Parvan';
        $region_name{'AF.23'} = 'Kandahar';
        $region_name{'AF.24'} = 'Kondoz';
        $region_name{'AF.26'} = 'Takhar';
        $region_name{'AF.27'} = 'Vardak';
        $region_name{'AF.28'} = 'Zabol';
        $region_name{'AF.29'} = 'Paktika';
        $region_name{'AF.30'} = 'Balkh';
        $region_name{'AF.31'} = 'Jowzjan';
        $region_name{'AF.32'} = 'Samangan';
        $region_name{'AF.33'} = 'Sar-e Pol';
        $region_name{'AF.34'} = 'Konar';
        $region_name{'AF.35'} = 'Laghman';
        $region_name{'AF.36'} = 'Paktia';
        $region_name{'AF.37'} = 'Khowst';
        $region_name{'AF.38'} = 'Nurestan';
        $region_name{'AG.1'} = 'Barbuda';
        $region_name{'AG.3'} = 'Saint George';
        $region_name{'AG.4'} = 'Saint John';
        $region_name{'AG.5'} = 'Saint Mary';
        $region_name{'AG.6'} = 'Saint Paul';
        $region_name{'AG.7'} = 'Saint Peter';
        $region_name{'AG.8'} = 'Saint Philip';
        $region_name{'AL.40'} = 'Berat';
        $region_name{'AL.41'} = 'Diber';
        $region_name{'AL.42'} = 'Durres';
        $region_name{'AL.43'} = 'Elbasan';
        $region_name{'AL.44'} = 'Fier';
        $region_name{'AL.45'} = 'Gjirokaster';
        $region_name{'AL.46'} = 'Korce';
        $region_name{'AL.47'} = 'Kukes';
        $region_name{'AL.48'} = 'Lezhe';
        $region_name{'AL.49'} = 'Shkoder';
        $region_name{'AL.50'} = 'Tirane';
        $region_name{'AL.51'} = 'Vlore';
        $region_name{'AM.1'} = 'Aragatsotn';
        $region_name{'AM.2'} = 'Ararat';
        $region_name{'AM.3'} = 'Armavir';
        $region_name{'AM.4'} = "Geghark'unik'";
        $region_name{'AM.5'} = "Kotayk'";
        $region_name{'AM.6'} = 'Lorri';
        $region_name{'AM.7'} = 'Shirak';
        $region_name{'AM.8'} = "Syunik'";
        $region_name{'AM.9'} = 'Tavush';
        $region_name{'AM.10'} = "Vayots' Dzor";
        $region_name{'AM.11'} = 'Yerevan';
        $region_name{'AO.1'} = 'Benguela';
        $region_name{'AO.2'} = 'Bie';
        $region_name{'AO.3'} = 'Cabinda';
        $region_name{'AO.4'} = 'Cuando Cubango';
        $region_name{'AO.5'} = 'Cuanza Norte';
        $region_name{'AO.6'} = 'Cuanza Sul';
        $region_name{'AO.7'} = 'Cunene';
        $region_name{'AO.8'} = 'Huambo';
        $region_name{'AO.9'} = 'Huila';
        $region_name{'AO.12'} = 'Malanje';
        $region_name{'AO.14'} = 'Moxico';
        $region_name{'AO.15'} = 'Uige';
        $region_name{'AO.16'} = 'Zaire';
        $region_name{'AO.17'} = 'Lunda Norte';
        $region_name{'AO.18'} = 'Lunda Sul';
        $region_name{'AO.19'} = 'Bengo';
        $region_name{'AO.20'} = 'Luanda';
        $region_name{'AR.1'} = 'Buenos Aires';
        $region_name{'AR.2'} = 'Catamarca';
        $region_name{'AR.3'} = 'Chaco';
        $region_name{'AR.4'} = 'Chubut';
        $region_name{'AR.5'} = 'Cordoba';
        $region_name{'AR.6'} = 'Corrientes';
        $region_name{'AR.7'} = 'Distrito Federal';
        $region_name{'AR.8'} = 'Entre Rios';
        $region_name{'AR.9'} = 'Formosa';
        $region_name{'AR.10'} = 'Jujuy';
        $region_name{'AR.11'} = 'La Pampa';
        $region_name{'AR.12'} = 'La Rioja';
        $region_name{'AR.13'} = 'Mendoza';
        $region_name{'AR.14'} = 'Misiones';
        $region_name{'AR.15'} = 'Neuquen';
        $region_name{'AR.16'} = 'Rio Negro';
        $region_name{'AR.17'} = 'Salta';
        $region_name{'AR.18'} = 'San Juan';
        $region_name{'AR.19'} = 'San Luis';
        $region_name{'AR.20'} = 'Santa Cruz';
        $region_name{'AR.21'} = 'Santa Fe';
        $region_name{'AR.22'} = 'Santiago del Estero';
        $region_name{'AR.23'} = 'Tierra del Fuego';
        $region_name{'AR.24'} = 'Tucuman';
        $region_name{'AT.1'} = 'Burgenland';
        $region_name{'AT.2'} = 'Karnten';
        $region_name{'AT.3'} = 'Niederosterreich';
        $region_name{'AT.4'} = 'Oberosterreich';
        $region_name{'AT.5'} = 'Salzburg';
        $region_name{'AT.6'} = 'Steiermark';
        $region_name{'AT.7'} = 'Tirol';
        $region_name{'AT.8'} = 'Vorarlberg';
        $region_name{'AT.9'} = 'Wien';
        $region_name{'AU.1'} = 'Australian Capital Territory';
        $region_name{'AU.2'} = 'New South Wales';
        $region_name{'AU.3'} = 'Northern Territory';
        $region_name{'AU.4'} = 'Queensland';
        $region_name{'AU.5'} = 'South Australia';
        $region_name{'AU.6'} = 'Tasmania';
        $region_name{'AU.7'} = 'Victoria';
        $region_name{'AU.8'} = 'Western Australia';
        $region_name{'AZ.1'} = 'Abseron';
        $region_name{'AZ.2'} = 'Agcabadi';
        $region_name{'AZ.3'} = 'Agdam';
        $region_name{'AZ.4'} = 'Agdas';
        $region_name{'AZ.5'} = 'Agstafa';
        $region_name{'AZ.6'} = 'Agsu';
        $region_name{'AZ.7'} = 'Ali Bayramli';
        $region_name{'AZ.8'} = 'Astara';
        $region_name{'AZ.9'} = 'Baki';
        $region_name{'AZ.10'} = 'Balakan';
        $region_name{'AZ.11'} = 'Barda';
        $region_name{'AZ.12'} = 'Beylaqan';
        $region_name{'AZ.13'} = 'Bilasuvar';
        $region_name{'AZ.14'} = 'Cabrayil';
        $region_name{'AZ.15'} = 'Calilabad';
        $region_name{'AZ.16'} = 'Daskasan';
        $region_name{'AZ.17'} = 'Davaci';
        $region_name{'AZ.18'} = 'Fuzuli';
        $region_name{'AZ.19'} = 'Gadabay';
        $region_name{'AZ.20'} = 'Ganca';
        $region_name{'AZ.21'} = 'Goranboy';
        $region_name{'AZ.22'} = 'Goycay';
        $region_name{'AZ.23'} = 'Haciqabul';
        $region_name{'AZ.24'} = 'Imisli';
        $region_name{'AZ.25'} = 'Ismayilli';
        $region_name{'AZ.26'} = 'Kalbacar';
        $region_name{'AZ.27'} = 'Kurdamir';
        $region_name{'AZ.28'} = 'Lacin';
        $region_name{'AZ.29'} = 'Lankaran';
        $region_name{'AZ.30'} = 'Lankaran';
        $region_name{'AZ.31'} = 'Lerik';
        $region_name{'AZ.32'} = 'Masalli';
        $region_name{'AZ.33'} = 'Mingacevir';
        $region_name{'AZ.34'} = 'Naftalan';
        $region_name{'AZ.35'} = 'Naxcivan';
        $region_name{'AZ.36'} = 'Neftcala';
        $region_name{'AZ.37'} = 'Oguz';
        $region_name{'AZ.38'} = 'Qabala';
        $region_name{'AZ.39'} = 'Qax';
        $region_name{'AZ.40'} = 'Qazax';
        $region_name{'AZ.41'} = 'Qobustan';
        $region_name{'AZ.42'} = 'Quba';
        $region_name{'AZ.43'} = 'Qubadli';
        $region_name{'AZ.44'} = 'Qusar';
        $region_name{'AZ.45'} = 'Saatli';
        $region_name{'AZ.46'} = 'Sabirabad';
        $region_name{'AZ.47'} = 'Saki';
        $region_name{'AZ.48'} = 'Saki';
        $region_name{'AZ.49'} = 'Salyan';
        $region_name{'AZ.50'} = 'Samaxi';
        $region_name{'AZ.51'} = 'Samkir';
        $region_name{'AZ.52'} = 'Samux';
        $region_name{'AZ.53'} = 'Siyazan';
        $region_name{'AZ.54'} = 'Sumqayit';
        $region_name{'AZ.55'} = 'Susa';
        $region_name{'AZ.56'} = 'Susa';
        $region_name{'AZ.57'} = 'Tartar';
        $region_name{'AZ.58'} = 'Tovuz';
        $region_name{'AZ.59'} = 'Ucar';
        $region_name{'AZ.60'} = 'Xacmaz';
        $region_name{'AZ.61'} = 'Xankandi';
        $region_name{'AZ.62'} = 'Xanlar';
        $region_name{'AZ.63'} = 'Xizi';
        $region_name{'AZ.64'} = 'Xocali';
        $region_name{'AZ.65'} = 'Xocavand';
        $region_name{'AZ.66'} = 'Yardimli';
        $region_name{'AZ.67'} = 'Yevlax';
        $region_name{'AZ.68'} = 'Yevlax';
        $region_name{'AZ.69'} = 'Zangilan';
        $region_name{'AZ.70'} = 'Zaqatala';
        $region_name{'AZ.71'} = 'Zardab';
        $region_name{'BA.1'} = 'Federation of Bosnia and Herzegovina';
        $region_name{'BA.2'} = 'Republika Srpska';
        $region_name{'BB.1'} = 'Christ Church';
        $region_name{'BB.2'} = 'Saint Andrew';
        $region_name{'BB.3'} = 'Saint George';
        $region_name{'BB.4'} = 'Saint James';
        $region_name{'BB.5'} = 'Saint John';
        $region_name{'BB.6'} = 'Saint Joseph';
        $region_name{'BB.7'} = 'Saint Lucy';
        $region_name{'BB.8'} = 'Saint Michael';
        $region_name{'BB.9'} = 'Saint Peter';
        $region_name{'BB.10'} = 'Saint Philip';
        $region_name{'BB.11'} = 'Saint Thomas';
        $region_name{'BD.1'} = 'Barisal';
        $region_name{'BD.4'} = 'Bandarban';
        $region_name{'BD.5'} = 'Comilla';
        $region_name{'BD.12'} = 'Mymensingh';
        $region_name{'BD.13'} = 'Noakhali';
        $region_name{'BD.15'} = 'Patuakhali';
        $region_name{'BD.22'} = 'Bagerhat';
        $region_name{'BD.23'} = 'Bhola';
        $region_name{'BD.24'} = 'Bogra';
        $region_name{'BD.25'} = 'Barguna';
        $region_name{'BD.26'} = 'Brahmanbaria';
        $region_name{'BD.27'} = 'Chandpur';
        $region_name{'BD.28'} = 'Chapai Nawabganj';
        $region_name{'BD.29'} = 'Chattagram';
        $region_name{'BD.30'} = 'Chuadanga';
        $region_name{'BD.31'} = "Cox's Bazar";
        $region_name{'BD.32'} = 'Dhaka';
        $region_name{'BD.33'} = 'Dinajpur';
        $region_name{'BD.34'} = 'Faridpur';
        $region_name{'BD.35'} = 'Feni';
        $region_name{'BD.36'} = 'Gaibandha';
        $region_name{'BD.37'} = 'Gazipur';
        $region_name{'BD.38'} = 'Gopalganj';
        $region_name{'BD.39'} = 'Habiganj';
        $region_name{'BD.40'} = 'Jaipurhat';
        $region_name{'BD.41'} = 'Jamalpur';
        $region_name{'BD.42'} = 'Jessore';
        $region_name{'BD.43'} = 'Jhalakati';
        $region_name{'BD.44'} = 'Jhenaidah';
        $region_name{'BD.45'} = 'Khagrachari';
        $region_name{'BD.46'} = 'Khulna';
        $region_name{'BD.47'} = 'Kishorganj';
        $region_name{'BD.48'} = 'Kurigram';
        $region_name{'BD.49'} = 'Kushtia';
        $region_name{'BD.50'} = 'Laksmipur';
        $region_name{'BD.51'} = 'Lalmonirhat';
        $region_name{'BD.52'} = 'Madaripur';
        $region_name{'BD.53'} = 'Magura';
        $region_name{'BD.54'} = 'Manikganj';
        $region_name{'BD.55'} = 'Meherpur';
        $region_name{'BD.56'} = 'Moulavibazar';
        $region_name{'BD.57'} = 'Munshiganj';
        $region_name{'BD.58'} = 'Naogaon';
        $region_name{'BD.59'} = 'Narail';
        $region_name{'BD.60'} = 'Narayanganj';
        $region_name{'BD.61'} = 'Narsingdi';
        $region_name{'BD.62'} = 'Nator';
        $region_name{'BD.63'} = 'Netrakona';
        $region_name{'BD.64'} = 'Nilphamari';
        $region_name{'BD.65'} = 'Pabna';
        $region_name{'BD.66'} = 'Panchagar';
        $region_name{'BD.67'} = 'Parbattya Chattagram';
        $region_name{'BD.68'} = 'Pirojpur';
        $region_name{'BD.69'} = 'Rajbari';
        $region_name{'BD.70'} = 'Rajshahi';
        $region_name{'BD.71'} = 'Rangpur';
        $region_name{'BD.72'} = 'Satkhira';
        $region_name{'BD.73'} = 'Shariyatpur';
        $region_name{'BD.74'} = 'Sherpur';
        $region_name{'BD.75'} = 'Sirajganj';
        $region_name{'BD.76'} = 'Sunamganj';
        $region_name{'BD.77'} = 'Sylhet';
        $region_name{'BD.78'} = 'Tangail';
        $region_name{'BD.79'} = 'Thakurgaon';
        $region_name{'BE.1'} = 'Antwerpen';
        $region_name{'BE.2'} = 'Brabant';
        $region_name{'BE.3'} = 'Hainaut';
        $region_name{'BE.4'} = 'Liege';
        $region_name{'BE.5'} = 'Limburg';
        $region_name{'BE.6'} = 'Luxembourg';
        $region_name{'BE.7'} = 'Namur';
        $region_name{'BE.8'} = 'Oost-Vlaanderen';
        $region_name{'BE.9'} = 'West-Vlaanderen';
        $region_name{'BE.10'} = 'Brabant Wallon';
        $region_name{'BE.11'} = 'Brussels Hoofdstedelijk Gewest';
        $region_name{'BE.12'} = 'Vlaams-Brabant';
        $region_name{'BF.15'} = 'Bam';
        $region_name{'BF.19'} = 'Boulkiemde';
        $region_name{'BF.20'} = 'Ganzourgou';
        $region_name{'BF.21'} = 'Gnagna';
        $region_name{'BF.28'} = 'Kouritenga';
        $region_name{'BF.33'} = 'Oudalan';
        $region_name{'BF.34'} = 'Passore';
        $region_name{'BF.36'} = 'Sanguie';
        $region_name{'BF.40'} = 'Soum';
        $region_name{'BF.42'} = 'Tapoa';
        $region_name{'BF.44'} = 'Zoundweogo';
        $region_name{'BF.45'} = 'Bale';
        $region_name{'BF.46'} = 'Banwa';
        $region_name{'BF.47'} = 'Bazega';
        $region_name{'BF.48'} = 'Bougouriba';
        $region_name{'BF.49'} = 'Boulgou';
        $region_name{'BF.50'} = 'Gourma';
        $region_name{'BF.51'} = 'Houet';
        $region_name{'BF.52'} = 'Ioba';
        $region_name{'BF.53'} = 'Kadiogo';
        $region_name{'BF.54'} = 'Kenedougou';
        $region_name{'BF.55'} = 'Komoe';
        $region_name{'BF.56'} = 'Komondjari';
        $region_name{'BF.57'} = 'Kompienga';
        $region_name{'BF.58'} = 'Kossi';
        $region_name{'BF.59'} = 'Koulpelogo';
        $region_name{'BF.60'} = 'Kourweogo';
        $region_name{'BF.61'} = 'Leraba';
        $region_name{'BF.62'} = 'Loroum';
        $region_name{'BF.63'} = 'Mouhoun';
        $region_name{'BF.64'} = 'Namentenga';
        $region_name{'BF.65'} = 'Naouri';
        $region_name{'BF.66'} = 'Nayala';
        $region_name{'BF.67'} = 'Noumbiel';
        $region_name{'BF.68'} = 'Oubritenga';
        $region_name{'BF.69'} = 'Poni';
        $region_name{'BF.70'} = 'Sanmatenga';
        $region_name{'BF.71'} = 'Seno';
        $region_name{'BF.72'} = 'Sissili';
        $region_name{'BF.73'} = 'Sourou';
        $region_name{'BF.74'} = 'Tuy';
        $region_name{'BF.75'} = 'Yagha';
        $region_name{'BF.76'} = 'Yatenga';
        $region_name{'BF.77'} = 'Ziro';
        $region_name{'BF.78'} = 'Zondoma';
        $region_name{'BG.33'} = 'Mikhaylovgrad';
        $region_name{'BG.38'} = 'Blagoevgrad';
        $region_name{'BG.39'} = 'Burgas';
        $region_name{'BG.40'} = 'Dobrich';
        $region_name{'BG.41'} = 'Gabrovo';
        $region_name{'BG.42'} = 'Grad Sofiya';
        $region_name{'BG.43'} = 'Khaskovo';
        $region_name{'BG.44'} = 'Kurdzhali';
        $region_name{'BG.45'} = 'Kyustendil';
        $region_name{'BG.46'} = 'Lovech';
        $region_name{'BG.47'} = 'Montana';
        $region_name{'BG.48'} = 'Pazardzhik';
        $region_name{'BG.49'} = 'Pernik';
        $region_name{'BG.50'} = 'Pleven';
        $region_name{'BG.51'} = 'Plovdiv';
        $region_name{'BG.52'} = 'Razgrad';
        $region_name{'BG.53'} = 'Ruse';
        $region_name{'BG.54'} = 'Shumen';
        $region_name{'BG.55'} = 'Silistra';
        $region_name{'BG.56'} = 'Sliven';
        $region_name{'BG.57'} = 'Smolyan';
        $region_name{'BG.58'} = 'Sofiya';
        $region_name{'BG.59'} = 'Stara Zagora';
        $region_name{'BG.60'} = 'Turgovishte';
        $region_name{'BG.61'} = 'Varna';
        $region_name{'BG.62'} = 'Veliko Turnovo';
        $region_name{'BG.63'} = 'Vidin';
        $region_name{'BG.64'} = 'Vratsa';
        $region_name{'BG.65'} = 'Yambol';
        $region_name{'BH.1'} = 'Al Hadd';
        $region_name{'BH.2'} = 'Al Manamah';
        $region_name{'BH.3'} = 'Al Muharraq';
        $region_name{'BH.5'} = 'Jidd Hafs';
        $region_name{'BH.6'} = 'Sitrah';
        $region_name{'BH.8'} = 'Al Mintaqah al Gharbiyah';
        $region_name{'BH.9'} = 'Mintaqat Juzur Hawar';
        $region_name{'BH.10'} = 'Al Mintaqah ash Shamaliyah';
        $region_name{'BH.11'} = 'Al Mintaqah al Wusta';
        $region_name{'BH.12'} = 'Madinat';
        $region_name{'BH.13'} = 'Ar Rifa';
        $region_name{'BH.14'} = 'Madinat Hamad';
        $region_name{'BI.2'} = 'Bujumbura';
        $region_name{'BI.9'} = 'Bubanza';
        $region_name{'BI.10'} = 'Bururi';
        $region_name{'BI.11'} = 'Cankuzo';
        $region_name{'BI.12'} = 'Cibitoke';
        $region_name{'BI.13'} = 'Gitega';
        $region_name{'BI.14'} = 'Karuzi';
        $region_name{'BI.15'} = 'Kayanza';
        $region_name{'BI.16'} = 'Kirundo';
        $region_name{'BI.17'} = 'Makamba';
        $region_name{'BI.18'} = 'Muyinga';
        $region_name{'BI.19'} = 'Ngozi';
        $region_name{'BI.20'} = 'Rutana';
        $region_name{'BI.21'} = 'Ruyigi';
        $region_name{'BI.22'} = 'Muramvya';
        $region_name{'BI.23'} = 'Mwaro';
        $region_name{'BJ.1'} = 'Atakora';
        $region_name{'BJ.2'} = 'Atlantique';
        $region_name{'BJ.3'} = 'Borgou';
        $region_name{'BJ.4'} = 'Mono';
        $region_name{'BJ.5'} = 'Oueme';
        $region_name{'BJ.6'} = 'Zou';
        $region_name{'BM.1'} = 'Devonshire';
        $region_name{'BM.2'} = 'Hamilton';
        $region_name{'BM.3'} = 'Hamilton';
        $region_name{'BM.4'} = 'Paget';
        $region_name{'BM.5'} = 'Pembroke';
        $region_name{'BM.6'} = 'Saint George';
        $region_name{'BM.7'} = "Saint George's";
        $region_name{'BM.8'} = 'Sandys';
        $region_name{'BM.9'} = 'Smiths';
        $region_name{'BM.10'} = 'Southampton';
        $region_name{'BM.11'} = 'Warwick';
        $region_name{'BN.7'} = 'Alibori';
        $region_name{'BN.8'} = 'Belait';
        $region_name{'BN.9'} = 'Brunei and Muara';
        $region_name{'BN.10'} = 'Temburong';
        $region_name{'BN.11'} = 'Collines';
        $region_name{'BN.12'} = 'Kouffo';
        $region_name{'BN.13'} = 'Donga';
        $region_name{'BN.14'} = 'Littoral';
        $region_name{'BN.15'} = 'Tutong';
        $region_name{'BN.16'} = 'Oueme';
        $region_name{'BN.17'} = 'Plateau';
        $region_name{'BN.18'} = 'Zou';
        $region_name{'BO.1'} = 'Chuquisaca';
        $region_name{'BO.2'} = 'Cochabamba';
        $region_name{'BO.3'} = 'El Beni';
        $region_name{'BO.4'} = 'La Paz';
        $region_name{'BO.5'} = 'Oruro';
        $region_name{'BO.6'} = 'Pando';
        $region_name{'BO.7'} = 'Potosi';
        $region_name{'BO.8'} = 'Santa Cruz';
        $region_name{'BO.9'} = 'Tarija';
        $region_name{'BR.1'} = 'Acre';
        $region_name{'BR.2'} = 'Alagoas';
        $region_name{'BR.3'} = 'Amapa';
        $region_name{'BR.4'} = 'Amazonas';
        $region_name{'BR.5'} = 'Bahia';
        $region_name{'BR.6'} = 'Ceara';
        $region_name{'BR.7'} = 'Distrito Federal';
        $region_name{'BR.8'} = 'Espirito Santo';
        $region_name{'BR.11'} = 'Mato Grosso do Sul';
        $region_name{'BR.13'} = 'Maranhao';
        $region_name{'BR.14'} = 'Mato Grosso';
        $region_name{'BR.15'} = 'Minas Gerais';
        $region_name{'BR.16'} = 'Para';
        $region_name{'BR.17'} = 'Paraiba';
        $region_name{'BR.18'} = 'Parana';
        $region_name{'BR.20'} = 'Piaui';
        $region_name{'BR.21'} = 'Rio de Janeiro';
        $region_name{'BR.22'} = 'Rio Grande do Norte';
        $region_name{'BR.23'} = 'Rio Grande do Sul';
        $region_name{'BR.24'} = 'Rondonia';
        $region_name{'BR.25'} = 'Roraima';
        $region_name{'BR.26'} = 'Santa Catarina';
        $region_name{'BR.27'} = 'Sao Paulo';
        $region_name{'BR.28'} = 'Sergipe';
        $region_name{'BR.29'} = 'Goias';
        $region_name{'BR.30'} = 'Pernambuco';
        $region_name{'BR.31'} = 'Tocantins';
        $region_name{'BS.5'} = 'Bimini';
        $region_name{'BS.6'} = 'Cat Island';
        $region_name{'BS.10'} = 'Exuma';
        $region_name{'BS.13'} = 'Inagua';
        $region_name{'BS.15'} = 'Long Island';
        $region_name{'BS.16'} = 'Mayaguana';
        $region_name{'BS.18'} = 'Ragged Island';
        $region_name{'BS.22'} = 'Harbour Island';
        $region_name{'BS.23'} = 'New Providence';
        $region_name{'BS.24'} = 'Acklins and Crooked Islands';
        $region_name{'BS.25'} = 'Freeport';
        $region_name{'BS.26'} = 'Fresh Creek';
        $region_name{'BS.27'} = "Governor's Harbour";
        $region_name{'BS.28'} = 'Green Turtle Cay';
        $region_name{'BS.29'} = 'High Rock';
        $region_name{'BS.30'} = 'Kemps Bay';
        $region_name{'BS.31'} = 'Marsh Harbour';
        $region_name{'BS.32'} = 'Nichollstown and Berry Islands';
        $region_name{'BS.33'} = 'Rock Sound';
        $region_name{'BS.34'} = 'Sandy Point';
        $region_name{'BS.35'} = 'San Salvador and Rum Cay';
        $region_name{'BT.5'} = 'Bumthang';
        $region_name{'BT.6'} = 'Chhukha';
        $region_name{'BT.7'} = 'Chirang';
        $region_name{'BT.8'} = 'Daga';
        $region_name{'BT.9'} = 'Geylegphug';
        $region_name{'BT.10'} = 'Ha';
        $region_name{'BT.11'} = 'Lhuntshi';
        $region_name{'BT.12'} = 'Mongar';
        $region_name{'BT.13'} = 'Paro';
        $region_name{'BT.14'} = 'Pemagatsel';
        $region_name{'BT.15'} = 'Punakha';
        $region_name{'BT.16'} = 'Samchi';
        $region_name{'BT.17'} = 'Samdrup';
        $region_name{'BT.18'} = 'Shemgang';
        $region_name{'BT.19'} = 'Tashigang';
        $region_name{'BT.20'} = 'Thimphu';
        $region_name{'BT.21'} = 'Tongsa';
        $region_name{'BT.22'} = 'Wangdi Phodrang';
        $region_name{'BW.1'} = 'Central';
        $region_name{'BW.2'} = 'Chobe';
        $region_name{'BW.3'} = 'Ghanzi';
        $region_name{'BW.4'} = 'Kgalagadi';
        $region_name{'BW.5'} = 'Kgatleng';
        $region_name{'BW.6'} = 'Kweneng';
        $region_name{'BW.7'} = 'Ngamiland';
        $region_name{'BW.8'} = 'North-East';
        $region_name{'BW.9'} = 'South-East';
        $region_name{'BW.10'} = 'Southern';
        $region_name{'BY.1'} = "Brestskaya Voblasts'";
        $region_name{'BY.2'} = "Homyel'skaya Voblasts'";
        $region_name{'BY.3'} = "Hrodzyenskaya Voblasts'";
        $region_name{'BY.4'} = 'Minsk';
        $region_name{'BY.5'} = "Minskaya Voblasts'";
        $region_name{'BY.6'} = "Mahilyowskaya Voblasts'";
        $region_name{'BY.7'} = "Vitsyebskaya Voblasts'";
        $region_name{'BZ.1'} = 'Belize';
        $region_name{'BZ.2'} = 'Cayo';
        $region_name{'BZ.3'} = 'Corozal';
        $region_name{'BZ.4'} = 'Orange Walk';
        $region_name{'BZ.5'} = 'Stann Creek';
        $region_name{'BZ.6'} = 'Toledo';
        $region_name{'CF.1'} = 'Bamingui-Bangoran';
        $region_name{'CF.2'} = 'Basse-Kotto';
        $region_name{'CF.3'} = 'Haute-Kotto';
        $region_name{'CF.4'} = 'Mambere-Kadei';
        $region_name{'CF.5'} = 'Haut-Mbomou';
        $region_name{'CF.6'} = 'Kemo';
        $region_name{'CF.7'} = 'Lobaye';
        $region_name{'CF.8'} = 'Mbomou';
        $region_name{'CF.9'} = 'Nana-Mambere';
        $region_name{'CF.11'} = 'Ouaka';
        $region_name{'CF.12'} = 'Ouham';
        $region_name{'CF.13'} = 'Ouham-Pende';
        $region_name{'CF.14'} = 'Vakaga';
        $region_name{'CF.15'} = 'Nana-Grebizi';
        $region_name{'CF.16'} = 'Sangha-Mbaere';
        $region_name{'CF.17'} = 'Ombella-Mpoko';
        $region_name{'CF.18'} = 'Bangui';
        $region_name{'CG.1'} = 'Bouenza';
        $region_name{'CG.3'} = 'Cuvette';
        $region_name{'CG.4'} = 'Kouilou';
        $region_name{'CG.5'} = 'Lekoumou';
        $region_name{'CG.6'} = 'Likouala';
        $region_name{'CG.7'} = 'Niari';
        $region_name{'CG.8'} = 'Plateaux';
        $region_name{'CG.10'} = 'Sangha';
        $region_name{'CG.11'} = 'Pool';
        $region_name{'CG.12'} = 'Brazzaville';
        $region_name{'CH.1'} = 'Aargau';
        $region_name{'CH.2'} = 'Ausser-Rhoden';
        $region_name{'CH.3'} = 'Basel-Landschaft';
        $region_name{'CH.4'} = 'Basel-Stadt';
        $region_name{'CH.5'} = 'Bern';
        $region_name{'CH.6'} = 'Fribourg';
        $region_name{'CH.7'} = 'Geneve';
        $region_name{'CH.8'} = 'Glarus';
        $region_name{'CH.9'} = 'Graubunden';
        $region_name{'CH.10'} = 'Inner-Rhoden';
        $region_name{'CH.11'} = 'Luzern';
        $region_name{'CH.12'} = 'Neuchatel';
        $region_name{'CH.13'} = 'Nidwalden';
        $region_name{'CH.14'} = 'Obwalden';
        $region_name{'CH.15'} = 'Sankt Gallen';
        $region_name{'CH.16'} = 'Schaffhausen';
        $region_name{'CH.17'} = 'Schwyz';
        $region_name{'CH.18'} = 'Solothurn';
        $region_name{'CH.19'} = 'Thurgau';
        $region_name{'CH.20'} = 'Ticino';
        $region_name{'CH.21'} = 'Uri';
        $region_name{'CH.22'} = 'Valais';
        $region_name{'CH.23'} = 'Vaud';
        $region_name{'CH.24'} = 'Zug';
        $region_name{'CH.25'} = 'Zurich';
        $region_name{'CH.26'} = 'Jura';
        $region_name{'CI.1'} = 'Abengourou';
        $region_name{'CI.3'} = 'Dabakala';
        $region_name{'CI.5'} = 'Adzope';
        $region_name{'CI.6'} = 'Agboville';
        $region_name{'CI.7'} = 'Biankouma';
        $region_name{'CI.11'} = 'Bouna';
        $region_name{'CI.12'} = 'Boundiali';
        $region_name{'CI.14'} = 'Danane';
        $region_name{'CI.16'} = 'Divo';
        $region_name{'CI.17'} = 'Ferkessedougou';
        $region_name{'CI.18'} = 'Gagnoa';
        $region_name{'CI.20'} = 'Katiola';
        $region_name{'CI.21'} = 'Korhogo';
        $region_name{'CI.23'} = 'Odienne';
        $region_name{'CI.25'} = 'Seguela';
        $region_name{'CI.26'} = 'Touba';
        $region_name{'CI.27'} = 'Bongouanou';
        $region_name{'CI.28'} = 'Issia';
        $region_name{'CI.29'} = 'Lakota';
        $region_name{'CI.30'} = 'Mankono';
        $region_name{'CI.31'} = 'Oume';
        $region_name{'CI.32'} = 'Soubre';
        $region_name{'CI.33'} = 'Tingrela';
        $region_name{'CI.34'} = 'Zuenoula';
        $region_name{'CI.36'} = 'Bangolo';
        $region_name{'CI.37'} = 'Beoumi';
        $region_name{'CI.38'} = 'Bondoukou';
        $region_name{'CI.39'} = 'Bouafle';
        $region_name{'CI.40'} = 'Bouake';
        $region_name{'CI.41'} = 'Daloa';
        $region_name{'CI.42'} = 'Daoukro';
        $region_name{'CI.44'} = 'Duekoue';
        $region_name{'CI.45'} = 'Grand-Lahou';
        $region_name{'CI.47'} = 'Man';
        $region_name{'CI.48'} = 'Mbahiakro';
        $region_name{'CI.49'} = 'Sakassou';
        $region_name{'CI.50'} = 'San Pedro';
        $region_name{'CI.51'} = 'Sassandra';
        $region_name{'CI.52'} = 'Sinfra';
        $region_name{'CI.53'} = 'Tabou';
        $region_name{'CI.54'} = 'Tanda';
        $region_name{'CI.55'} = 'Tiassale';
        $region_name{'CI.56'} = 'Toumodi';
        $region_name{'CI.57'} = 'Vavoua';
        $region_name{'CI.61'} = 'Abidjan';
        $region_name{'CI.62'} = 'Aboisso';
        $region_name{'CI.63'} = 'Adiake';
        $region_name{'CI.64'} = 'Alepe';
        $region_name{'CI.65'} = 'Bocanda';
        $region_name{'CI.66'} = 'Dabou';
        $region_name{'CI.67'} = 'Dimbokro';
        $region_name{'CI.68'} = 'Grand-Bassam';
        $region_name{'CI.69'} = 'Guiglo';
        $region_name{'CI.70'} = 'Jacqueville';
        $region_name{'CI.71'} = 'Tiebissou';
        $region_name{'CI.72'} = 'Toulepleu';
        $region_name{'CI.73'} = 'Yamoussoukro';
        $region_name{'CL.1'} = 'Valparaiso';
        $region_name{'CL.2'} = 'Aisen del General Carlos Ibanez del Campo';
        $region_name{'CL.3'} = 'Antofagasta';
        $region_name{'CL.4'} = 'Araucania';
        $region_name{'CL.5'} = 'Atacama';
        $region_name{'CL.6'} = 'Bio-Bio';
        $region_name{'CL.7'} = 'Coquimbo';
        $region_name{'CL.8'} = "Libertador General Bernardo O'Higgins";
        $region_name{'CL.9'} = 'Los Lagos';
        $region_name{'CL.10'} = 'Magallanes y de la Antartica Chilena';
        $region_name{'CL.11'} = 'Maule';
        $region_name{'CL.12'} = 'Region Metropolitana';
        $region_name{'CL.13'} = 'Tarapaca';
        $region_name{'CM.4'} = 'Est';
        $region_name{'CM.5'} = 'Littoral';
        $region_name{'CM.7'} = 'Nord-Ouest';
        $region_name{'CM.8'} = 'Ouest';
        $region_name{'CM.9'} = 'Sud-Ouest';
        $region_name{'CM.10'} = 'Adamaoua';
        $region_name{'CM.11'} = 'Centre';
        $region_name{'CM.12'} = 'Extreme-Nord';
        $region_name{'CM.13'} = 'Nord';
        $region_name{'CM.14'} = 'Sud';
        $region_name{'CN.1'} = 'Anhui';
        $region_name{'CN.2'} = 'Zhejiang';
        $region_name{'CN.3'} = 'Jiangxi';
        $region_name{'CN.4'} = 'Jiangsu';
        $region_name{'CN.5'} = 'Jilin';
        $region_name{'CN.6'} = 'Qinghai';
        $region_name{'CN.7'} = 'Fujian';
        $region_name{'CN.8'} = 'Heilongjiang';
        $region_name{'CN.9'} = 'Henan';
        $region_name{'CN.10'} = 'Hebei';
        $region_name{'CN.11'} = 'Hunan';
        $region_name{'CN.12'} = 'Hubei';
        $region_name{'CN.13'} = 'Xinjiang';
        $region_name{'CN.14'} = 'Xizang';
        $region_name{'CN.15'} = 'Gansu';
        $region_name{'CN.16'} = 'Guangxi';
        $region_name{'CN.18'} = 'Guizhou';
        $region_name{'CN.19'} = 'Liaoning';
        $region_name{'CN.20'} = 'Nei Mongol';
        $region_name{'CN.21'} = 'Ningxia';
        $region_name{'CN.22'} = 'Beijing';
        $region_name{'CN.23'} = 'Shanghai';
        $region_name{'CN.24'} = 'Shanxi';
        $region_name{'CN.25'} = 'Shandong';
        $region_name{'CN.26'} = 'Shaanxi';
        $region_name{'CN.28'} = 'Tianjin';
        $region_name{'CN.29'} = 'Yunnan';
        $region_name{'CN.30'} = 'Guangdong';
        $region_name{'CN.31'} = 'Hainan';
        $region_name{'CN.32'} = 'Sichuan';
        $region_name{'CN.33'} = 'Chongqing';
        $region_name{'CO.1'} = 'Amazonas';
        $region_name{'CO.2'} = 'Antioquia';
        $region_name{'CO.3'} = 'Arauca';
        $region_name{'CO.4'} = 'Atlantico';
        $region_name{'CO.8'} = 'Caqueta';
        $region_name{'CO.9'} = 'Cauca';
        $region_name{'CO.10'} = 'Cesar';
        $region_name{'CO.11'} = 'Choco';
        $region_name{'CO.12'} = 'Cordoba';
        $region_name{'CO.14'} = 'Guaviare';
        $region_name{'CO.15'} = 'Guainia';
        $region_name{'CO.16'} = 'Huila';
        $region_name{'CO.17'} = 'La Guajira';
        $region_name{'CO.19'} = 'Meta';
        $region_name{'CO.20'} = 'Narino';
        $region_name{'CO.21'} = 'Norte de Santander';
        $region_name{'CO.22'} = 'Putumayo';
        $region_name{'CO.23'} = 'Quindio';
        $region_name{'CO.24'} = 'Risaralda';
        $region_name{'CO.25'} = 'San Andres y Providencia';
        $region_name{'CO.26'} = 'Santander';
        $region_name{'CO.27'} = 'Sucre';
        $region_name{'CO.28'} = 'Tolima';
        $region_name{'CO.29'} = 'Valle del Cauca';
        $region_name{'CO.30'} = 'Vaupes';
        $region_name{'CO.31'} = 'Vichada';
        $region_name{'CO.32'} = 'Casanare';
        $region_name{'CO.33'} = 'Cundinamarca';
        $region_name{'CO.34'} = 'Distrito Especial';
        $region_name{'CO.35'} = 'Bolivar';
        $region_name{'CO.36'} = 'Boyaca';
        $region_name{'CO.37'} = 'Caldas';
        $region_name{'CO.38'} = 'Magdalena';
        $region_name{'CR.1'} = 'Alajuela';
        $region_name{'CR.2'} = 'Cartago';
        $region_name{'CR.3'} = 'Guanacaste';
        $region_name{'CR.4'} = 'Heredia';
        $region_name{'CR.6'} = 'Limon';
        $region_name{'CR.7'} = 'Puntarenas';
        $region_name{'CR.8'} = 'San Jose';
        $region_name{'CU.1'} = 'Pinar del Rio';
        $region_name{'CU.2'} = 'Ciudad de la Habana';
        $region_name{'CU.3'} = 'Matanzas';
        $region_name{'CU.4'} = 'Isla de la Juventud';
        $region_name{'CU.5'} = 'Camaguey';
        $region_name{'CU.7'} = 'Ciego de Avila';
        $region_name{'CU.8'} = 'Cienfuegos';
        $region_name{'CU.9'} = 'Granma';
        $region_name{'CU.10'} = 'Guantanamo';
        $region_name{'CU.11'} = 'La Habana';
        $region_name{'CU.12'} = 'Holguin';
        $region_name{'CU.13'} = 'Las Tunas';
        $region_name{'CU.14'} = 'Sancti Spiritus';
        $region_name{'CU.15'} = 'Santiago de Cuba';
        $region_name{'CU.16'} = 'Villa Clara';
        $region_name{'CV.1'} = 'Boa Vista';
        $region_name{'CV.2'} = 'Brava';
        $region_name{'CV.4'} = 'Maio';
        $region_name{'CV.5'} = 'Paul';
        $region_name{'CV.7'} = 'Ribeira Grande';
        $region_name{'CV.8'} = 'Sal';
        $region_name{'CV.10'} = 'Sao Nicolau';
        $region_name{'CV.11'} = 'Sao Vicente';
        $region_name{'CV.13'} = 'Mosteiros';
        $region_name{'CV.14'} = 'Praia';
        $region_name{'CV.15'} = 'Santa Catarina';
        $region_name{'CV.16'} = 'Santa Cruz';
        $region_name{'CV.17'} = 'Sao Domingos';
        $region_name{'CV.18'} = 'Sao Filipe';
        $region_name{'CV.19'} = 'Sao Miguel';
        $region_name{'CV.20'} = 'Tarrafal';
        $region_name{'CY.1'} = 'Famagusta';
        $region_name{'CY.2'} = 'Kyrenia';
        $region_name{'CY.3'} = 'Larnaca';
        $region_name{'CY.4'} = 'Nicosia';
        $region_name{'CY.5'} = 'Limassol';
        $region_name{'CY.6'} = 'Paphos';
        $region_name{'CZ.3'} = 'Blansko';
        $region_name{'CZ.4'} = 'Breclav';
        $region_name{'CZ.20'} = 'Hradec Kralove';
        $region_name{'CZ.21'} = 'Jablonec nad Nisou';
        $region_name{'CZ.23'} = 'Jiein';
        $region_name{'CZ.24'} = 'Jihlava';
        $region_name{'CZ.30'} = 'Kolin';
        $region_name{'CZ.33'} = 'Liberec';
        $region_name{'CZ.36'} = 'Melnik';
        $region_name{'CZ.37'} = 'Mlada Boleslav';
        $region_name{'CZ.39'} = 'Nachod';
        $region_name{'CZ.41'} = 'Nymburk';
        $region_name{'CZ.45'} = 'Pardubice';
        $region_name{'CZ.52'} = 'Hlavni Mesto Praha';
        $region_name{'CZ.61'} = 'Semily';
        $region_name{'CZ.70'} = 'Trutnov';
        $region_name{'CZ.78'} = 'Jihomoravsky Kraj';
        $region_name{'CZ.79'} = 'Jihocesky Kraj';
        $region_name{'CZ.80'} = 'Vysocina';
        $region_name{'CZ.81'} = 'Karlovarsky Kraj';
        $region_name{'CZ.82'} = 'Kralovehradecky Kraj';
        $region_name{'CZ.83'} = 'Liberecky Kraj';
        $region_name{'CZ.84'} = 'Olomoucky Kraj';
        $region_name{'CZ.85'} = 'Moravskoslezsky Kraj';
        $region_name{'CZ.86'} = 'Pardubicky Kraj';
        $region_name{'CZ.87'} = 'Plzensky Kraj';
        $region_name{'CZ.88'} = 'Stredocesky Kraj';
        $region_name{'CZ.89'} = 'Ustecky Kraj';
        $region_name{'CZ.90'} = 'Zlinsky Kraj';
        $region_name{'DE.1'} = 'Baden-Wrttemberg';
        $region_name{'DE.2'} = 'Bayern';
        $region_name{'DE.3'} = 'Bremen';
        $region_name{'DE.4'} = 'Hamburg';
        $region_name{'DE.5'} = 'Hessen';
        $region_name{'DE.6'} = 'Niedersachsen';
        $region_name{'DE.7'} = 'Nordrhein-Westfalen';
        $region_name{'DE.8'} = 'Rheinland-Pfalz';
        $region_name{'DE.9'} = 'Saarland';
        $region_name{'DE.10'} = 'Schleswig-Holstein';
        $region_name{'DE.11'} = 'Brandenburg';
        $region_name{'DE.12'} = 'Mecklenburg-Vorpommern';
        $region_name{'DE.13'} = 'Sachsen';
        $region_name{'DE.14'} = 'Sachsen-Anhalt';
        $region_name{'DE.15'} = 'Thuringen';
        $region_name{'DE.16'} = 'Berlin';
        $region_name{'DJ.2'} = 'Dikhil';
        $region_name{'DJ.3'} = 'Djibouti';
        $region_name{'DJ.4'} = 'Obock';
        $region_name{'DJ.5'} = 'Tadjoura';
        $region_name{'DK.1'} = 'Arhus';
        $region_name{'DK.2'} = 'Bornholm';
        $region_name{'DK.3'} = 'Frederiksborg';
        $region_name{'DK.4'} = 'Fyn';
        $region_name{'DK.5'} = 'Kobenhavn';
        $region_name{'DK.6'} = 'Staden Kobenhavn';
        $region_name{'DK.7'} = 'Nordjylland';
        $region_name{'DK.8'} = 'Ribe';
        $region_name{'DK.9'} = 'Ringkobing';
        $region_name{'DK.10'} = 'Roskilde';
        $region_name{'DK.11'} = 'Sonderjylland';
        $region_name{'DK.12'} = 'Storstrom';
        $region_name{'DK.13'} = 'Vejle';
        $region_name{'DK.14'} = 'Vestsjalland';
        $region_name{'DK.15'} = 'Viborg';
        $region_name{'DM.2'} = 'Saint Andrew';
        $region_name{'DM.3'} = 'Saint David';
        $region_name{'DM.4'} = 'Saint George';
        $region_name{'DM.5'} = 'Saint John';
        $region_name{'DM.6'} = 'Saint Joseph';
        $region_name{'DM.7'} = 'Saint Luke';
        $region_name{'DM.8'} = 'Saint Mark';
        $region_name{'DM.9'} = 'Saint Patrick';
        $region_name{'DM.10'} = 'Saint Paul';
        $region_name{'DM.11'} = 'Saint Peter';
        $region_name{'DO.1'} = 'Azua';
        $region_name{'DO.2'} = 'Baoruco';
        $region_name{'DO.3'} = 'Barahona';
        $region_name{'DO.4'} = 'Dajabon';
        $region_name{'DO.5'} = 'Distrito Nacional';
        $region_name{'DO.6'} = 'Duarte';
        $region_name{'DO.8'} = 'Espaillat';
        $region_name{'DO.9'} = 'Independencia';
        $region_name{'DO.10'} = 'La Altagracia';
        $region_name{'DO.11'} = 'Elias Pina';
        $region_name{'DO.12'} = 'La Romana';
        $region_name{'DO.14'} = 'Maria Trinidad Sanchez';
        $region_name{'DO.15'} = 'Monte Cristi';
        $region_name{'DO.16'} = 'Pedernales';
        $region_name{'DO.17'} = 'Peravia';
        $region_name{'DO.18'} = 'Puerto Plata';
        $region_name{'DO.19'} = 'Salcedo';
        $region_name{'DO.20'} = 'Samana';
        $region_name{'DO.21'} = 'Sanchez Ramirez';
        $region_name{'DO.23'} = 'San Juan';
        $region_name{'DO.24'} = 'San Pedro De Macoris';
        $region_name{'DO.25'} = 'Santiago';
        $region_name{'DO.26'} = 'Santiago Rodriguez';
        $region_name{'DO.27'} = 'Valverde';
        $region_name{'DO.28'} = 'El Seibo';
        $region_name{'DO.29'} = 'Hato Mayor';
        $region_name{'DO.30'} = 'La Vega';
        $region_name{'DO.31'} = 'Monsenor Nouel';
        $region_name{'DO.32'} = 'Monte Plata';
        $region_name{'DO.33'} = 'San Cristobal';
        $region_name{'DZ.1'} = 'Alger';
        $region_name{'DZ.3'} = 'Batna';
        $region_name{'DZ.4'} = 'Constantine';
        $region_name{'DZ.6'} = 'Medea';
        $region_name{'DZ.7'} = 'Mostaganem';
        $region_name{'DZ.9'} = 'Oran';
        $region_name{'DZ.10'} = 'Saida';
        $region_name{'DZ.12'} = 'Setif';
        $region_name{'DZ.13'} = 'Tiaret';
        $region_name{'DZ.14'} = 'Tizi Ouzou';
        $region_name{'DZ.15'} = 'Tlemcen';
        $region_name{'DZ.18'} = 'Bejaia';
        $region_name{'DZ.19'} = 'Biskra';
        $region_name{'DZ.20'} = 'Blida';
        $region_name{'DZ.21'} = 'Bouira';
        $region_name{'DZ.22'} = 'Djelfa';
        $region_name{'DZ.23'} = 'Guelma';
        $region_name{'DZ.24'} = 'Jijel';
        $region_name{'DZ.25'} = 'Laghouat';
        $region_name{'DZ.26'} = 'Mascara';
        $region_name{'DZ.27'} = "M'sila";
        $region_name{'DZ.29'} = 'Oum el Bouaghi';
        $region_name{'DZ.30'} = 'Sidi Bel Abbes';
        $region_name{'DZ.31'} = 'Skikda';
        $region_name{'DZ.33'} = 'Tebessa';
        $region_name{'DZ.34'} = 'Adrar';
        $region_name{'DZ.35'} = 'Ain Defla';
        $region_name{'DZ.36'} = 'Ain Temouchent';
        $region_name{'DZ.37'} = 'Annaba';
        $region_name{'DZ.38'} = 'Bechar';
        $region_name{'DZ.39'} = 'Bordj Bou Arreridj';
        $region_name{'DZ.40'} = 'Boumerdes';
        $region_name{'DZ.41'} = 'Chlef';
        $region_name{'DZ.42'} = 'El Bayadh';
        $region_name{'DZ.43'} = 'El Oued';
        $region_name{'DZ.44'} = 'El Tarf';
        $region_name{'DZ.45'} = 'Ghardaia';
        $region_name{'DZ.46'} = 'Illizi';
        $region_name{'DZ.47'} = 'Khenchela';
        $region_name{'DZ.48'} = 'Mila';
        $region_name{'DZ.49'} = 'Naama';
        $region_name{'DZ.50'} = 'Ouargla';
        $region_name{'DZ.51'} = 'Relizane';
        $region_name{'DZ.52'} = 'Souk Ahras';
        $region_name{'DZ.53'} = 'Tamanghasset';
        $region_name{'DZ.54'} = 'Tindouf';
        $region_name{'DZ.55'} = 'Tipaza';
        $region_name{'DZ.56'} = 'Tissemsilt';
        $region_name{'EC.1'} = 'Galapagos';
        $region_name{'EC.2'} = 'Azuay';
        $region_name{'EC.3'} = 'Bolivar';
        $region_name{'EC.4'} = 'Canar';
        $region_name{'EC.5'} = 'Carchi';
        $region_name{'EC.6'} = 'Chimborazo';
        $region_name{'EC.7'} = 'Cotopaxi';
        $region_name{'EC.8'} = 'El Oro';
        $region_name{'EC.9'} = 'Esmeraldas';
        $region_name{'EC.10'} = 'Guayas';
        $region_name{'EC.11'} = 'Imbabura';
        $region_name{'EC.12'} = 'Loja';
        $region_name{'EC.13'} = 'Los Rios';
        $region_name{'EC.14'} = 'Manabi';
        $region_name{'EC.15'} = 'Morona-Santiago';
        $region_name{'EC.17'} = 'Pastaza';
        $region_name{'EC.18'} = 'Pichincha';
        $region_name{'EC.19'} = 'Tungurahua';
        $region_name{'EC.20'} = 'Zamora-Chinchipe';
        $region_name{'EC.22'} = 'Sucumbios';
        $region_name{'EC.23'} = 'Napo';
        $region_name{'EC.24'} = 'Orellana';
        $region_name{'EE.1'} = 'Harjumaa';
        $region_name{'EE.2'} = 'Hiiumaa';
        $region_name{'EE.3'} = 'Ida-Virumaa';
        $region_name{'EE.4'} = 'Jarvamaa';
        $region_name{'EE.5'} = 'Jogevamaa';
        $region_name{'EE.6'} = 'Kohtla-Jarve';
        $region_name{'EE.7'} = 'Laanemaa';
        $region_name{'EE.8'} = 'Laane-Virumaa';
        $region_name{'EE.9'} = 'Narva';
        $region_name{'EE.10'} = 'Parnu';
        $region_name{'EE.11'} = 'Parnumaa';
        $region_name{'EE.12'} = 'Polvamaa';
        $region_name{'EE.13'} = 'Raplamaa';
        $region_name{'EE.14'} = 'Saaremaa';
        $region_name{'EE.15'} = 'Sillamae';
        $region_name{'EE.16'} = 'Tallinn';
        $region_name{'EE.17'} = 'Tartu';
        $region_name{'EE.18'} = 'Tartumaa';
        $region_name{'EE.19'} = 'Valgamaa';
        $region_name{'EE.20'} = 'Viljandimaa';
        $region_name{'EE.21'} = 'Vorumaa';
        $region_name{'EG.1'} = 'Ad Daqahliyah';
        $region_name{'EG.2'} = 'Al Bahr al Ahmar';
        $region_name{'EG.3'} = 'Al Buhayrah';
        $region_name{'EG.4'} = 'Al Fayyum';
        $region_name{'EG.5'} = 'Al Gharbiyah';
        $region_name{'EG.6'} = 'Al Iskandariyah';
        $region_name{'EG.7'} = "Al Isma'iliyah";
        $region_name{'EG.8'} = 'Al Jizah';
        $region_name{'EG.9'} = 'Al Minufiyah';
        $region_name{'EG.10'} = 'Al Minya';
        $region_name{'EG.11'} = 'Al Qahirah';
        $region_name{'EG.12'} = 'Al Qalyubiyah';
        $region_name{'EG.13'} = 'Al Wadi al Jadid';
        $region_name{'EG.14'} = 'Ash Sharqiyah';
        $region_name{'EG.15'} = 'As Suways';
        $region_name{'EG.16'} = 'Aswan';
        $region_name{'EG.17'} = 'Asyut';
        $region_name{'EG.18'} = 'Bani Suwayf';
        $region_name{'EG.19'} = "Bur Sa'id";
        $region_name{'EG.20'} = 'Dumyat';
        $region_name{'EG.21'} = 'Kafr ash Shaykh';
        $region_name{'EG.22'} = 'Matruh';
        $region_name{'EG.23'} = 'Qina';
        $region_name{'EG.24'} = 'Suhaj';
        $region_name{'EG.26'} = "Janub Sina'";
        $region_name{'EG.27'} = "Shamal Sina'";
        $region_name{'ES.7'} = 'Islas Baleares';
        $region_name{'ES.27'} = 'La Rioja';
        $region_name{'ES.29'} = 'Madrid';
        $region_name{'ES.31'} = 'Murcia';
        $region_name{'ES.32'} = 'Navarra';
        $region_name{'ES.34'} = 'Asturias';
        $region_name{'ES.39'} = 'Cantabria';
        $region_name{'ES.51'} = 'Andalucia';
        $region_name{'ES.52'} = 'Aragon';
        $region_name{'ES.53'} = 'Canarias';
        $region_name{'ES.54'} = 'Castilla-La Mancha';
        $region_name{'ES.55'} = 'Castilla y Leon';
        $region_name{'ES.56'} = 'Cataluna';
        $region_name{'ES.57'} = 'Extremadura';
        $region_name{'ES.58'} = 'Galicia';
        $region_name{'ES.59'} = 'Pais Vasco';
        $region_name{'ES.60'} = 'Comunidad Valenciana';
        $region_name{'ET.2'} = 'Amhara';
        $region_name{'ET.7'} = 'Somali';
        $region_name{'ET.8'} = 'Gambella';
        $region_name{'ET.10'} = 'Addis Abeba';
        $region_name{'ET.11'} = 'Southern';
        $region_name{'ET.12'} = 'Tigray';
        $region_name{'ET.13'} = 'Benishangul';
        $region_name{'ET.14'} = 'Afar';
        $region_name{'ET.44'} = 'Adis Abeba';
        $region_name{'ET.45'} = 'Afar';
        $region_name{'ET.46'} = 'Amara';
        $region_name{'ET.47'} = 'Binshangul Gumuz';
        $region_name{'ET.48'} = 'Dire Dawa';
        $region_name{'ET.49'} = 'Gambela Hizboch';
        $region_name{'ET.50'} = 'Hareri Hizb';
        $region_name{'ET.51'} = 'Oromiya';
        $region_name{'ET.52'} = 'Sumale';
        $region_name{'ET.53'} = 'Tigray';
        $region_name{'ET.54'} = 'YeDebub Biheroch Bihereseboch na Hizboch';
        $region_name{'FI.1'} = 'land';
        $region_name{'FI.6'} = 'Lapland';
        $region_name{'FI.8'} = 'Oulu';
        $region_name{'FI.13'} = 'Southern Finland';
        $region_name{'FI.14'} = 'Eastern Finland';
        $region_name{'FI.15'} = 'Western Finland';
        $region_name{'FJ.1'} = 'Central';
        $region_name{'FJ.2'} = 'Eastern';
        $region_name{'FJ.3'} = 'Northern';
        $region_name{'FJ.4'} = 'Rotuma';
        $region_name{'FJ.5'} = 'Western';
        $region_name{'FM.1'} = 'Kosrae';
        $region_name{'FM.2'} = 'Pohnpei';
        $region_name{'FM.3'} = 'Chuuk';
        $region_name{'FM.4'} = 'Yap';
        $region_name{'FR.97'} = 'Aquitaine';
        $region_name{'FR.98'} = 'Auvergne';
        $region_name{'FR.99'} = 'Basse-Normandie';
        $region_name{'FR.101'} = 'Bourgogne';
        $region_name{'FR.102'} = 'Bretagne';
        $region_name{'FR.103'} = 'Centre';
        $region_name{'FR.104'} = 'Champagne-Ardenne';
        $region_name{'FR.105'} = 'Corse';
        $region_name{'FR.106'} = 'Franche-Comte';
        $region_name{'FR.107'} = 'Haute-Normandie';
        $region_name{'FR.108'} = 'Ile-de-France';
        $region_name{'FR.109'} = 'Languedoc-Roussillon';
        $region_name{'FR.111'} = 'Limousin';
        $region_name{'FR.112'} = 'Lorraine';
        $region_name{'FR.113'} = 'Midi-Pyrenees';
        $region_name{'FR.114'} = 'Nord-Pas-de-Calais';
        $region_name{'FR.115'} = 'Pays de la Loire';
        $region_name{'FR.116'} = 'Picardie';
        $region_name{'FR.117'} = 'Poitou-Charentes';
        $region_name{'FR.118'} = "Provence-Alpes-Cote d'Azur";
        $region_name{'FR.119'} = 'Rhone-Alpes';
        $region_name{'FR.121'} = 'Alsace';
        $region_name{'GA.1'} = 'Estuaire';
        $region_name{'GA.2'} = 'Haut-Ogooue';
        $region_name{'GA.3'} = 'Moyen-Ogooue';
        $region_name{'GA.4'} = 'Ngounie';
        $region_name{'GA.5'} = 'Nyanga';
        $region_name{'GA.6'} = 'Ogooue-Ivindo';
        $region_name{'GA.7'} = 'Ogooue-Lolo';
        $region_name{'GA.8'} = 'Ogooue-Maritime';
        $region_name{'GA.9'} = 'Woleu-Ntem';
        $region_name{'GB.1'} = 'Avon';
        $region_name{'GB.3'} = 'Berkshire';
        $region_name{'GB.7'} = 'Cleveland';
        $region_name{'GB.17'} = 'Greater London';
        $region_name{'GB.18'} = 'Greater Manchester';
        $region_name{'GB.20'} = 'Hereford and Worcester';
        $region_name{'GB.22'} = 'Humberside';
        $region_name{'GB.28'} = 'Merseyside';
        $region_name{'GB.37'} = 'South Yorkshire';
        $region_name{'GB.41'} = 'Tyne and Wear';
        $region_name{'GB.43'} = 'West Midlands';
        $region_name{'GB.45'} = 'West Yorkshire';
        $region_name{'GB.79'} = 'Central';
        $region_name{'GB.82'} = 'Grampian';
        $region_name{'GB.84'} = 'Lothian';
        $region_name{'GB.87'} = 'Strathclyde';
        $region_name{'GB.88'} = 'Tayside';
        $region_name{'GB.90'} = 'Clwyd';
        $region_name{'GB.91'} = 'Dyfed';
        $region_name{'GB.92'} = 'Gwent';
        $region_name{'GB.94'} = 'Mid Glamorgan';
        $region_name{'GB.96'} = 'South Glamorgan';
        $region_name{'GB.97'} = 'West Glamorgan';
        $region_name{'GB.101'} = 'Barking and Dagenham';
        $region_name{'GB.102'} = 'Barnet';
        $region_name{'GB.103'} = 'Barnsley';
        $region_name{'GB.104'} = 'Bath and North East Somerset';
        $region_name{'GB.105'} = 'Bedfordshire';
        $region_name{'GB.106'} = 'Bexley';
        $region_name{'GB.107'} = 'Birmingham';
        $region_name{'GB.108'} = 'Blackburn with Darwen';
        $region_name{'GB.109'} = 'Blackpool';
        $region_name{'GB.111'} = 'Bolton';
        $region_name{'GB.112'} = 'Bournemouth';
        $region_name{'GB.113'} = 'Bracknell Forest';
        $region_name{'GB.114'} = 'Bradford';
        $region_name{'GB.115'} = 'Brent';
        $region_name{'GB.116'} = 'Brighton and Hove';
        $region_name{'GB.117'} = 'Bristol';
        $region_name{'GB.118'} = 'Bromley';
        $region_name{'GB.119'} = 'Buckinghamshire';
        $region_name{'GB.121'} = 'Bury';
        $region_name{'GB.122'} = 'Calderdale';
        $region_name{'GB.123'} = 'Cambridgeshire';
        $region_name{'GB.124'} = 'Camden';
        $region_name{'GB.125'} = 'Cheshire';
        $region_name{'GB.126'} = 'Cornwall';
        $region_name{'GB.127'} = 'Coventry';
        $region_name{'GB.128'} = 'Croydon';
        $region_name{'GB.129'} = 'Cumbria';
        $region_name{'GB.131'} = 'Darlington';
        $region_name{'GB.132'} = 'Derby';
        $region_name{'GB.133'} = 'Derbyshire';
        $region_name{'GB.134'} = 'Devon';
        $region_name{'GB.135'} = 'Doncaster';
        $region_name{'GB.136'} = 'Dorset';
        $region_name{'GB.137'} = 'Dudley';
        $region_name{'GB.138'} = 'Durham';
        $region_name{'GB.139'} = 'Ealing';
        $region_name{'GB.141'} = 'East Riding of Yorkshire';
        $region_name{'GB.142'} = 'East Sussex';
        $region_name{'GB.143'} = 'Enfield';
        $region_name{'GB.144'} = 'Essex';
        $region_name{'GB.145'} = 'Gateshead';
        $region_name{'GB.146'} = 'Gloucestershire';
        $region_name{'GB.147'} = 'Greenwich';
        $region_name{'GB.148'} = 'Hackney';
        $region_name{'GB.149'} = 'Halton';
        $region_name{'GB.151'} = 'Hammersmith and Fulham';
        $region_name{'GB.152'} = 'Hampshire';
        $region_name{'GB.153'} = 'Haringey';
        $region_name{'GB.154'} = 'Harrow';
        $region_name{'GB.155'} = 'Hartlepool';
        $region_name{'GB.156'} = 'Havering';
        $region_name{'GB.157'} = 'Herefordshire';
        $region_name{'GB.158'} = 'Hertford';
        $region_name{'GB.159'} = 'Hillingdon';
        $region_name{'GB.161'} = 'Hounslow';
        $region_name{'GB.162'} = 'Isle of Wight';
        $region_name{'GB.163'} = 'Islington';
        $region_name{'GB.164'} = 'Kensington and Chelsea';
        $region_name{'GB.165'} = 'Kent';
        $region_name{'GB.166'} = 'Kingston upon Hull';
        $region_name{'GB.167'} = 'Kingston upon Thames';
        $region_name{'GB.168'} = 'Kirklees';
        $region_name{'GB.169'} = 'Knowsley';
        $region_name{'GB.171'} = 'Lambeth';
        $region_name{'GB.172'} = 'Lancashire';
        $region_name{'GB.173'} = 'Leeds';
        $region_name{'GB.174'} = 'Leicester';
        $region_name{'GB.175'} = 'Leicestershire';
        $region_name{'GB.176'} = 'Lewisham';
        $region_name{'GB.177'} = 'Lincolnshire';
        $region_name{'GB.178'} = 'Liverpool';
        $region_name{'GB.179'} = 'London';
        $region_name{'GB.181'} = 'Luton';
        $region_name{'GB.182'} = 'Manchester';
        $region_name{'GB.183'} = 'Medway';
        $region_name{'GB.184'} = 'Merton';
        $region_name{'GB.185'} = 'Middlesbrough';
        $region_name{'GB.186'} = 'Milton Keynes';
        $region_name{'GB.187'} = 'Newcastle upon Tyne';
        $region_name{'GB.188'} = 'Newham';
        $region_name{'GB.189'} = 'Norfolk';
        $region_name{'GB.191'} = 'Northamptonshire';
        $region_name{'GB.192'} = 'North East Lincolnshire';
        $region_name{'GB.193'} = 'North Lincolnshire';
        $region_name{'GB.194'} = 'North Somerset';
        $region_name{'GB.195'} = 'North Tyneside';
        $region_name{'GB.196'} = 'Northumberland';
        $region_name{'GB.197'} = 'North Yorkshire';
        $region_name{'GB.198'} = 'Nottingham';
        $region_name{'GB.199'} = 'Nottinghamshire';
        $region_name{'GB.201'} = 'Oldham';
        $region_name{'GB.202'} = 'Oxfordshire';
        $region_name{'GB.203'} = 'Peterborough';
        $region_name{'GB.204'} = 'Plymouth';
        $region_name{'GB.205'} = 'Poole';
        $region_name{'GB.206'} = 'Portsmouth';
        $region_name{'GB.207'} = 'Reading';
        $region_name{'GB.208'} = 'Redbridge';
        $region_name{'GB.209'} = 'Redcar and Cleveland';
        $region_name{'GB.211'} = 'Richmond upon Thames';
        $region_name{'GB.212'} = 'Rochdale';
        $region_name{'GB.213'} = 'Rotherham';
        $region_name{'GB.214'} = 'Rutland';
        $region_name{'GB.215'} = 'Salford';
        $region_name{'GB.216'} = 'Shropshire';
        $region_name{'GB.217'} = 'Sandwell';
        $region_name{'GB.218'} = 'Sefton';
        $region_name{'GB.219'} = 'Sheffield';
        $region_name{'GB.221'} = 'Slough';
        $region_name{'GB.222'} = 'Solihull';
        $region_name{'GB.223'} = 'Somerset';
        $region_name{'GB.224'} = 'Southampton';
        $region_name{'GB.225'} = 'Southend-on-Sea';
        $region_name{'GB.226'} = 'South Gloucestershire';
        $region_name{'GB.227'} = 'South Tyneside';
        $region_name{'GB.228'} = 'Southwark';
        $region_name{'GB.229'} = 'Staffordshire';
        $region_name{'GB.231'} = 'St. Helens';
        $region_name{'GB.232'} = 'Stockport';
        $region_name{'GB.233'} = 'Stockton-on-Tees';
        $region_name{'GB.234'} = 'Stoke-on-Trent';
        $region_name{'GB.235'} = 'Suffolk';
        $region_name{'GB.236'} = 'Sunderland';
        $region_name{'GB.237'} = 'Surrey';
        $region_name{'GB.238'} = 'Sutton';
        $region_name{'GB.239'} = 'Swindon';
        $region_name{'GB.241'} = 'Tameside';
        $region_name{'GB.242'} = 'Telford and Wrekin';
        $region_name{'GB.243'} = 'Thurrock';
        $region_name{'GB.244'} = 'Torbay';
        $region_name{'GB.245'} = 'Tower Hamlets';
        $region_name{'GB.246'} = 'Trafford';
        $region_name{'GB.247'} = 'Wakefield';
        $region_name{'GB.248'} = 'Walsall';
        $region_name{'GB.249'} = 'Waltham Forest';
        $region_name{'GB.251'} = 'Wandsworth';
        $region_name{'GB.252'} = 'Warrington';
        $region_name{'GB.253'} = 'Warwickshire';
        $region_name{'GB.254'} = 'West Berkshire';
        $region_name{'GB.255'} = 'Westminster';
        $region_name{'GB.256'} = 'West Sussex';
        $region_name{'GB.257'} = 'Wigan';
        $region_name{'GB.258'} = 'Wiltshire';
        $region_name{'GB.259'} = 'Windsor and Maidenhead';
        $region_name{'GB.261'} = 'Wirral';
        $region_name{'GB.262'} = 'Wokingham';
        $region_name{'GB.263'} = 'Wolverhampton';
        $region_name{'GB.264'} = 'Worcestershire';
        $region_name{'GB.265'} = 'York';
        $region_name{'GB.266'} = 'Antrim';
        $region_name{'GB.267'} = 'Ards';
        $region_name{'GB.268'} = 'Armagh';
        $region_name{'GB.269'} = 'Ballymena';
        $region_name{'GB.271'} = 'Ballymoney';
        $region_name{'GB.272'} = 'Banbridge';
        $region_name{'GB.273'} = 'Belfast';
        $region_name{'GB.274'} = 'Carrickfergus';
        $region_name{'GB.275'} = 'Castlereagh';
        $region_name{'GB.276'} = 'Coleraine';
        $region_name{'GB.277'} = 'Cookstown';
        $region_name{'GB.278'} = 'Craigavon';
        $region_name{'GB.279'} = 'Down';
        $region_name{'GB.281'} = 'Dungannon';
        $region_name{'GB.282'} = 'Fermanagh';
        $region_name{'GB.283'} = 'Larne';
        $region_name{'GB.284'} = 'Limavady';
        $region_name{'GB.285'} = 'Lisburn';
        $region_name{'GB.286'} = 'Derry';
        $region_name{'GB.287'} = 'Magherafelt';
        $region_name{'GB.288'} = 'Moyle';
        $region_name{'GB.289'} = 'Newry and Mourne';
        $region_name{'GB.291'} = 'Newtownabbey';
        $region_name{'GB.292'} = 'North Down';
        $region_name{'GB.293'} = 'Omagh';
        $region_name{'GB.294'} = 'Strabane';
        $region_name{'GB.295'} = 'Aberdeen City';
        $region_name{'GB.296'} = 'Aberdeenshire';
        $region_name{'GB.297'} = 'Angus';
        $region_name{'GB.298'} = 'Argyll and Bute';
        $region_name{'GB.299'} = 'Scottish Borders';
        $region_name{'GB.301'} = 'Clackmannanshire';
        $region_name{'GB.302'} = 'Dumfries and Galloway';
        $region_name{'GB.303'} = 'Dundee City';
        $region_name{'GB.304'} = 'East Ayrshire';
        $region_name{'GB.305'} = 'East Dunbartonshire';
        $region_name{'GB.306'} = 'East Lothian';
        $region_name{'GB.307'} = 'East Renfrewshire';
        $region_name{'GB.308'} = 'Edinburgh';
        $region_name{'GB.309'} = 'Falkirk';
        $region_name{'GB.311'} = 'Fife';
        $region_name{'GB.312'} = 'Glasgow City';
        $region_name{'GB.313'} = 'Highland';
        $region_name{'GB.314'} = 'Inverclyde';
        $region_name{'GB.315'} = 'Midlothian';
        $region_name{'GB.316'} = 'Moray';
        $region_name{'GB.317'} = 'North Ayrshire';
        $region_name{'GB.318'} = 'North Lanarkshire';
        $region_name{'GB.319'} = 'Orkney';
        $region_name{'GB.321'} = 'Perth and Kinross';
        $region_name{'GB.322'} = 'Renfrewshire';
        $region_name{'GB.323'} = 'Shetland Islands';
        $region_name{'GB.324'} = 'South Ayrshire';
        $region_name{'GB.325'} = 'South Lanarkshire';
        $region_name{'GB.326'} = 'Stirling';
        $region_name{'GB.327'} = 'West Dunbartonshire';
        $region_name{'GB.328'} = 'Eilean Siar';
        $region_name{'GB.329'} = 'West Lothian';
        $region_name{'GB.331'} = 'Isle of Anglesey';
        $region_name{'GB.332'} = 'Blaenau Gwent';
        $region_name{'GB.333'} = 'Bridgend';
        $region_name{'GB.334'} = 'Caerphilly';
        $region_name{'GB.335'} = 'Cardiff';
        $region_name{'GB.336'} = 'Ceredigion';
        $region_name{'GB.337'} = 'Carmarthenshire';
        $region_name{'GB.338'} = 'Conwy';
        $region_name{'GB.339'} = 'Denbighshire';
        $region_name{'GB.341'} = 'Flintshire';
        $region_name{'GB.342'} = 'Gwynedd';
        $region_name{'GB.343'} = 'Merthyr Tydfil';
        $region_name{'GB.344'} = 'Monmouthshire';
        $region_name{'GB.345'} = 'Neath Port Talbot';
        $region_name{'GB.346'} = 'Newport';
        $region_name{'GB.347'} = 'Pembrokeshire';
        $region_name{'GB.348'} = 'Powys';
        $region_name{'GB.349'} = 'Rhondda Cynon Taff';
        $region_name{'GB.351'} = 'Swansea';
        $region_name{'GB.352'} = 'Torfaen';
        $region_name{'GB.353'} = 'Vale of Glamorgan';
        $region_name{'GB.354'} = 'Wrexham';
        $region_name{'GD.1'} = 'Saint Andrew';
        $region_name{'GD.2'} = 'Saint David';
        $region_name{'GD.3'} = 'Saint George';
        $region_name{'GD.4'} = 'Saint John';
        $region_name{'GD.5'} = 'Saint Mark';
        $region_name{'GD.6'} = 'Saint Patrick';
        $region_name{'GE.1'} = 'Abashis Raioni';
        $region_name{'GE.2'} = 'Abkhazia';
        $region_name{'GE.3'} = 'Adigenis Raioni';
        $region_name{'GE.4'} = 'Ajaria';
        $region_name{'GE.5'} = 'Akhalgoris Raioni';
        $region_name{'GE.6'} = "Akhalk'alak'is Raioni";
        $region_name{'GE.7'} = "Akhalts'ikhis Raioni";
        $region_name{'GE.8'} = 'Akhmetis Raioni';
        $region_name{'GE.9'} = 'Ambrolauris Raioni';
        $region_name{'GE.10'} = 'Aspindzis Raioni';
        $region_name{'GE.11'} = "Baghdat'is Raioni";
        $region_name{'GE.12'} = 'Bolnisis Raioni';
        $region_name{'GE.13'} = 'Borjomis Raioni';
        $region_name{'GE.14'} = "Chiat'ura";
        $region_name{'GE.15'} = "Ch'khorotsqus Raioni";
        $region_name{'GE.16'} = "Ch'okhatauris Raioni";
        $region_name{'GE.17'} = "Dedop'listsqaros Raioni";
        $region_name{'GE.18'} = 'Dmanisis Raioni';
        $region_name{'GE.19'} = "Dushet'is Raioni";
        $region_name{'GE.20'} = 'Gardabanis Raioni';
        $region_name{'GE.21'} = 'Gori';
        $region_name{'GE.22'} = 'Goris Raioni';
        $region_name{'GE.23'} = 'Gurjaanis Raioni';
        $region_name{'GE.24'} = 'Javis Raioni';
        $region_name{'GE.25'} = "K'arelis Raioni";
        $region_name{'GE.26'} = 'Kaspis Raioni';
        $region_name{'GE.27'} = 'Kharagaulis Raioni';
        $region_name{'GE.28'} = 'Khashuris Raioni';
        $region_name{'GE.29'} = 'Khobis Raioni';
        $region_name{'GE.30'} = 'Khonis Raioni';
        $region_name{'GE.31'} = "K'ut'aisi";
        $region_name{'GE.32'} = 'Lagodekhis Raioni';
        $region_name{'GE.33'} = "Lanch'khut'is Raioni";
        $region_name{'GE.34'} = 'Lentekhis Raioni';
        $region_name{'GE.35'} = 'Marneulis Raioni';
        $region_name{'GE.36'} = 'Martvilis Raioni';
        $region_name{'GE.37'} = 'Mestiis Raioni';
        $region_name{'GE.38'} = "Mts'khet'is Raioni";
        $region_name{'GE.39'} = 'Ninotsmindis Raioni';
        $region_name{'GE.40'} = 'Onis Raioni';
        $region_name{'GE.41'} = "Ozurget'is Raioni";
        $region_name{'GE.42'} = "P'ot'i";
        $region_name{'GE.43'} = 'Qazbegis Raioni';
        $region_name{'GE.44'} = 'Qvarlis Raioni';
        $region_name{'GE.45'} = "Rust'avi";
        $region_name{'GE.46'} = "Sach'kheris Raioni";
        $region_name{'GE.47'} = 'Sagarejos Raioni';
        $region_name{'GE.48'} = 'Samtrediis Raioni';
        $region_name{'GE.49'} = 'Senakis Raioni';
        $region_name{'GE.50'} = 'Sighnaghis Raioni';
        $region_name{'GE.51'} = "T'bilisi";
        $region_name{'GE.52'} = "T'elavis Raioni";
        $region_name{'GE.53'} = "T'erjolis Raioni";
        $region_name{'GE.54'} = "T'et'ritsqaros Raioni";
        $region_name{'GE.55'} = "T'ianet'is Raioni";
        $region_name{'GE.56'} = 'Tqibuli';
        $region_name{'GE.57'} = "Ts'ageris Raioni";
        $region_name{'GE.58'} = 'Tsalenjikhis Raioni';
        $region_name{'GE.59'} = 'Tsalkis Raioni';
        $region_name{'GE.60'} = 'Tsqaltubo';
        $region_name{'GE.61'} = 'Vanis Raioni';
        $region_name{'GE.62'} = "Zestap'onis Raioni";
        $region_name{'GE.63'} = 'Zugdidi';
        $region_name{'GE.64'} = 'Zugdidis Raioni';
        $region_name{'GH.1'} = 'Greater Accra';
        $region_name{'GH.2'} = 'Ashanti';
        $region_name{'GH.3'} = 'Brong-Ahafo';
        $region_name{'GH.4'} = 'Central';
        $region_name{'GH.5'} = 'Eastern';
        $region_name{'GH.6'} = 'Northern';
        $region_name{'GH.8'} = 'Volta';
        $region_name{'GH.9'} = 'Western';
        $region_name{'GH.10'} = 'Upper East';
        $region_name{'GH.11'} = 'Upper West';
        $region_name{'GL.1'} = 'Nordgronland';
        $region_name{'GL.2'} = 'Ostgronland';
        $region_name{'GL.3'} = 'Vestgronland';
        $region_name{'GM.1'} = 'Banjul';
        $region_name{'GM.2'} = 'Lower River';
        $region_name{'GM.3'} = 'MacCarthy Island';
        $region_name{'GM.4'} = 'Upper River';
        $region_name{'GM.5'} = 'Western';
        $region_name{'GM.7'} = 'North Bank';
        $region_name{'GN.1'} = 'Beyla';
        $region_name{'GN.2'} = 'Boffa';
        $region_name{'GN.3'} = 'Boke';
        $region_name{'GN.4'} = 'Conakry';
        $region_name{'GN.5'} = 'Dabola';
        $region_name{'GN.6'} = 'Dalaba';
        $region_name{'GN.7'} = 'Dinguiraye';
        $region_name{'GN.9'} = 'Faranah';
        $region_name{'GN.10'} = 'Forecariah';
        $region_name{'GN.11'} = 'Fria';
        $region_name{'GN.12'} = 'Gaoual';
        $region_name{'GN.13'} = 'Gueckedou';
        $region_name{'GN.15'} = 'Kerouane';
        $region_name{'GN.16'} = 'Kindia';
        $region_name{'GN.17'} = 'Kissidougou';
        $region_name{'GN.18'} = 'Koundara';
        $region_name{'GN.19'} = 'Kouroussa';
        $region_name{'GN.21'} = 'Macenta';
        $region_name{'GN.22'} = 'Mali';
        $region_name{'GN.23'} = 'Mamou';
        $region_name{'GN.25'} = 'Pita';
        $region_name{'GN.27'} = 'Telimele';
        $region_name{'GN.28'} = 'Tougue';
        $region_name{'GN.29'} = 'Yomou';
        $region_name{'GN.30'} = 'Coyah';
        $region_name{'GN.31'} = 'Dubreka';
        $region_name{'GN.32'} = 'Kankan';
        $region_name{'GN.33'} = 'Koubia';
        $region_name{'GN.34'} = 'Labe';
        $region_name{'GN.35'} = 'Lelouma';
        $region_name{'GN.36'} = 'Lola';
        $region_name{'GN.37'} = 'Mandiana';
        $region_name{'GN.38'} = 'Nzerekore';
        $region_name{'GN.39'} = 'Siguiri';
        $region_name{'GQ.3'} = 'Annobon';
        $region_name{'GQ.4'} = 'Bioko Norte';
        $region_name{'GQ.5'} = 'Bioko Sur';
        $region_name{'GQ.6'} = 'Centro Sur';
        $region_name{'GQ.7'} = 'Kie-Ntem';
        $region_name{'GQ.8'} = 'Litoral';
        $region_name{'GQ.9'} = 'Wele-Nzas';
        $region_name{'GR.1'} = 'Evros';
        $region_name{'GR.2'} = 'Rodhopi';
        $region_name{'GR.3'} = 'Xanthi';
        $region_name{'GR.4'} = 'Drama';
        $region_name{'GR.5'} = 'Serrai';
        $region_name{'GR.6'} = 'Kilkis';
        $region_name{'GR.7'} = 'Pella';
        $region_name{'GR.8'} = 'Florina';
        $region_name{'GR.9'} = 'Kastoria';
        $region_name{'GR.10'} = 'Grevena';
        $region_name{'GR.11'} = 'Kozani';
        $region_name{'GR.12'} = 'Imathia';
        $region_name{'GR.13'} = 'Thessaloniki';
        $region_name{'GR.14'} = 'Kavala';
        $region_name{'GR.15'} = 'Khalkidhiki';
        $region_name{'GR.16'} = 'Pieria';
        $region_name{'GR.17'} = 'Ioannina';
        $region_name{'GR.18'} = 'Thesprotia';
        $region_name{'GR.19'} = 'Preveza';
        $region_name{'GR.20'} = 'Arta';
        $region_name{'GR.21'} = 'Larisa';
        $region_name{'GR.22'} = 'Trikala';
        $region_name{'GR.23'} = 'Kardhitsa';
        $region_name{'GR.24'} = 'Magnisia';
        $region_name{'GR.25'} = 'Kerkira';
        $region_name{'GR.26'} = 'Levkas';
        $region_name{'GR.27'} = 'Kefallinia';
        $region_name{'GR.28'} = 'Zakinthos';
        $region_name{'GR.29'} = 'Fthiotis';
        $region_name{'GR.30'} = 'Evritania';
        $region_name{'GR.31'} = 'Aitolia kai Akarnania';
        $region_name{'GR.32'} = 'Fokis';
        $region_name{'GR.33'} = 'Voiotia';
        $region_name{'GR.34'} = 'Evvoia';
        $region_name{'GR.35'} = 'Attiki';
        $region_name{'GR.36'} = 'Argolis';
        $region_name{'GR.37'} = 'Korinthia';
        $region_name{'GR.38'} = 'Akhaia';
        $region_name{'GR.39'} = 'Ilia';
        $region_name{'GR.40'} = 'Messinia';
        $region_name{'GR.41'} = 'Arkadhia';
        $region_name{'GR.42'} = 'Lakonia';
        $region_name{'GR.43'} = 'Khania';
        $region_name{'GR.44'} = 'Rethimni';
        $region_name{'GR.45'} = 'Iraklion';
        $region_name{'GR.46'} = 'Lasithi';
        $region_name{'GR.47'} = 'Dhodhekanisos';
        $region_name{'GR.48'} = 'Samos';
        $region_name{'GR.49'} = 'Kikladhes';
        $region_name{'GR.50'} = 'Khios';
        $region_name{'GR.51'} = 'Lesvos';
        $region_name{'GT.1'} = 'Alta Verapaz';
        $region_name{'GT.2'} = 'Baja Verapaz';
        $region_name{'GT.3'} = 'Chimaltenango';
        $region_name{'GT.4'} = 'Chiquimula';
        $region_name{'GT.5'} = 'El Progreso';
        $region_name{'GT.6'} = 'Escuintla';
        $region_name{'GT.7'} = 'Guatemala';
        $region_name{'GT.8'} = 'Huehuetenango';
        $region_name{'GT.9'} = 'Izabal';
        $region_name{'GT.10'} = 'Jalapa';
        $region_name{'GT.11'} = 'Jutiapa';
        $region_name{'GT.12'} = 'Peten';
        $region_name{'GT.13'} = 'Quetzaltenango';
        $region_name{'GT.14'} = 'Quiche';
        $region_name{'GT.15'} = 'Retalhuleu';
        $region_name{'GT.16'} = 'Sacatepequez';
        $region_name{'GT.17'} = 'San Marcos';
        $region_name{'GT.18'} = 'Santa Rosa';
        $region_name{'GT.19'} = 'Solola';
        $region_name{'GT.20'} = 'Suchitepequez';
        $region_name{'GT.21'} = 'Totonicapan';
        $region_name{'GT.22'} = 'Zacapa';
        $region_name{'GW.1'} = 'Bafata';
        $region_name{'GW.2'} = 'Quinara';
        $region_name{'GW.4'} = 'Oio';
        $region_name{'GW.5'} = 'Bolama';
        $region_name{'GW.6'} = 'Cacheu';
        $region_name{'GW.7'} = 'Tombali';
        $region_name{'GW.10'} = 'Gabu';
        $region_name{'GW.11'} = 'Bissau';
        $region_name{'GW.12'} = 'Biombo';
        $region_name{'GY.10'} = 'Barima-Waini';
        $region_name{'GY.11'} = 'Cuyuni-Mazaruni';
        $region_name{'GY.12'} = 'Demerara-Mahaica';
        $region_name{'GY.13'} = 'East Berbice-Corentyne';
        $region_name{'GY.14'} = 'Essequibo Islands-West Demerara';
        $region_name{'GY.15'} = 'Mahaica-Berbice';
        $region_name{'GY.16'} = 'Pomeroon-Supenaam';
        $region_name{'GY.17'} = 'Potaro-Siparuni';
        $region_name{'GY.18'} = 'Upper Demerara-Berbice';
        $region_name{'GY.19'} = 'Upper Takutu-Upper Essequibo';
        $region_name{'HN.1'} = 'Atlantida';
        $region_name{'HN.2'} = 'Choluteca';
        $region_name{'HN.3'} = 'Colon';
        $region_name{'HN.4'} = 'Comayagua';
        $region_name{'HN.5'} = 'Copan';
        $region_name{'HN.6'} = 'Cortes';
        $region_name{'HN.7'} = 'El Paraiso';
        $region_name{'HN.8'} = 'Francisco Morazan';
        $region_name{'HN.9'} = 'Gracias a Dios';
        $region_name{'HN.10'} = 'Intibuca';
        $region_name{'HN.11'} = 'Islas de la Bahia';
        $region_name{'HN.12'} = 'La Paz';
        $region_name{'HN.13'} = 'Lempira';
        $region_name{'HN.14'} = 'Ocotepeque';
        $region_name{'HN.15'} = 'Olancho';
        $region_name{'HN.16'} = 'Santa Barbara';
        $region_name{'HN.17'} = 'Valle';
        $region_name{'HN.18'} = 'Yoro';
        $region_name{'HR.1'} = 'Bjelovarsko-Bilogorska';
        $region_name{'HR.2'} = 'Brodsko-Posavska';
        $region_name{'HR.3'} = 'Dubrovacko-Neretvanska';
        $region_name{'HR.4'} = 'Istarska';
        $region_name{'HR.5'} = 'Karlovacka';
        $region_name{'HR.6'} = 'Koprivnicko-Krizevacka';
        $region_name{'HR.7'} = 'Krapinsko-Zagorska';
        $region_name{'HR.8'} = 'Licko-Senjska';
        $region_name{'HR.9'} = 'Medimurska';
        $region_name{'HR.10'} = 'Osjecko-Baranjska';
        $region_name{'HR.11'} = 'Pozesko-Slavonska';
        $region_name{'HR.12'} = 'Primorsko-Goranska';
        $region_name{'HR.13'} = 'Sibensko-Kninska';
        $region_name{'HR.14'} = 'Sisacko-Moslavacka';
        $region_name{'HR.15'} = 'Splitsko-Dalmatinska';
        $region_name{'HR.16'} = 'Varazdinska';
        $region_name{'HR.17'} = 'Viroviticko-Podravska';
        $region_name{'HR.18'} = 'Vukovarsko-Srijemska';
        $region_name{'HR.19'} = 'Zadarska';
        $region_name{'HR.20'} = 'Zagrebacka';
        $region_name{'HR.21'} = 'Grad Zagreb';
        $region_name{'HT.3'} = 'Nord-Ouest';
        $region_name{'HT.6'} = 'Artibonite';
        $region_name{'HT.7'} = 'Centre';
        $region_name{'HT.8'} = "Grand' Anse";
        $region_name{'HT.9'} = 'Nord';
        $region_name{'HT.10'} = 'Nord-Est';
        $region_name{'HT.11'} = 'Ouest';
        $region_name{'HT.12'} = 'Sud';
        $region_name{'HT.13'} = 'Sud-Est';
        $region_name{'HU.1'} = 'Bacs-Kiskun';
        $region_name{'HU.2'} = 'Baranya';
        $region_name{'HU.3'} = 'Bekes';
        $region_name{'HU.4'} = 'Borsod-Abauj-Zemplen';
        $region_name{'HU.5'} = 'Budapest';
        $region_name{'HU.6'} = 'Csongrad';
        $region_name{'HU.7'} = 'Debrecen';
        $region_name{'HU.8'} = 'Fejer';
        $region_name{'HU.9'} = 'Gyor-Moson-Sopron';
        $region_name{'HU.10'} = 'Hajdu-Bihar';
        $region_name{'HU.11'} = 'Heves';
        $region_name{'HU.12'} = 'Komarom-Esztergom';
        $region_name{'HU.13'} = 'Miskolc';
        $region_name{'HU.14'} = 'Nograd';
        $region_name{'HU.15'} = 'Pecs';
        $region_name{'HU.16'} = 'Pest';
        $region_name{'HU.17'} = 'Somogy';
        $region_name{'HU.18'} = 'Szabolcs-Szatmar-Bereg';
        $region_name{'HU.19'} = 'Szeged';
        $region_name{'HU.20'} = 'Jasz-Nagykun-Szolnok';
        $region_name{'HU.21'} = 'Tolna';
        $region_name{'HU.22'} = 'Vas';
        $region_name{'HU.23'} = 'Veszprem';
        $region_name{'HU.24'} = 'Zala';
        $region_name{'HU.25'} = 'Gyor';
        $region_name{'HU.26'} = 'Bekescsaba';
        $region_name{'HU.27'} = 'Dunaujvaros';
        $region_name{'HU.28'} = 'Eger';
        $region_name{'HU.29'} = 'Hodmezovasarhely';
        $region_name{'HU.30'} = 'Kaposvar';
        $region_name{'HU.31'} = 'Kecskemet';
        $region_name{'HU.32'} = 'Nagykanizsa';
        $region_name{'HU.33'} = 'Nyiregyhaza';
        $region_name{'HU.34'} = 'Sopron';
        $region_name{'HU.35'} = 'Szekesfehervar';
        $region_name{'HU.36'} = 'Szolnok';
        $region_name{'HU.37'} = 'Szombathely';
        $region_name{'HU.38'} = 'Tatabanya';
        $region_name{'HU.39'} = 'Veszprem';
        $region_name{'HU.40'} = 'Zalaegerszeg';
        $region_name{'ID.1'} = 'Aceh';
        $region_name{'ID.2'} = 'Bali';
        $region_name{'ID.3'} = 'Bengkulu';
        $region_name{'ID.4'} = 'Jakarta Raya';
        $region_name{'ID.5'} = 'Jambi';
        $region_name{'ID.7'} = 'Jawa Tengah';
        $region_name{'ID.8'} = 'Jawa Timur';
        $region_name{'ID.9'} = 'Papua';
        $region_name{'ID.10'} = 'Yogyakarta';
        $region_name{'ID.11'} = 'Kalimantan Barat';
        $region_name{'ID.12'} = 'Kalimantan Selatan';
        $region_name{'ID.13'} = 'Kalimantan Tengah';
        $region_name{'ID.14'} = 'Kalimantan Timur';
        $region_name{'ID.15'} = 'Lampung';
        $region_name{'ID.17'} = 'Nusa Tenggara Barat';
        $region_name{'ID.18'} = 'Nusa Tenggara Timur';
        $region_name{'ID.19'} = 'Riau';
        $region_name{'ID.20'} = 'Sulawesi Selatan';
        $region_name{'ID.21'} = 'Sulawesi Tengah';
        $region_name{'ID.22'} = 'Sulawesi Tenggara';
        $region_name{'ID.24'} = 'Sumatera Barat';
        $region_name{'ID.26'} = 'Sumatera Utara';
        $region_name{'ID.28'} = 'Maluku';
        $region_name{'ID.29'} = 'Maluku Utara';
        $region_name{'ID.30'} = 'Jawa Barat';
        $region_name{'ID.31'} = 'Sulawesi Utara';
        $region_name{'ID.32'} = 'Sumatera Selatan';
        $region_name{'ID.33'} = 'Banten';
        $region_name{'ID.34'} = 'Gorontalo';
        $region_name{'ID.35'} = 'Kepulauan Bangka Belitung';
        $region_name{'IE.1'} = 'Carlow';
        $region_name{'IE.2'} = 'Cavan';
        $region_name{'IE.3'} = 'Clare';
        $region_name{'IE.4'} = 'Cork';
        $region_name{'IE.6'} = 'Donegal';
        $region_name{'IE.7'} = 'Dublin';
        $region_name{'IE.10'} = 'Galway';
        $region_name{'IE.11'} = 'Kerry';
        $region_name{'IE.12'} = 'Kildare';
        $region_name{'IE.13'} = 'Kilkenny';
        $region_name{'IE.14'} = 'Leitrim';
        $region_name{'IE.15'} = 'Laois';
        $region_name{'IE.16'} = 'Limerick';
        $region_name{'IE.18'} = 'Longford';
        $region_name{'IE.19'} = 'Louth';
        $region_name{'IE.20'} = 'Mayo';
        $region_name{'IE.21'} = 'Meath';
        $region_name{'IE.22'} = 'Monaghan';
        $region_name{'IE.23'} = 'Offaly';
        $region_name{'IE.24'} = 'Roscommon';
        $region_name{'IE.25'} = 'Sligo';
        $region_name{'IE.26'} = 'Tipperary';
        $region_name{'IE.27'} = 'Waterford';
        $region_name{'IE.29'} = 'Westmeath';
        $region_name{'IE.30'} = 'Wexford';
        $region_name{'IE.31'} = 'Wicklow';
        $region_name{'IL.1'} = 'HaDarom';
        $region_name{'IL.2'} = 'HaMerkaz';
        $region_name{'IL.3'} = 'HaZafon';
        $region_name{'IL.4'} = 'Hefa';
        $region_name{'IL.5'} = 'Tel Aviv';
        $region_name{'IL.6'} = 'Yerushalayim';
        $region_name{'IN.1'} = 'Andaman and Nicobar Islands';
        $region_name{'IN.2'} = 'Andhra Pradesh';
        $region_name{'IN.3'} = 'Assam';
        $region_name{'IN.5'} = 'Chandigarh';
        $region_name{'IN.6'} = 'Dadra and Nagar Haveli';
        $region_name{'IN.7'} = 'Delhi';
        $region_name{'IN.9'} = 'Gujarat';
        $region_name{'IN.10'} = 'Haryana';
        $region_name{'IN.11'} = 'Himachal Pradesh';
        $region_name{'IN.12'} = 'Jammu and Kashmir';
        $region_name{'IN.13'} = 'Kerala';
        $region_name{'IN.14'} = 'Lakshadweep';
        $region_name{'IN.16'} = 'Maharashtra';
        $region_name{'IN.17'} = 'Manipur';
        $region_name{'IN.18'} = 'Meghalaya';
        $region_name{'IN.19'} = 'Karnataka';
        $region_name{'IN.20'} = 'Nagaland';
        $region_name{'IN.21'} = 'Orissa';
        $region_name{'IN.22'} = 'Pondicherry';
        $region_name{'IN.23'} = 'Punjab';
        $region_name{'IN.24'} = 'Rajasthan';
        $region_name{'IN.25'} = 'Tamil Nadu';
        $region_name{'IN.26'} = 'Tripura';
        $region_name{'IN.28'} = 'West Bengal';
        $region_name{'IN.29'} = 'Sikkim';
        $region_name{'IN.30'} = 'Arunachal Pradesh';
        $region_name{'IN.31'} = 'Mizoram';
        $region_name{'IN.32'} = 'Daman and Diu';
        $region_name{'IN.33'} = 'Goa';
        $region_name{'IN.34'} = 'Bihar';
        $region_name{'IN.35'} = 'Madhya Pradesh';
        $region_name{'IN.36'} = 'Uttar Pradesh';
        $region_name{'IN.37'} = 'Chhattisgarh';
        $region_name{'IN.38'} = 'Jharkhand';
        $region_name{'IN.39'} = 'Uttaranchal';
        $region_name{'IQ.1'} = 'Al Anbar';
        $region_name{'IQ.2'} = 'Al Basrah';
        $region_name{'IQ.3'} = 'Al Muthanna';
        $region_name{'IQ.4'} = 'Al Qadisiyah';
        $region_name{'IQ.5'} = 'As Sulaymaniyah';
        $region_name{'IQ.6'} = 'Babil';
        $region_name{'IQ.7'} = 'Baghdad';
        $region_name{'IQ.8'} = 'Dahuk';
        $region_name{'IQ.9'} = 'Dhi Qar';
        $region_name{'IQ.10'} = 'Diyala';
        $region_name{'IQ.11'} = 'Arbil';
        $region_name{'IQ.12'} = "Karbala'";
        $region_name{'IQ.13'} = "At Ta'mim";
        $region_name{'IQ.14'} = 'Maysan';
        $region_name{'IQ.15'} = 'Ninawa';
        $region_name{'IQ.16'} = 'Wasit';
        $region_name{'IQ.17'} = 'An Najaf';
        $region_name{'IQ.18'} = 'Salah ad Din';
        $region_name{'IR.1'} = 'Azarbayjan-e Bakhtari';
        $region_name{'IR.2'} = 'Azarbayjan-e Khavari';
        $region_name{'IR.3'} = 'Chahar Mahall va Bakhtiari';
        $region_name{'IR.4'} = 'Sistan va Baluchestan';
        $region_name{'IR.5'} = 'Kohkiluyeh va Buyer Ahmadi';
        $region_name{'IR.7'} = 'Fars';
        $region_name{'IR.8'} = 'Gilan';
        $region_name{'IR.9'} = 'Hamadan';
        $region_name{'IR.10'} = 'Ilam';
        $region_name{'IR.11'} = 'Hormozgan';
        $region_name{'IR.13'} = 'Bakhtaran';
        $region_name{'IR.15'} = 'Khuzestan';
        $region_name{'IR.16'} = 'Kordestan';
        $region_name{'IR.22'} = 'Bushehr';
        $region_name{'IR.23'} = 'Lorestan';
        $region_name{'IR.25'} = 'Semnan';
        $region_name{'IR.26'} = 'Tehran';
        $region_name{'IR.28'} = 'Esfahan';
        $region_name{'IR.29'} = 'Kerman';
        $region_name{'IR.30'} = 'Khorasan';
        $region_name{'IR.31'} = 'Yazd';
        $region_name{'IR.32'} = 'Ardabil';
        $region_name{'IR.34'} = 'Markazi';
        $region_name{'IR.35'} = 'Mazandaran';
        $region_name{'IR.36'} = 'Zanjan';
        $region_name{'IR.37'} = 'Golestan';
        $region_name{'IR.38'} = 'Qazvin';
        $region_name{'IR.39'} = 'Qom';
        $region_name{'IS.1'} = 'Akranes';
        $region_name{'IS.2'} = 'Akureyri';
        $region_name{'IS.3'} = 'Arnessysla';
        $region_name{'IS.4'} = 'Austur-Bardastrandarsysla';
        $region_name{'IS.5'} = 'Austur-Hunavatnssysla';
        $region_name{'IS.6'} = 'Austur-Skaftafellssysla';
        $region_name{'IS.7'} = 'Borgarfjardarsysla';
        $region_name{'IS.8'} = 'Dalasysla';
        $region_name{'IS.9'} = 'Eyjafjardarsysla';
        $region_name{'IS.10'} = 'Gullbringusysla';
        $region_name{'IS.11'} = 'Hafnarfjordur';
        $region_name{'IS.12'} = 'Husavik';
        $region_name{'IS.13'} = 'Isafjordur';
        $region_name{'IS.14'} = 'Keflavik';
        $region_name{'IS.15'} = 'Kjosarsysla';
        $region_name{'IS.16'} = 'Kopavogur';
        $region_name{'IS.17'} = 'Myrasysla';
        $region_name{'IS.18'} = 'Neskaupstadur';
        $region_name{'IS.19'} = 'Nordur-Isafjardarsysla';
        $region_name{'IS.20'} = 'Nordur-Mulasysla';
        $region_name{'IS.21'} = 'Nordur-Tingeyjarsysla';
        $region_name{'IS.22'} = 'Olafsfjordur';
        $region_name{'IS.23'} = 'Rangarvallasysla';
        $region_name{'IS.24'} = 'Reykjavik';
        $region_name{'IS.25'} = 'Saudarkrokur';
        $region_name{'IS.26'} = 'Seydisfjordur';
        $region_name{'IS.27'} = 'Siglufjordur';
        $region_name{'IS.28'} = 'Skagafjardarsysla';
        $region_name{'IS.29'} = 'Snafellsnes- og Hnappadalssysla';
        $region_name{'IS.30'} = 'Strandasysla';
        $region_name{'IS.31'} = 'Sudur-Mulasysla';
        $region_name{'IS.32'} = 'Sudur-Tingeyjarsysla';
        $region_name{'IS.33'} = 'Vestmannaeyjar';
        $region_name{'IS.34'} = 'Vestur-Bardastrandarsysla';
        $region_name{'IS.35'} = 'Vestur-Hunavatnssysla';
        $region_name{'IS.36'} = 'Vestur-Isafjardarsysla';
        $region_name{'IS.37'} = 'Vestur-Skaftafellssysla';
        $region_name{'IT.1'} = 'Abruzzi';
        $region_name{'IT.2'} = 'Basilicata';
        $region_name{'IT.3'} = 'Calabria';
        $region_name{'IT.4'} = 'Campania';
        $region_name{'IT.5'} = 'Emilia-Romagna';
        $region_name{'IT.6'} = 'Friuli-Venezia Giulia';
        $region_name{'IT.7'} = 'Lazio';
        $region_name{'IT.8'} = 'Liguria';
        $region_name{'IT.9'} = 'Lombardia';
        $region_name{'IT.10'} = 'Marche';
        $region_name{'IT.11'} = 'Molise';
        $region_name{'IT.12'} = 'Piemonte';
        $region_name{'IT.13'} = 'Puglia';
        $region_name{'IT.14'} = 'Sardegna';
        $region_name{'IT.15'} = 'Sicilia';
        $region_name{'IT.16'} = 'Toscana';
        $region_name{'IT.17'} = 'Trentino-Alto Adige';
        $region_name{'IT.18'} = 'Umbria';
        $region_name{'IT.19'} = "Valle d'Aosta";
        $region_name{'IT.20'} = 'Veneto';
        $region_name{'JM.1'} = 'Clarendon';
        $region_name{'JM.2'} = 'Hanover';
        $region_name{'JM.4'} = 'Manchester';
        $region_name{'JM.7'} = 'Portland';
        $region_name{'JM.8'} = 'Saint Andrew';
        $region_name{'JM.9'} = 'Saint Ann';
        $region_name{'JM.10'} = 'Saint Catherine';
        $region_name{'JM.11'} = 'Saint Elizabeth';
        $region_name{'JM.12'} = 'Saint James';
        $region_name{'JM.13'} = 'Saint Mary';
        $region_name{'JM.14'} = 'Saint Thomas';
        $region_name{'JM.15'} = 'Trelawny';
        $region_name{'JM.16'} = 'Westmoreland';
        $region_name{'JM.17'} = 'Kingston';
        $region_name{'JO.2'} = "Al Balqa'";
        $region_name{'JO.7'} = 'Ma';
        $region_name{'JO.9'} = 'Al Karak';
        $region_name{'JO.10'} = 'Al Mafraq';
        $region_name{'JO.12'} = 'At Tafilah';
        $region_name{'JO.13'} = 'Az Zarqa';
        $region_name{'JO.14'} = 'Irbid';
        $region_name{'JO.16'} = 'Amman';
        $region_name{'JP.1'} = 'Aichi';
        $region_name{'JP.2'} = 'Akita';
        $region_name{'JP.3'} = 'Aomori';
        $region_name{'JP.4'} = 'Chiba';
        $region_name{'JP.5'} = 'Ehime';
        $region_name{'JP.6'} = 'Fukui';
        $region_name{'JP.7'} = 'Fukuoka';
        $region_name{'JP.8'} = 'Fukushima';
        $region_name{'JP.9'} = 'Gifu';
        $region_name{'JP.10'} = 'Gumma';
        $region_name{'JP.11'} = 'Hiroshima';
        $region_name{'JP.12'} = 'Hokkaido';
        $region_name{'JP.13'} = 'Hyogo';
        $region_name{'JP.14'} = 'Ibaraki';
        $region_name{'JP.15'} = 'Ishikawa';
        $region_name{'JP.16'} = 'Iwate';
        $region_name{'JP.17'} = 'Kagawa';
        $region_name{'JP.18'} = 'Kagoshima';
        $region_name{'JP.19'} = 'Kanagawa';
        $region_name{'JP.20'} = 'Kochi';
        $region_name{'JP.21'} = 'Kumamoto';
        $region_name{'JP.22'} = 'Kyoto';
        $region_name{'JP.23'} = 'Mie';
        $region_name{'JP.24'} = 'Miyagi';
        $region_name{'JP.25'} = 'Miyazaki';
        $region_name{'JP.26'} = 'Nagano';
        $region_name{'JP.27'} = 'Nagasaki';
        $region_name{'JP.28'} = 'Nara';
        $region_name{'JP.29'} = 'Niigata';
        $region_name{'JP.30'} = 'Oita';
        $region_name{'JP.31'} = 'Okayama';
        $region_name{'JP.32'} = 'Osaka';
        $region_name{'JP.33'} = 'Saga';
        $region_name{'JP.34'} = 'Saitama';
        $region_name{'JP.35'} = 'Shiga';
        $region_name{'JP.36'} = 'Shimane';
        $region_name{'JP.37'} = 'Shizuoka';
        $region_name{'JP.38'} = 'Tochigi';
        $region_name{'JP.39'} = 'Tokushima';
        $region_name{'JP.40'} = 'Tokyo';
        $region_name{'JP.41'} = 'Tottori';
        $region_name{'JP.42'} = 'Toyama';
        $region_name{'JP.43'} = 'Wakayama';
        $region_name{'JP.44'} = 'Yamagata';
        $region_name{'JP.45'} = 'Yamaguchi';
        $region_name{'JP.46'} = 'Yamanashi';
        $region_name{'JP.47'} = 'Okinawa';
        $region_name{'KE.1'} = 'Central';
        $region_name{'KE.2'} = 'Coast';
        $region_name{'KE.3'} = 'Eastern';
        $region_name{'KE.5'} = 'Nairobi Area';
        $region_name{'KE.6'} = 'North-Eastern';
        $region_name{'KE.7'} = 'Nyanza';
        $region_name{'KE.8'} = 'Rift Valley';
        $region_name{'KE.9'} = 'Western';
        $region_name{'KG.1'} = 'Bishkek';
        $region_name{'KG.2'} = 'Chuy';
        $region_name{'KG.3'} = 'Jalal-Abad';
        $region_name{'KG.4'} = 'Naryn';
        $region_name{'KG.6'} = 'Talas';
        $region_name{'KG.7'} = 'Ysyk-Kol';
        $region_name{'KG.8'} = 'Osh';
        $region_name{'KG.9'} = 'Batken';
        $region_name{'KH.2'} = 'Kampong Cham';
        $region_name{'KH.3'} = 'Kampong Chhnang';
        $region_name{'KH.4'} = 'Kampong Spoe';
        $region_name{'KH.5'} = 'Kampong Thum';
        $region_name{'KH.6'} = 'Kampot';
        $region_name{'KH.7'} = 'Kandal';
        $region_name{'KH.8'} = 'Kaoh Kong';
        $region_name{'KH.9'} = 'Kracheh';
        $region_name{'KH.10'} = 'Mondol Kiri';
        $region_name{'KH.11'} = 'Phnum Penh';
        $region_name{'KH.12'} = 'Pouthisat';
        $region_name{'KH.13'} = 'Preah Vihear';
        $region_name{'KH.14'} = 'Prey Veng';
        $region_name{'KH.15'} = 'Rotanokiri';
        $region_name{'KH.16'} = 'Siemreab-Otdar Meanchey';
        $region_name{'KH.17'} = 'Stoeng Treng';
        $region_name{'KH.18'} = 'Svay Rieng';
        $region_name{'KH.19'} = 'Takev';
        $region_name{'KH.29'} = 'Batdambang';
        $region_name{'KH.30'} = 'Pailin';
        $region_name{'KI.1'} = 'Gilbert Islands';
        $region_name{'KI.2'} = 'Line Islands';
        $region_name{'KI.3'} = 'Phoenix Islands';
        $region_name{'KM.1'} = 'Anjouan';
        $region_name{'KM.2'} = 'Grande Comore';
        $region_name{'KM.3'} = 'Moheli';
        $region_name{'KN.1'} = 'Christ Church Nichola Town';
        $region_name{'KN.2'} = 'Saint Anne Sandy Point';
        $region_name{'KN.3'} = 'Saint George Basseterre';
        $region_name{'KN.4'} = 'Saint George Gingerland';
        $region_name{'KN.5'} = 'Saint James Windward';
        $region_name{'KN.6'} = 'Saint John Capisterre';
        $region_name{'KN.7'} = 'Saint John Figtree';
        $region_name{'KN.8'} = 'Saint Mary Cayon';
        $region_name{'KN.9'} = 'Saint Paul Capisterre';
        $region_name{'KN.10'} = 'Saint Paul Charlestown';
        $region_name{'KN.11'} = 'Saint Peter Basseterre';
        $region_name{'KN.12'} = 'Saint Thomas Lowland';
        $region_name{'KN.13'} = 'Saint Thomas Middle Island';
        $region_name{'KN.15'} = 'Trinity Palmetto Point';
        $region_name{'KP.1'} = 'Chagang-do';
        $region_name{'KP.3'} = 'Hamgyong-namdo';
        $region_name{'KP.6'} = 'Hwanghae-namdo';
        $region_name{'KP.7'} = 'Hwanghae-bukto';
        $region_name{'KP.8'} = 'Kaesong-si';
        $region_name{'KP.9'} = 'Kangwon-do';
        $region_name{'KP.11'} = "P'yongan-bukto";
        $region_name{'KP.12'} = "P'yongyang-si";
        $region_name{'KP.13'} = 'Yanggang-do';
        $region_name{'KP.14'} = "Namp'o-si";
        $region_name{'KP.15'} = "P'yongan-namdo";
        $region_name{'KP.17'} = 'Hamgyong-bukto';
        $region_name{'KP.18'} = 'Najin Sonbong-si';
        $region_name{'KR.1'} = 'Cheju-do';
        $region_name{'KR.3'} = 'Cholla-bukto';
        $region_name{'KR.5'} = "Ch'ungch'ong-bukto";
        $region_name{'KR.6'} = 'Kangwon-do';
        $region_name{'KR.10'} = 'Pusan-jikhalsi';
        $region_name{'KR.11'} = "Seoul-t'ukpyolsi";
        $region_name{'KR.12'} = "Inch'on-jikhalsi";
        $region_name{'KR.13'} = 'Kyonggi-do';
        $region_name{'KR.14'} = 'Kyongsang-bukto';
        $region_name{'KR.15'} = 'Taegu-jikhalsi';
        $region_name{'KR.16'} = 'Cholla-namdo';
        $region_name{'KR.17'} = "Ch'ungch'ong-namdo";
        $region_name{'KR.18'} = 'Kwangju-jikhalsi';
        $region_name{'KR.19'} = 'Taejon-jikhalsi';
        $region_name{'KR.20'} = 'Kyongsang-namdo';
        $region_name{'KR.21'} = 'Ulsan-gwangyoksi';
        $region_name{'KW.1'} = 'Al Ahmadi';
        $region_name{'KW.2'} = 'Al Kuwayt';
        $region_name{'KW.3'} = 'Hawalli';
        $region_name{'KW.5'} = 'Al Jahra';
        $region_name{'KY.1'} = 'Creek';
        $region_name{'KY.2'} = 'Eastern';
        $region_name{'KY.3'} = 'Midland';
        $region_name{'KY.4'} = 'South Town';
        $region_name{'KY.5'} = 'Spot Bay';
        $region_name{'KY.6'} = 'Stake Bay';
        $region_name{'KY.7'} = 'West End';
        $region_name{'KY.8'} = 'Western';
        $region_name{'KZ.1'} = 'Almaty';
        $region_name{'KZ.2'} = 'Almaty City';
        $region_name{'KZ.3'} = 'Aqmola';
        $region_name{'KZ.4'} = 'Aqtbe';
        $region_name{'KZ.5'} = 'Astana';
        $region_name{'KZ.6'} = 'Atyrau';
        $region_name{'KZ.7'} = 'West Kazakhstan';
        $region_name{'KZ.8'} = 'Bayqonyr';
        $region_name{'KZ.9'} = 'Mangghystau';
        $region_name{'KZ.10'} = 'South Kazakhstan';
        $region_name{'KZ.11'} = 'Pavlodar';
        $region_name{'KZ.12'} = 'Qaraghandy';
        $region_name{'KZ.13'} = 'Qostanay';
        $region_name{'KZ.14'} = 'Qyzylorda';
        $region_name{'KZ.15'} = 'East Kazakhstan';
        $region_name{'KZ.16'} = 'North Kazakhstan';
        $region_name{'KZ.17'} = 'Zhambyl';
        $region_name{'LA.1'} = 'Attapu';
        $region_name{'LA.2'} = 'Champasak';
        $region_name{'LA.3'} = 'Houaphan';
        $region_name{'LA.4'} = 'Khammouan';
        $region_name{'LA.5'} = 'Louang Namtha';
        $region_name{'LA.7'} = 'Oudomxai';
        $region_name{'LA.8'} = 'Phongsali';
        $region_name{'LA.9'} = 'Saravan';
        $region_name{'LA.10'} = 'Savannakhet';
        $region_name{'LA.11'} = 'Vientiane';
        $region_name{'LA.13'} = 'Xaignabouri';
        $region_name{'LA.14'} = 'Xiangkhoang';
        $region_name{'LA.17'} = 'Louangphrabang';
        $region_name{'LB.1'} = 'Beqaa';
        $region_name{'LB.3'} = 'Liban-Nord';
        $region_name{'LB.4'} = 'Beyrouth';
        $region_name{'LB.5'} = 'Mont-Liban';
        $region_name{'LB.6'} = 'Liban-Sud';
        $region_name{'LB.7'} = 'Nabatiye';
        $region_name{'LC.1'} = 'Anse-la-Raye';
        $region_name{'LC.2'} = 'Dauphin';
        $region_name{'LC.3'} = 'Castries';
        $region_name{'LC.4'} = 'Choiseul';
        $region_name{'LC.5'} = 'Dennery';
        $region_name{'LC.6'} = 'Gros-Islet';
        $region_name{'LC.7'} = 'Laborie';
        $region_name{'LC.8'} = 'Micoud';
        $region_name{'LC.9'} = 'Soufriere';
        $region_name{'LC.10'} = 'Vieux-Fort';
        $region_name{'LC.11'} = 'Praslin';
        $region_name{'LI.1'} = 'Balzers';
        $region_name{'LI.2'} = 'Eschen';
        $region_name{'LI.3'} = 'Gamprin';
        $region_name{'LI.4'} = 'Mauren';
        $region_name{'LI.5'} = 'Planken';
        $region_name{'LI.6'} = 'Ruggell';
        $region_name{'LI.7'} = 'Schaan';
        $region_name{'LI.8'} = 'Schellenberg';
        $region_name{'LI.9'} = 'Triesen';
        $region_name{'LI.10'} = 'Triesenberg';
        $region_name{'LI.11'} = 'Vaduz';
        $region_name{'LK.1'} = 'Amparai';
        $region_name{'LK.2'} = 'Anuradhapura';
        $region_name{'LK.3'} = 'Badulla';
        $region_name{'LK.4'} = 'Batticaloa';
        $region_name{'LK.6'} = 'Galle';
        $region_name{'LK.7'} = 'Hambantota';
        $region_name{'LK.9'} = 'Kalutara';
        $region_name{'LK.10'} = 'Kandy';
        $region_name{'LK.11'} = 'Kegalla';
        $region_name{'LK.12'} = 'Kurunegala';
        $region_name{'LK.14'} = 'Matale';
        $region_name{'LK.15'} = 'Matara';
        $region_name{'LK.16'} = 'Moneragala';
        $region_name{'LK.17'} = 'Nuwara Eliya';
        $region_name{'LK.18'} = 'Polonnaruwa';
        $region_name{'LK.19'} = 'Puttalam';
        $region_name{'LK.20'} = 'Ratnapura';
        $region_name{'LK.21'} = 'Trincomalee';
        $region_name{'LK.23'} = 'Colombo';
        $region_name{'LK.24'} = 'Gampaha';
        $region_name{'LK.25'} = 'Jaffna';
        $region_name{'LK.26'} = 'Mannar';
        $region_name{'LK.27'} = 'Mullaittivu';
        $region_name{'LK.28'} = 'Vavuniya';
        $region_name{'LR.1'} = 'Bong';
        $region_name{'LR.2'} = 'Grand Jide';
        $region_name{'LR.4'} = 'Grand Cape Mount';
        $region_name{'LR.5'} = 'Lofa';
        $region_name{'LR.6'} = 'Maryland';
        $region_name{'LR.7'} = 'Monrovia';
        $region_name{'LR.9'} = 'Nimba';
        $region_name{'LR.10'} = 'Sino';
        $region_name{'LR.11'} = 'Grand Bassa';
        $region_name{'LR.14'} = 'Montserrado';
        $region_name{'LS.10'} = 'Berea';
        $region_name{'LS.11'} = 'Butha-Buthe';
        $region_name{'LS.12'} = 'Leribe';
        $region_name{'LS.13'} = 'Mafeteng';
        $region_name{'LS.14'} = 'Maseru';
        $region_name{'LS.15'} = 'Mohales Hoek';
        $region_name{'LS.16'} = 'Mokhotlong';
        $region_name{'LS.17'} = 'Qachas Nek';
        $region_name{'LS.18'} = 'Quthing';
        $region_name{'LS.19'} = 'Thaba-Tseka';
        $region_name{'LT.56'} = 'Alytaus Apskritis';
        $region_name{'LT.57'} = 'Kauno Apskritis';
        $region_name{'LT.58'} = 'Klaipedos Apskritis';
        $region_name{'LT.59'} = 'Marijampoles Apskritis';
        $region_name{'LT.60'} = 'Panevezio Apskritis';
        $region_name{'LT.61'} = 'Siauliu Apskritis';
        $region_name{'LT.62'} = 'Taurages Apskritis';
        $region_name{'LT.63'} = 'Telsiu Apskritis';
        $region_name{'LT.64'} = 'Utenos Apskritis';
        $region_name{'LT.65'} = 'Vilniaus Apskritis';
        $region_name{'LU.1'} = 'Diekirch';
        $region_name{'LU.2'} = 'Grevenmacher';
        $region_name{'LU.3'} = 'Luxembourg';
        $region_name{'LV.1'} = 'Aizkraukles';
        $region_name{'LV.2'} = 'Aluksnes';
        $region_name{'LV.3'} = 'Balvu';
        $region_name{'LV.4'} = 'Bauskas';
        $region_name{'LV.5'} = 'Csu';
        $region_name{'LV.6'} = 'Daugavpils';
        $region_name{'LV.7'} = 'Daugavpils';
        $region_name{'LV.8'} = 'Dobeles';
        $region_name{'LV.9'} = 'Gulbenes';
        $region_name{'LV.10'} = 'Jkabpils';
        $region_name{'LV.11'} = 'Jelgava';
        $region_name{'LV.12'} = 'Jelgavas';
        $region_name{'LV.13'} = 'Jurmala';
        $region_name{'LV.14'} = 'Krslavas';
        $region_name{'LV.15'} = 'Kuldigas';
        $region_name{'LV.16'} = 'Liepja';
        $region_name{'LV.17'} = 'Liepjas';
        $region_name{'LV.18'} = 'Limbazu';
        $region_name{'LV.19'} = 'Ludzas';
        $region_name{'LV.20'} = 'Madonas';
        $region_name{'LV.21'} = 'Ogres';
        $region_name{'LV.22'} = 'Preilu';
        $region_name{'LV.23'} = 'Rzekne';
        $region_name{'LV.24'} = 'Rzeknes';
        $region_name{'LV.25'} = 'Riga';
        $region_name{'LV.26'} = 'Rigas';
        $region_name{'LV.27'} = 'Saldus';
        $region_name{'LV.28'} = 'Talsu';
        $region_name{'LV.29'} = 'Tukuma';
        $region_name{'LV.30'} = 'Valkas';
        $region_name{'LV.31'} = 'Valmieras';
        $region_name{'LV.32'} = 'Ventspils';
        $region_name{'LV.33'} = 'Ventspils';
        $region_name{'LY.3'} = 'Al';
        $region_name{'LY.5'} = 'Al Jufrah';
        $region_name{'LY.8'} = 'Al Kufrah';
        $region_name{'LY.13'} = "Ash Shati'";
        $region_name{'LY.30'} = 'Murzuq';
        $region_name{'LY.34'} = 'Sabha';
        $region_name{'LY.41'} = 'Tarhunah';
        $region_name{'LY.42'} = 'Tubruq';
        $region_name{'LY.45'} = 'Zlitan';
        $region_name{'LY.47'} = 'Ajdabiya';
        $region_name{'LY.48'} = 'Al Fatih';
        $region_name{'LY.49'} = 'Al Jabal al Akhdar';
        $region_name{'LY.50'} = 'Al Khums';
        $region_name{'LY.51'} = 'An Nuqat al Khams';
        $region_name{'LY.52'} = 'Awbari';
        $region_name{'LY.53'} = 'Az Zawiyah';
        $region_name{'LY.54'} = 'Banghazi';
        $region_name{'LY.55'} = 'Darnah';
        $region_name{'LY.56'} = 'Ghadamis';
        $region_name{'LY.57'} = 'Gharyan';
        $region_name{'LY.58'} = 'Misratah';
        $region_name{'LY.59'} = 'Sawfajjin';
        $region_name{'LY.60'} = 'Surt';
        $region_name{'LY.61'} = 'Tarabulus';
        $region_name{'LY.62'} = 'Yafran';
        $region_name{'MA.1'} = 'Agadir';
        $region_name{'MA.2'} = 'Al Hoceima';
        $region_name{'MA.3'} = 'Azilal';
        $region_name{'MA.4'} = 'Ben Slimane';
        $region_name{'MA.5'} = 'Beni Mellal';
        $region_name{'MA.6'} = 'Boulemane';
        $region_name{'MA.7'} = 'Casablanca';
        $region_name{'MA.8'} = 'Chaouen';
        $region_name{'MA.9'} = 'El Jadida';
        $region_name{'MA.10'} = 'El Kelaa des Srarhna';
        $region_name{'MA.11'} = 'Er Rachidia';
        $region_name{'MA.12'} = 'Essaouira';
        $region_name{'MA.13'} = 'Fes';
        $region_name{'MA.14'} = 'Figuig';
        $region_name{'MA.15'} = 'Kenitra';
        $region_name{'MA.16'} = 'Khemisset';
        $region_name{'MA.17'} = 'Khenifra';
        $region_name{'MA.18'} = 'Khouribga';
        $region_name{'MA.19'} = 'Marrakech';
        $region_name{'MA.20'} = 'Meknes';
        $region_name{'MA.21'} = 'Nador';
        $region_name{'MA.22'} = 'Ouarzazate';
        $region_name{'MA.23'} = 'Oujda';
        $region_name{'MA.24'} = 'Rabat-Sale';
        $region_name{'MA.25'} = 'Safi';
        $region_name{'MA.26'} = 'Settat';
        $region_name{'MA.27'} = 'Tanger';
        $region_name{'MA.29'} = 'Tata';
        $region_name{'MA.30'} = 'Taza';
        $region_name{'MA.32'} = 'Tiznit';
        $region_name{'MA.33'} = 'Guelmim';
        $region_name{'MA.34'} = 'Ifrane';
        $region_name{'MA.35'} = 'Laayoune';
        $region_name{'MA.36'} = 'Tan-Tan';
        $region_name{'MA.37'} = 'Taounate';
        $region_name{'MA.38'} = 'Sidi Kacem';
        $region_name{'MA.39'} = 'Taroudannt';
        $region_name{'MA.40'} = 'Tetouan';
        $region_name{'MA.41'} = 'Larache';
        $region_name{'MC.1'} = 'La Condamine';
        $region_name{'MC.2'} = 'Monaco';
        $region_name{'MC.3'} = 'Monte-Carlo';
        $region_name{'MD.46'} = 'Balti';
        $region_name{'MD.47'} = 'Cahul';
        $region_name{'MD.48'} = 'Chisinau';
        $region_name{'MD.49'} = 'Stinga Nistrului';
        $region_name{'MD.50'} = 'Edinet';
        $region_name{'MD.51'} = 'Gagauzia';
        $region_name{'MD.52'} = 'Lapusna';
        $region_name{'MD.53'} = 'Orhei';
        $region_name{'MD.54'} = 'Soroca';
        $region_name{'MD.55'} = 'Tighina';
        $region_name{'MD.56'} = 'Ungheni';
        $region_name{'MG.1'} = 'Antsiranana';
        $region_name{'MG.2'} = 'Fianarantsoa';
        $region_name{'MG.3'} = 'Mahajanga';
        $region_name{'MG.4'} = 'Toamasina';
        $region_name{'MG.5'} = 'Antananarivo';
        $region_name{'MG.6'} = 'Toliara';
        $region_name{'MK.1'} = 'Aracinovo';
        $region_name{'MK.2'} = 'Bac';
        $region_name{'MK.3'} = 'Belcista';
        $region_name{'MK.4'} = 'Berovo';
        $region_name{'MK.5'} = 'Bistrica';
        $region_name{'MK.6'} = 'Bitola';
        $region_name{'MK.7'} = 'Blatec';
        $region_name{'MK.8'} = 'Bogdanci';
        $region_name{'MK.9'} = 'Bogomila';
        $region_name{'MK.10'} = 'Bogovinje';
        $region_name{'MK.11'} = 'Bosilovo';
        $region_name{'MK.12'} = 'Brvenica';
        $region_name{'MK.13'} = 'Cair';
        $region_name{'MK.14'} = 'Capari';
        $region_name{'MK.15'} = 'Caska';
        $region_name{'MK.16'} = 'Cegrane';
        $region_name{'MK.17'} = 'Centar';
        $region_name{'MK.18'} = 'Centar Zupa';
        $region_name{'MK.19'} = 'Cesinovo';
        $region_name{'MK.20'} = 'Cucer-Sandevo';
        $region_name{'MK.21'} = 'Debar';
        $region_name{'MK.22'} = 'Delcevo';
        $region_name{'MK.23'} = 'Delogozdi';
        $region_name{'MK.24'} = 'Demir Hisar';
        $region_name{'MK.25'} = 'Demir Kapija';
        $region_name{'MK.26'} = 'Dobrusevo';
        $region_name{'MK.27'} = 'Dolna Banjica';
        $region_name{'MK.28'} = 'Dolneni';
        $region_name{'MK.29'} = 'Dorce Petrov';
        $region_name{'MK.30'} = 'Drugovo';
        $region_name{'MK.31'} = 'Dzepciste';
        $region_name{'MK.32'} = 'Gazi Baba';
        $region_name{'MK.33'} = 'Gevgelija';
        $region_name{'MK.34'} = 'Gostivar';
        $region_name{'MK.35'} = 'Gradsko';
        $region_name{'MK.36'} = 'Ilinden';
        $region_name{'MK.37'} = 'Izvor';
        $region_name{'MK.38'} = 'Jegunovce';
        $region_name{'MK.39'} = 'Kamenjane';
        $region_name{'MK.40'} = 'Karbinci';
        $region_name{'MK.41'} = 'Karpos';
        $region_name{'MK.42'} = 'Kavadarci';
        $region_name{'MK.43'} = 'Kicevo';
        $region_name{'MK.44'} = 'Kisela Voda';
        $region_name{'MK.45'} = 'Klecevce';
        $region_name{'MK.46'} = 'Kocani';
        $region_name{'MK.47'} = 'Konce';
        $region_name{'MK.48'} = 'Kondovo';
        $region_name{'MK.49'} = 'Konopiste';
        $region_name{'MK.50'} = 'Kosel';
        $region_name{'MK.51'} = 'Kratovo';
        $region_name{'MK.52'} = 'Kriva Palanka';
        $region_name{'MK.53'} = 'Krivogastani';
        $region_name{'MK.54'} = 'Krusevo';
        $region_name{'MK.55'} = 'Kuklis';
        $region_name{'MK.56'} = 'Kukurecani';
        $region_name{'MK.57'} = 'Kumanovo';
        $region_name{'MK.58'} = 'Labunista';
        $region_name{'MK.59'} = 'Lipkovo';
        $region_name{'MK.60'} = 'Lozovo';
        $region_name{'MK.61'} = 'Lukovo';
        $region_name{'MK.62'} = 'Makedonska Kamenica';
        $region_name{'MK.63'} = 'Makedonski Brod';
        $region_name{'MK.64'} = 'Mavrovi Anovi';
        $region_name{'MK.65'} = 'Meseista';
        $region_name{'MK.66'} = 'Miravci';
        $region_name{'MK.67'} = 'Mogila';
        $region_name{'MK.68'} = 'Murtino';
        $region_name{'MK.69'} = 'Negotino';
        $region_name{'MK.70'} = 'Negotino-Polosko';
        $region_name{'MK.71'} = 'Novaci';
        $region_name{'MK.72'} = 'Novo Selo';
        $region_name{'MK.73'} = 'Oblesevo';
        $region_name{'MK.74'} = 'Ohrid';
        $region_name{'MK.75'} = 'Orasac';
        $region_name{'MK.76'} = 'Orizari';
        $region_name{'MK.77'} = 'Oslomej';
        $region_name{'MK.78'} = 'Pehcevo';
        $region_name{'MK.79'} = 'Petrovec';
        $region_name{'MK.80'} = 'Plasnica';
        $region_name{'MK.81'} = 'Podares';
        $region_name{'MK.82'} = 'Prilep';
        $region_name{'MK.83'} = 'Probistip';
        $region_name{'MK.84'} = 'Radovis';
        $region_name{'MK.85'} = 'Rankovce';
        $region_name{'MK.86'} = 'Resen';
        $region_name{'MK.87'} = 'Rosoman';
        $region_name{'MK.88'} = 'Rostusa';
        $region_name{'MK.89'} = 'Samokov';
        $region_name{'MK.90'} = 'Saraj';
        $region_name{'MK.91'} = 'Sipkovica';
        $region_name{'MK.92'} = 'Sopiste';
        $region_name{'MK.93'} = 'Sopotnica';
        $region_name{'MK.94'} = 'Srbinovo';
        $region_name{'MK.95'} = 'Staravina';
        $region_name{'MK.96'} = 'Star Dojran';
        $region_name{'MK.97'} = 'Staro Nagoricane';
        $region_name{'MK.98'} = 'Stip';
        $region_name{'MK.99'} = 'Struga';
        $region_name{'MK.101'} = 'Strumica';
        $region_name{'MK.102'} = 'Studenicani';
        $region_name{'MK.103'} = 'Suto Orizari';
        $region_name{'MK.104'} = 'Sveti Nikole';
        $region_name{'MK.105'} = 'Tearce';
        $region_name{'MK.106'} = 'Tetovo';
        $region_name{'MK.107'} = 'Topolcani';
        $region_name{'MK.108'} = 'Valandovo';
        $region_name{'MK.109'} = 'Vasilevo';
        $region_name{'MK.111'} = 'Veles';
        $region_name{'MK.112'} = 'Velesta';
        $region_name{'MK.113'} = 'Vevcani';
        $region_name{'MK.114'} = 'Vinica';
        $region_name{'MK.115'} = 'Vitoliste';
        $region_name{'MK.116'} = 'Vranestica';
        $region_name{'MK.117'} = 'Vrapciste';
        $region_name{'MK.118'} = 'Vratnica';
        $region_name{'MK.119'} = 'Vrutok';
        $region_name{'MK.121'} = 'Zajas';
        $region_name{'MK.122'} = 'Zelenikovo';
        $region_name{'MK.123'} = 'Zelino';
        $region_name{'MK.124'} = 'Zitose';
        $region_name{'MK.125'} = 'Zletovo';
        $region_name{'MK.126'} = 'Zrnovci';
        $region_name{'ML.1'} = 'Bamako';
        $region_name{'ML.3'} = 'Kayes';
        $region_name{'ML.4'} = 'Mopti';
        $region_name{'ML.5'} = 'Segou';
        $region_name{'ML.6'} = 'Sikasso';
        $region_name{'ML.7'} = 'Koulikoro';
        $region_name{'ML.8'} = 'Tombouctou';
        $region_name{'ML.9'} = 'Gao';
        $region_name{'ML.10'} = 'Kidal';
        $region_name{'MM.1'} = 'Rakhine State';
        $region_name{'MM.2'} = 'Chin State';
        $region_name{'MM.3'} = 'Irrawaddy';
        $region_name{'MM.4'} = 'Kachin State';
        $region_name{'MM.5'} = 'Karan State';
        $region_name{'MM.6'} = 'Kayah State';
        $region_name{'MM.7'} = 'Magwe';
        $region_name{'MM.8'} = 'Mandalay';
        $region_name{'MM.9'} = 'Pegu';
        $region_name{'MM.10'} = 'Sagaing';
        $region_name{'MM.11'} = 'Shan State';
        $region_name{'MM.12'} = 'Tenasserim';
        $region_name{'MM.13'} = 'Mon State';
        $region_name{'MM.14'} = 'Rangoon';
        $region_name{'MM.17'} = 'Yangon';
        $region_name{'MN.1'} = 'Arhangay';
        $region_name{'MN.2'} = 'Bayanhongor';
        $region_name{'MN.3'} = 'Bayan-Olgiy';
        $region_name{'MN.5'} = 'Darhan';
        $region_name{'MN.6'} = 'Dornod';
        $region_name{'MN.7'} = 'Dornogovi';
        $region_name{'MN.8'} = 'Dundgovi';
        $region_name{'MN.9'} = 'Dzavhan';
        $region_name{'MN.10'} = 'Govi-Altay';
        $region_name{'MN.11'} = 'Hentiy';
        $region_name{'MN.12'} = 'Hovd';
        $region_name{'MN.13'} = 'Hovsgol';
        $region_name{'MN.14'} = 'Omnogovi';
        $region_name{'MN.15'} = 'Ovorhangay';
        $region_name{'MN.16'} = 'Selenge';
        $region_name{'MN.17'} = 'Suhbaatar';
        $region_name{'MN.18'} = 'Tov';
        $region_name{'MN.19'} = 'Uvs';
        $region_name{'MN.20'} = 'Ulaanbaatar';
        $region_name{'MN.21'} = 'Bulgan';
        $region_name{'MN.22'} = 'Erdenet';
        $region_name{'MN.23'} = 'Darhan Uul';
        $region_name{'MN.24'} = 'Govi-Sumber';
        $region_name{'MN.25'} = 'Orhon';
        $region_name{'MO.1'} = 'Ilhas';
        $region_name{'MO.2'} = 'Macau';
        $region_name{'MR.1'} = 'Hodh Ech Chargui';
        $region_name{'MR.2'} = 'Hodh El Gharbi';
        $region_name{'MR.3'} = 'Assaba';
        $region_name{'MR.4'} = 'Gorgol';
        $region_name{'MR.5'} = 'Brakna';
        $region_name{'MR.6'} = 'Trarza';
        $region_name{'MR.7'} = 'Adrar';
        $region_name{'MR.8'} = 'Dakhlet Nouadhibou';
        $region_name{'MR.9'} = 'Tagant';
        $region_name{'MR.10'} = 'Guidimaka';
        $region_name{'MR.11'} = 'Tiris Zemmour';
        $region_name{'MR.12'} = 'Inchiri';
        $region_name{'MS.1'} = 'Saint Anthony';
        $region_name{'MS.2'} = 'Saint Georges';
        $region_name{'MS.3'} = 'Saint Peter';
        $region_name{'MU.12'} = 'Black River';
        $region_name{'MU.13'} = 'Flacq';
        $region_name{'MU.14'} = 'Grand Port';
        $region_name{'MU.15'} = 'Moka';
        $region_name{'MU.16'} = 'Pamplemousses';
        $region_name{'MU.17'} = 'Plaines Wilhems';
        $region_name{'MU.18'} = 'Port Louis';
        $region_name{'MU.19'} = 'Riviere du Rempart';
        $region_name{'MU.20'} = 'Savanne';
        $region_name{'MU.21'} = 'Agalega Islands';
        $region_name{'MU.22'} = 'Cargados Carajos';
        $region_name{'MU.23'} = 'Rodrigues';
        $region_name{'MV.1'} = 'Seenu';
        $region_name{'MV.2'} = 'Aliff';
        $region_name{'MV.3'} = 'Laviyani';
        $region_name{'MV.4'} = 'Waavu';
        $region_name{'MV.5'} = 'Laamu';
        $region_name{'MV.7'} = 'Haa Aliff';
        $region_name{'MV.8'} = 'Thaa';
        $region_name{'MV.12'} = 'Meemu';
        $region_name{'MV.13'} = 'Raa';
        $region_name{'MV.14'} = 'Faafu';
        $region_name{'MV.17'} = 'Daalu';
        $region_name{'MV.20'} = 'Baa';
        $region_name{'MV.23'} = 'Haa Daalu';
        $region_name{'MV.24'} = 'Shaviyani';
        $region_name{'MV.25'} = 'Noonu';
        $region_name{'MV.26'} = 'Kaafu';
        $region_name{'MV.27'} = 'Gaafu Aliff';
        $region_name{'MV.28'} = 'Gaafu Daalu';
        $region_name{'MV.29'} = 'Naviyani';
        $region_name{'MW.2'} = 'Chikwawa';
        $region_name{'MW.3'} = 'Chiradzulu';
        $region_name{'MW.4'} = 'Chitipa';
        $region_name{'MW.5'} = 'Thyolo';
        $region_name{'MW.6'} = 'Dedza';
        $region_name{'MW.7'} = 'Dowa';
        $region_name{'MW.8'} = 'Karonga';
        $region_name{'MW.9'} = 'Kasungu';
        $region_name{'MW.11'} = 'Lilongwe';
        $region_name{'MW.12'} = 'Mangochi';
        $region_name{'MW.13'} = 'Mchinji';
        $region_name{'MW.15'} = 'Mzimba';
        $region_name{'MW.16'} = 'Ntcheu';
        $region_name{'MW.17'} = 'Nkhata Bay';
        $region_name{'MW.18'} = 'Nkhotakota';
        $region_name{'MW.19'} = 'Nsanje';
        $region_name{'MW.20'} = 'Ntchisi';
        $region_name{'MW.21'} = 'Rumphi';
        $region_name{'MW.22'} = 'Salima';
        $region_name{'MW.23'} = 'Zomba';
        $region_name{'MW.24'} = 'Blantyre';
        $region_name{'MW.25'} = 'Mwanza';
        $region_name{'MW.26'} = 'Balaka';
        $region_name{'MW.27'} = 'Likoma';
        $region_name{'MW.28'} = 'Machinga';
        $region_name{'MW.29'} = 'Mulanje';
        $region_name{'MW.30'} = 'Phalombe';
        $region_name{'MX.1'} = 'Aguascalientes';
        $region_name{'MX.2'} = 'Baja California';
        $region_name{'MX.3'} = 'Baja California Sur';
        $region_name{'MX.4'} = 'Campeche';
        $region_name{'MX.5'} = 'Chiapas';
        $region_name{'MX.6'} = 'Chihuahua';
        $region_name{'MX.7'} = 'Coahuila de Zaragoza';
        $region_name{'MX.8'} = 'Colima';
        $region_name{'MX.9'} = 'Distrito Federal';
        $region_name{'MX.10'} = 'Durango';
        $region_name{'MX.11'} = 'Guanajuato';
        $region_name{'MX.12'} = 'Guerrero';
        $region_name{'MX.13'} = 'Hidalgo';
        $region_name{'MX.14'} = 'Jalisco';
        $region_name{'MX.15'} = 'Mexico';
        $region_name{'MX.16'} = 'Michoacan de Ocampo';
        $region_name{'MX.17'} = 'Morelos';
        $region_name{'MX.18'} = 'Nayarit';
        $region_name{'MX.19'} = 'Nuevo Leon';
        $region_name{'MX.20'} = 'Oaxaca';
        $region_name{'MX.21'} = 'Puebla';
        $region_name{'MX.22'} = 'Queretaro de Arteaga';
        $region_name{'MX.23'} = 'Quintana Roo';
        $region_name{'MX.24'} = 'San Luis Potosi';
        $region_name{'MX.25'} = 'Sinaloa';
        $region_name{'MX.26'} = 'Sonora';
        $region_name{'MX.27'} = 'Tabasco';
        $region_name{'MX.28'} = 'Tamaulipas';
        $region_name{'MX.29'} = 'Tlaxcala';
        $region_name{'MX.30'} = 'Veracruz-Llave';
        $region_name{'MX.31'} = 'Yucatan';
        $region_name{'MX.32'} = 'Zacatecas';
        $region_name{'MY.1'} = 'Johor';
        $region_name{'MY.2'} = 'Kedah';
        $region_name{'MY.3'} = 'Kelantan';
        $region_name{'MY.4'} = 'Melaka';
        $region_name{'MY.5'} = 'Negeri Sembilan';
        $region_name{'MY.6'} = 'Pahang';
        $region_name{'MY.7'} = 'Perak';
        $region_name{'MY.8'} = 'Perlis';
        $region_name{'MY.9'} = 'Pulau Pinang';
        $region_name{'MY.11'} = 'Sarawak';
        $region_name{'MY.12'} = 'Selangor';
        $region_name{'MY.13'} = 'Terengganu';
        $region_name{'MY.14'} = 'Wilayah Persekutuan';
        $region_name{'MY.15'} = 'Labuan';
        $region_name{'MY.16'} = 'Sabah';
        $region_name{'MZ.1'} = 'Cabo Delgado';
        $region_name{'MZ.2'} = 'Gaza';
        $region_name{'MZ.3'} = 'Inhambane';
        $region_name{'MZ.4'} = 'Maputo';
        $region_name{'MZ.5'} = 'Sofala';
        $region_name{'MZ.6'} = 'Nampula';
        $region_name{'MZ.7'} = 'Niassa';
        $region_name{'MZ.8'} = 'Tete';
        $region_name{'MZ.9'} = 'Zambezia';
        $region_name{'MZ.10'} = 'Manica';
        $region_name{'NA.1'} = 'Bethanien';
        $region_name{'NA.2'} = 'Caprivi Oos';
        $region_name{'NA.3'} = 'Boesmanland';
        $region_name{'NA.4'} = 'Gobabis';
        $region_name{'NA.5'} = 'Grootfontein';
        $region_name{'NA.6'} = 'Kaokoland';
        $region_name{'NA.7'} = 'Karibib';
        $region_name{'NA.8'} = 'Keetmanshoop';
        $region_name{'NA.9'} = 'Luderitz';
        $region_name{'NA.10'} = 'Maltahohe';
        $region_name{'NA.11'} = 'Okahandja';
        $region_name{'NA.12'} = 'Omaruru';
        $region_name{'NA.13'} = 'Otjiwarongo';
        $region_name{'NA.14'} = 'Outjo';
        $region_name{'NA.15'} = 'Owambo';
        $region_name{'NA.16'} = 'Rehoboth';
        $region_name{'NA.17'} = 'Swakopmund';
        $region_name{'NA.18'} = 'Tsumeb';
        $region_name{'NA.20'} = 'Karasburg';
        $region_name{'NA.21'} = 'Windhoek';
        $region_name{'NA.22'} = 'Damaraland';
        $region_name{'NA.23'} = 'Hereroland Oos';
        $region_name{'NA.24'} = 'Hereroland Wes';
        $region_name{'NA.25'} = 'Kavango';
        $region_name{'NA.26'} = 'Mariental';
        $region_name{'NA.27'} = 'Namaland';
        $region_name{'NA.28'} = 'Caprivi';
        $region_name{'NA.29'} = 'Erongo';
        $region_name{'NA.30'} = 'Hardap';
        $region_name{'NA.31'} = 'Karas';
        $region_name{'NA.32'} = 'Kunene';
        $region_name{'NA.33'} = 'Ohangwena';
        $region_name{'NA.34'} = 'Okavango';
        $region_name{'NA.35'} = 'Omaheke';
        $region_name{'NA.36'} = 'Omusati';
        $region_name{'NA.37'} = 'Oshana';
        $region_name{'NA.38'} = 'Oshikoto';
        $region_name{'NA.39'} = 'Otjozondjupa';
        $region_name{'NE.1'} = 'Agadez';
        $region_name{'NE.2'} = 'Diffa';
        $region_name{'NE.3'} = 'Dosso';
        $region_name{'NE.4'} = 'Maradi';
        $region_name{'NE.5'} = 'Niamey';
        $region_name{'NE.6'} = 'Tahoua';
        $region_name{'NE.7'} = 'Zinder';
        $region_name{'NG.5'} = 'Lagos';
        $region_name{'NG.11'} = 'Abuja Capital Territory';
        $region_name{'NG.16'} = 'Ogun';
        $region_name{'NG.21'} = 'Akwa Ibom';
        $region_name{'NG.22'} = 'Cross River';
        $region_name{'NG.23'} = 'Kaduna';
        $region_name{'NG.24'} = 'Katsina';
        $region_name{'NG.25'} = 'Anambra';
        $region_name{'NG.26'} = 'Benue';
        $region_name{'NG.27'} = 'Borno';
        $region_name{'NG.28'} = 'Imo';
        $region_name{'NG.29'} = 'Kano';
        $region_name{'NG.30'} = 'Kwara';
        $region_name{'NG.31'} = 'Niger';
        $region_name{'NG.32'} = 'Oyo';
        $region_name{'NG.35'} = 'Adamawa';
        $region_name{'NG.36'} = 'Delta';
        $region_name{'NG.37'} = 'Edo';
        $region_name{'NG.39'} = 'Jigawa';
        $region_name{'NG.40'} = 'Kebbi';
        $region_name{'NG.41'} = 'Kogi';
        $region_name{'NG.42'} = 'Osun';
        $region_name{'NG.43'} = 'Taraba';
        $region_name{'NG.44'} = 'Yobe';
        $region_name{'NG.45'} = 'Abia';
        $region_name{'NG.46'} = 'Bauchi';
        $region_name{'NG.47'} = 'Enugu';
        $region_name{'NG.48'} = 'Ondo';
        $region_name{'NG.49'} = 'Plateau';
        $region_name{'NG.50'} = 'Rivers';
        $region_name{'NG.51'} = 'Sokoto';
        $region_name{'NG.52'} = 'Bayelsa';
        $region_name{'NG.53'} = 'Ebonyi';
        $region_name{'NG.54'} = 'Ekiti';
        $region_name{'NG.55'} = 'Gombe';
        $region_name{'NG.56'} = 'Nassarawa';
        $region_name{'NG.57'} = 'Zamfara';
        $region_name{'NI.1'} = 'Boaco';
        $region_name{'NI.2'} = 'Carazo';
        $region_name{'NI.3'} = 'Chinandega';
        $region_name{'NI.4'} = 'Chontales';
        $region_name{'NI.5'} = 'Esteli';
        $region_name{'NI.6'} = 'Granada';
        $region_name{'NI.7'} = 'Jinotega';
        $region_name{'NI.8'} = 'Leon';
        $region_name{'NI.9'} = 'Madriz';
        $region_name{'NI.10'} = 'Managua';
        $region_name{'NI.11'} = 'Masaya';
        $region_name{'NI.12'} = 'Matagalpa';
        $region_name{'NI.13'} = 'Nueva Segovia';
        $region_name{'NI.14'} = 'Rio San Juan';
        $region_name{'NI.15'} = 'Rivas';
        $region_name{'NI.16'} = 'Zelaya';
        $region_name{'NL.1'} = 'Drenthe';
        $region_name{'NL.2'} = 'Friesland';
        $region_name{'NL.3'} = 'Gelderland';
        $region_name{'NL.4'} = 'Groningen';
        $region_name{'NL.5'} = 'Limburg';
        $region_name{'NL.6'} = 'Noord-Brabant';
        $region_name{'NL.7'} = 'Noord-Holland';
        $region_name{'NL.8'} = 'Overijssel';
        $region_name{'NL.9'} = 'Utrecht';
        $region_name{'NL.10'} = 'Zeeland';
        $region_name{'NL.11'} = 'Zuid-Holland';
        $region_name{'NL.12'} = 'Dronten';
        $region_name{'NL.13'} = 'Zuidelijke IJsselmeerpolders';
        $region_name{'NL.14'} = 'Lelystad';
        $region_name{'NL.15'} = 'Overijssel';
        $region_name{'NL.16'} = 'Flevoland';
        $region_name{'NO.1'} = 'Akershus';
        $region_name{'NO.2'} = 'Aust-Agder';
        $region_name{'NO.4'} = 'Buskerud';
        $region_name{'NO.5'} = 'Finnmark';
        $region_name{'NO.6'} = 'Hedmark';
        $region_name{'NO.7'} = 'Hordaland';
        $region_name{'NO.8'} = 'More og Romsdal';
        $region_name{'NO.9'} = 'Nordland';
        $region_name{'NO.10'} = 'Nord-Trondelag';
        $region_name{'NO.11'} = 'Oppland';
        $region_name{'NO.12'} = 'Oslo';
        $region_name{'NO.13'} = 'Ostfold';
        $region_name{'NO.14'} = 'Rogaland';
        $region_name{'NO.15'} = 'Sogn og Fjordane';
        $region_name{'NO.16'} = 'Sor-Trondelag';
        $region_name{'NO.17'} = 'Telemark';
        $region_name{'NO.18'} = 'Troms';
        $region_name{'NO.19'} = 'Vest-Agder';
        $region_name{'NO.20'} = 'Vestfold';
        $region_name{'NP.1'} = 'Bagmati';
        $region_name{'NP.2'} = 'Bheri';
        $region_name{'NP.3'} = 'Dhawalagiri';
        $region_name{'NP.4'} = 'Gandaki';
        $region_name{'NP.5'} = 'Janakpur';
        $region_name{'NP.6'} = 'Karnali';
        $region_name{'NP.7'} = 'Kosi';
        $region_name{'NP.8'} = 'Lumbini';
        $region_name{'NP.9'} = 'Mahakali';
        $region_name{'NP.10'} = 'Mechi';
        $region_name{'NP.11'} = 'Narayani';
        $region_name{'NP.12'} = 'Rapti';
        $region_name{'NP.13'} = 'Sagarmatha';
        $region_name{'NP.14'} = 'Seti';
        $region_name{'NR.1'} = 'Aiwo';
        $region_name{'NR.2'} = 'Anabar';
        $region_name{'NR.3'} = 'Anetan';
        $region_name{'NR.4'} = 'Anibare';
        $region_name{'NR.5'} = 'Baiti';
        $region_name{'NR.6'} = 'Boe';
        $region_name{'NR.7'} = 'Buada';
        $region_name{'NR.8'} = 'Denigomodu';
        $region_name{'NR.9'} = 'Ewa';
        $region_name{'NR.10'} = 'Ijuw';
        $region_name{'NR.11'} = 'Meneng';
        $region_name{'NR.12'} = 'Nibok';
        $region_name{'NR.13'} = 'Uaboe';
        $region_name{'NR.14'} = 'Yaren';
        $region_name{'NZ.1'} = 'Akaroa';
        $region_name{'NZ.3'} = 'Amuri';
        $region_name{'NZ.4'} = 'Ashburton';
        $region_name{'NZ.7'} = 'Bay of Islands';
        $region_name{'NZ.8'} = 'Bruce';
        $region_name{'NZ.9'} = 'Buller';
        $region_name{'NZ.10'} = 'Chatham Islands';
        $region_name{'NZ.11'} = 'Cheviot';
        $region_name{'NZ.12'} = 'Clifton';
        $region_name{'NZ.13'} = 'Clutha';
        $region_name{'NZ.14'} = 'Cook';
        $region_name{'NZ.16'} = 'Dannevirke';
        $region_name{'NZ.17'} = 'Egmont';
        $region_name{'NZ.18'} = 'Eketahuna';
        $region_name{'NZ.19'} = 'Ellesmere';
        $region_name{'NZ.20'} = 'Eltham';
        $region_name{'NZ.21'} = 'Eyre';
        $region_name{'NZ.22'} = 'Featherston';
        $region_name{'NZ.24'} = 'Franklin';
        $region_name{'NZ.26'} = 'Golden Bay';
        $region_name{'NZ.27'} = 'Great Barrier Island';
        $region_name{'NZ.28'} = 'Grey';
        $region_name{'NZ.29'} = 'Hauraki Plains';
        $region_name{'NZ.30'} = 'Hawera';
        $region_name{'NZ.31'} = "Hawke's Bay";
        $region_name{'NZ.32'} = 'Heathcote';
        $region_name{'NZ.33'} = 'Hobson';
        $region_name{'NZ.34'} = 'Hokianga';
        $region_name{'NZ.35'} = 'Horowhenua';
        $region_name{'NZ.36'} = 'Hutt';
        $region_name{'NZ.37'} = 'Inangahua';
        $region_name{'NZ.38'} = 'Inglewood';
        $region_name{'NZ.39'} = 'Kaikoura';
        $region_name{'NZ.40'} = 'Kairanga';
        $region_name{'NZ.41'} = 'Kiwitea';
        $region_name{'NZ.43'} = 'Lake';
        $region_name{'NZ.45'} = 'Mackenzie';
        $region_name{'NZ.46'} = 'Malvern';
        $region_name{'NZ.47'} = 'Manawatu';
        $region_name{'NZ.48'} = 'Mangonui';
        $region_name{'NZ.49'} = 'Maniototo';
        $region_name{'NZ.50'} = 'Marlborough';
        $region_name{'NZ.51'} = 'Masterton';
        $region_name{'NZ.52'} = 'Matamata';
        $region_name{'NZ.53'} = 'Mount Herbert';
        $region_name{'NZ.54'} = 'Ohinemuri';
        $region_name{'NZ.55'} = 'Opotiki';
        $region_name{'NZ.56'} = 'Oroua';
        $region_name{'NZ.57'} = 'Otamatea';
        $region_name{'NZ.58'} = 'Otorohanga';
        $region_name{'NZ.59'} = 'Oxford';
        $region_name{'NZ.60'} = 'Pahiatua';
        $region_name{'NZ.61'} = 'Paparua';
        $region_name{'NZ.63'} = 'Patea';
        $region_name{'NZ.65'} = 'Piako';
        $region_name{'NZ.66'} = 'Pohangina';
        $region_name{'NZ.67'} = 'Raglan';
        $region_name{'NZ.68'} = 'Rangiora';
        $region_name{'NZ.69'} = 'Rangitikei';
        $region_name{'NZ.70'} = 'Rodney';
        $region_name{'NZ.71'} = 'Rotorua';
        $region_name{'NZ.72'} = 'Southland';
        $region_name{'NZ.73'} = 'Stewart Island';
        $region_name{'NZ.74'} = 'Stratford';
        $region_name{'NZ.76'} = 'Taranaki';
        $region_name{'NZ.77'} = 'Taumarunui';
        $region_name{'NZ.78'} = 'Taupo';
        $region_name{'NZ.79'} = 'Tauranga';
        $region_name{'NZ.81'} = 'Tuapeka';
        $region_name{'NZ.82'} = 'Vincent';
        $region_name{'NZ.83'} = 'Waiapu';
        $region_name{'NZ.84'} = 'Waihemo';
        $region_name{'NZ.85'} = 'Waikato';
        $region_name{'NZ.86'} = 'Waikohu';
        $region_name{'NZ.88'} = 'Waimairi';
        $region_name{'NZ.89'} = 'Waimarino';
        $region_name{'NZ.90'} = 'Waimate';
        $region_name{'NZ.91'} = 'Waimate West';
        $region_name{'NZ.92'} = 'Waimea';
        $region_name{'NZ.93'} = 'Waipa';
        $region_name{'NZ.95'} = 'Waipawa';
        $region_name{'NZ.96'} = 'Waipukurau';
        $region_name{'NZ.97'} = 'Wairarapa South';
        $region_name{'NZ.98'} = 'Wairewa';
        $region_name{'NZ.99'} = 'Wairoa';
        $region_name{'NZ.101'} = 'Whangarei';
        $region_name{'NZ.102'} = 'Whangaroa';
        $region_name{'NZ.103'} = 'Woodville';
        $region_name{'NZ.104'} = 'Waitaki';
        $region_name{'NZ.106'} = 'Waitomo';
        $region_name{'NZ.108'} = 'Waitotara';
        $region_name{'NZ.112'} = 'Wanganui';
        $region_name{'NZ.113'} = 'Westland';
        $region_name{'NZ.114'} = 'Whakatane';
        $region_name{'NZ.134'} = 'Hurunui';
        $region_name{'NZ.135'} = 'Silverpeaks';
        $region_name{'NZ.136'} = 'Strathallan';
        $region_name{'NZ.138'} = 'Waiheke';
        $region_name{'NZ.139'} = 'Hikurangi';
        $region_name{'NZ.141'} = 'Manaia';
        $region_name{'NZ.142'} = 'Runanga';
        $region_name{'NZ.143'} = 'Saint Kilda';
        $region_name{'NZ.144'} = 'Thames-Coromandel';
        $region_name{'NZ.145'} = 'Waverley';
        $region_name{'NZ.146'} = 'Wallace';
        $region_name{'OM.1'} = 'Ad Dakhiliyah';
        $region_name{'OM.2'} = 'Al Batinah';
        $region_name{'OM.3'} = 'Al Wusta';
        $region_name{'OM.4'} = 'Ash Sharqiyah';
        $region_name{'OM.5'} = 'Az Zahirah';
        $region_name{'OM.6'} = 'Masqat';
        $region_name{'OM.7'} = 'Musandam';
        $region_name{'OM.8'} = 'Zufar';
        $region_name{'PA.1'} = 'Bocas del Toro';
        $region_name{'PA.2'} = 'Chiriqui';
        $region_name{'PA.3'} = 'Cocle';
        $region_name{'PA.4'} = 'Colon';
        $region_name{'PA.5'} = 'Darien';
        $region_name{'PA.6'} = 'Herrera';
        $region_name{'PA.7'} = 'Los Santos';
        $region_name{'PA.8'} = 'Panama';
        $region_name{'PA.9'} = 'San Blas';
        $region_name{'PA.10'} = 'Veraguas';
        $region_name{'PE.1'} = 'Amazonas';
        $region_name{'PE.2'} = 'Ancash';
        $region_name{'PE.3'} = 'Apurimac';
        $region_name{'PE.4'} = 'Arequipa';
        $region_name{'PE.5'} = 'Ayacucho';
        $region_name{'PE.6'} = 'Cajamarca';
        $region_name{'PE.7'} = 'Callao';
        $region_name{'PE.8'} = 'Cusco';
        $region_name{'PE.9'} = 'Huancavelica';
        $region_name{'PE.10'} = 'Huanuco';
        $region_name{'PE.11'} = 'Ica';
        $region_name{'PE.12'} = 'Junin';
        $region_name{'PE.13'} = 'La Libertad';
        $region_name{'PE.14'} = 'Lambayeque';
        $region_name{'PE.15'} = 'Lima';
        $region_name{'PE.16'} = 'Loreto';
        $region_name{'PE.17'} = 'Madre de Dios';
        $region_name{'PE.18'} = 'Moquegua';
        $region_name{'PE.19'} = 'Pasco';
        $region_name{'PE.20'} = 'Piura';
        $region_name{'PE.21'} = 'Puno';
        $region_name{'PE.22'} = 'San Martin';
        $region_name{'PE.23'} = 'Tacna';
        $region_name{'PE.24'} = 'Tumbes';
        $region_name{'PE.25'} = 'Ucayali';
        $region_name{'PG.1'} = 'Central';
        $region_name{'PG.2'} = 'Gulf';
        $region_name{'PG.3'} = 'Milne Bay';
        $region_name{'PG.4'} = 'Northern';
        $region_name{'PG.5'} = 'Southern Highlands';
        $region_name{'PG.6'} = 'Western';
        $region_name{'PG.7'} = 'North Solomons';
        $region_name{'PG.8'} = 'Chimbu';
        $region_name{'PG.9'} = 'Eastern Highlands';
        $region_name{'PG.10'} = 'East New Britain';
        $region_name{'PG.11'} = 'East Sepik';
        $region_name{'PG.12'} = 'Madang';
        $region_name{'PG.13'} = 'Manus';
        $region_name{'PG.14'} = 'Morobe';
        $region_name{'PG.15'} = 'New Ireland';
        $region_name{'PG.16'} = 'Western Highlands';
        $region_name{'PG.17'} = 'West New Britain';
        $region_name{'PG.18'} = 'Sandaun';
        $region_name{'PG.19'} = 'Enga';
        $region_name{'PG.20'} = 'National Capital';
        $region_name{'PH.1'} = 'Abra';
        $region_name{'PH.2'} = 'Agusan del Norte';
        $region_name{'PH.3'} = 'Agusan del Sur';
        $region_name{'PH.4'} = 'Aklan';
        $region_name{'PH.5'} = 'Albay';
        $region_name{'PH.6'} = 'Antique';
        $region_name{'PH.7'} = 'Bataan';
        $region_name{'PH.8'} = 'Batanes';
        $region_name{'PH.9'} = 'Batangas';
        $region_name{'PH.10'} = 'Benguet';
        $region_name{'PH.11'} = 'Bohol';
        $region_name{'PH.12'} = 'Bukidnon';
        $region_name{'PH.13'} = 'Bulacan';
        $region_name{'PH.14'} = 'Cagayan';
        $region_name{'PH.15'} = 'Camarines Norte';
        $region_name{'PH.16'} = 'Camarines Sur';
        $region_name{'PH.17'} = 'Camiguin';
        $region_name{'PH.18'} = 'Capiz';
        $region_name{'PH.19'} = 'Catanduanes';
        $region_name{'PH.20'} = 'Cavite';
        $region_name{'PH.21'} = 'Cebu';
        $region_name{'PH.22'} = 'Basilan';
        $region_name{'PH.23'} = 'Eastern Samar';
        $region_name{'PH.24'} = 'Davao';
        $region_name{'PH.25'} = 'Davao del Sur';
        $region_name{'PH.26'} = 'Davao Oriental';
        $region_name{'PH.27'} = 'Ifugao';
        $region_name{'PH.28'} = 'Ilocos Norte';
        $region_name{'PH.29'} = 'Ilocos Sur';
        $region_name{'PH.30'} = 'Iloilo';
        $region_name{'PH.31'} = 'Isabela';
        $region_name{'PH.32'} = 'Kalinga-Apayao';
        $region_name{'PH.33'} = 'Laguna';
        $region_name{'PH.34'} = 'Lanao del Norte';
        $region_name{'PH.35'} = 'Lanao del Sur';
        $region_name{'PH.36'} = 'La Union';
        $region_name{'PH.37'} = 'Leyte';
        $region_name{'PH.38'} = 'Marinduque';
        $region_name{'PH.39'} = 'Masbate';
        $region_name{'PH.40'} = 'Mindoro Occidental';
        $region_name{'PH.41'} = 'Mindoro Oriental';
        $region_name{'PH.42'} = 'Misamis Occidental';
        $region_name{'PH.43'} = 'Misamis Oriental';
        $region_name{'PH.44'} = 'Mountain';
        $region_name{'PH.46'} = 'Negros Oriental';
        $region_name{'PH.47'} = 'Nueva Ecija';
        $region_name{'PH.48'} = 'Nueva Vizcaya';
        $region_name{'PH.49'} = 'Palawan';
        $region_name{'PH.50'} = 'Pampanga';
        $region_name{'PH.51'} = 'Pangasinan';
        $region_name{'PH.53'} = 'Rizal';
        $region_name{'PH.54'} = 'Romblon';
        $region_name{'PH.55'} = 'Samar';
        $region_name{'PH.56'} = 'Maguindanao';
        $region_name{'PH.57'} = 'North Cotabato';
        $region_name{'PH.58'} = 'Sorsogon';
        $region_name{'PH.59'} = 'Southern Leyte';
        $region_name{'PH.60'} = 'Sulu';
        $region_name{'PH.61'} = 'Surigao del Norte';
        $region_name{'PH.62'} = 'Surigao del Sur';
        $region_name{'PH.63'} = 'Tarlac';
        $region_name{'PH.64'} = 'Zambales';
        $region_name{'PH.65'} = 'Zamboanga del Norte';
        $region_name{'PH.66'} = 'Zamboanga del Sur';
        $region_name{'PH.67'} = 'Northern Samar';
        $region_name{'PH.68'} = 'Quirino';
        $region_name{'PH.69'} = 'Siquijor';
        $region_name{'PH.70'} = 'South Cotabato';
        $region_name{'PH.71'} = 'Sultan Kudarat';
        $region_name{'PH.72'} = 'Tawitawi';
        $region_name{'PH.101'} = 'Angeles';
        $region_name{'PH.102'} = 'Bacolod';
        $region_name{'PH.103'} = 'Bago';
        $region_name{'PH.104'} = 'Baguio';
        $region_name{'PH.105'} = 'Bais';
        $region_name{'PH.106'} = 'Basilan City';
        $region_name{'PH.107'} = 'Batangas City';
        $region_name{'PH.108'} = 'Butuan';
        $region_name{'PH.109'} = 'Cabanatuan';
        $region_name{'PH.111'} = 'Cadiz';
        $region_name{'PH.112'} = 'Cagayan de Oro';
        $region_name{'PH.113'} = 'Calbayog';
        $region_name{'PH.114'} = 'Caloocan';
        $region_name{'PH.115'} = 'Canlaon';
        $region_name{'PH.116'} = 'Cavite City';
        $region_name{'PH.117'} = 'Cebu City';
        $region_name{'PH.118'} = 'Cotabato';
        $region_name{'PH.119'} = 'Dagupan';
        $region_name{'PH.121'} = 'Danao';
        $region_name{'PH.122'} = 'Dapitan';
        $region_name{'PH.123'} = 'Davao City';
        $region_name{'PH.124'} = 'Dipolog';
        $region_name{'PH.125'} = 'Dumaguete';
        $region_name{'PH.126'} = 'General Santos';
        $region_name{'PH.127'} = 'Gingoog';
        $region_name{'PH.128'} = 'Iligan';
        $region_name{'PH.129'} = 'Iloilo City';
        $region_name{'PH.131'} = 'Iriga';
        $region_name{'PH.132'} = 'La Carlota';
        $region_name{'PH.133'} = 'Laoag';
        $region_name{'PH.134'} = 'Lapu-Lapu';
        $region_name{'PH.135'} = 'Legaspi';
        $region_name{'PH.136'} = 'Lipa';
        $region_name{'PH.137'} = 'Lucena';
        $region_name{'PH.138'} = 'Mandaue';
        $region_name{'PH.139'} = 'Manila';
        $region_name{'PH.141'} = 'Marawi';
        $region_name{'PH.142'} = 'Naga';
        $region_name{'PH.143'} = 'Olongapo';
        $region_name{'PH.144'} = 'Ormoc';
        $region_name{'PH.145'} = 'Oroquieta';
        $region_name{'PH.146'} = 'Ozamis';
        $region_name{'PH.147'} = 'Pagadian';
        $region_name{'PH.148'} = 'Palayan';
        $region_name{'PH.149'} = 'Pasay';
        $region_name{'PH.151'} = 'Puerto Princesa';
        $region_name{'PH.152'} = 'Quezon City';
        $region_name{'PH.153'} = 'Roxas';
        $region_name{'PH.154'} = 'San Carlos';
        $region_name{'PH.155'} = 'San Carlos';
        $region_name{'PH.156'} = 'San Jose';
        $region_name{'PH.157'} = 'San Pablo';
        $region_name{'PH.158'} = 'Silay';
        $region_name{'PH.159'} = 'Surigao';
        $region_name{'PH.161'} = 'Tacloban';
        $region_name{'PH.162'} = 'Tagaytay';
        $region_name{'PH.163'} = 'Tagbilaran';
        $region_name{'PH.164'} = 'Tangub';
        $region_name{'PH.165'} = 'Toledo';
        $region_name{'PH.166'} = 'Trece Martires';
        $region_name{'PH.167'} = 'Zamboanga';
        $region_name{'PH.168'} = 'Aurora';
        $region_name{'PH.172'} = 'Quezon';
        $region_name{'PH.173'} = 'Negros Occidental';
        $region_name{'PK.1'} = 'Federally Administered Tribal Areas';
        $region_name{'PK.2'} = 'Balochistan';
        $region_name{'PK.3'} = 'North-West Frontier';
        $region_name{'PK.4'} = 'Punjab';
        $region_name{'PK.5'} = 'Sindh';
        $region_name{'PK.6'} = 'Azad Kashmir';
        $region_name{'PK.7'} = 'Northern Areas';
        $region_name{'PK.8'} = 'Islamabad';
        $region_name{'PL.23'} = 'Biala Podlaska';
        $region_name{'PL.24'} = 'Bialystok';
        $region_name{'PL.25'} = 'Bielsko';
        $region_name{'PL.26'} = 'Bydgoszcz';
        $region_name{'PL.27'} = 'Chelm';
        $region_name{'PL.28'} = 'Ciechanow';
        $region_name{'PL.29'} = 'Czestochowa';
        $region_name{'PL.30'} = 'Elblag';
        $region_name{'PL.31'} = 'Gdansk';
        $region_name{'PL.32'} = 'Gorzow';
        $region_name{'PL.33'} = 'Jelenia Gora';
        $region_name{'PL.34'} = 'Kalisz';
        $region_name{'PL.35'} = 'Katowice';
        $region_name{'PL.36'} = 'Kielce';
        $region_name{'PL.37'} = 'Konin';
        $region_name{'PL.38'} = 'Koszalin';
        $region_name{'PL.39'} = 'Krakow';
        $region_name{'PL.40'} = 'Krosno';
        $region_name{'PL.41'} = 'Legnica';
        $region_name{'PL.42'} = 'Leszno';
        $region_name{'PL.43'} = 'Lodz';
        $region_name{'PL.44'} = 'Lomza';
        $region_name{'PL.45'} = 'Lublin';
        $region_name{'PL.46'} = 'Nowy Sacz';
        $region_name{'PL.47'} = 'Olsztyn';
        $region_name{'PL.48'} = 'Opole';
        $region_name{'PL.49'} = 'Ostroleka';
        $region_name{'PL.50'} = 'Pila';
        $region_name{'PL.51'} = 'Piotrkow';
        $region_name{'PL.52'} = 'Plock';
        $region_name{'PL.53'} = 'Poznan';
        $region_name{'PL.54'} = 'Przemysl';
        $region_name{'PL.55'} = 'Radom';
        $region_name{'PL.56'} = 'Rzeszow';
        $region_name{'PL.57'} = 'Siedlce';
        $region_name{'PL.58'} = 'Sieradz';
        $region_name{'PL.59'} = 'Skierniewice';
        $region_name{'PL.60'} = 'Slupsk';
        $region_name{'PL.61'} = 'Suwalki';
        $region_name{'PL.62'} = 'Szczecin';
        $region_name{'PL.63'} = 'Tarnobrzeg';
        $region_name{'PL.64'} = 'Tarnow';
        $region_name{'PL.65'} = 'Torun';
        $region_name{'PL.66'} = 'Walbrzych';
        $region_name{'PL.67'} = 'Warszawa';
        $region_name{'PL.68'} = 'Wloclawek';
        $region_name{'PL.69'} = 'Wroclaw';
        $region_name{'PL.70'} = 'Zamosc';
        $region_name{'PL.71'} = 'Zielona Gora';
        $region_name{'PL.72'} = 'Dolnoslaskie';
        $region_name{'PL.73'} = 'Kujawsko-Pomorskie';
        $region_name{'PL.74'} = 'Lodzkie';
        $region_name{'PL.75'} = 'Lubelskie';
        $region_name{'PL.76'} = 'Lubuskie';
        $region_name{'PL.77'} = 'Malopolskie';
        $region_name{'PL.78'} = 'Mazowieckie';
        $region_name{'PL.79'} = 'Opolskie';
        $region_name{'PL.80'} = 'Podkarpackie';
        $region_name{'PL.81'} = 'Podlaskie';
        $region_name{'PL.82'} = 'Pomorskie';
        $region_name{'PL.83'} = 'Slaskie';
        $region_name{'PL.84'} = 'Swietokrzyskie';
        $region_name{'PL.85'} = 'Warminsko-Mazurskie';
        $region_name{'PL.86'} = 'Wielkopolskie';
        $region_name{'PL.87'} = 'Zachodniopomorskie';
        $region_name{'PT.2'} = 'Aveiro';
        $region_name{'PT.3'} = 'Beja';
        $region_name{'PT.4'} = 'Braga';
        $region_name{'PT.5'} = 'Braganca';
        $region_name{'PT.6'} = 'Castelo Branco';
        $region_name{'PT.7'} = 'Coimbra';
        $region_name{'PT.8'} = 'Evora';
        $region_name{'PT.9'} = 'Faro';
        $region_name{'PT.10'} = 'Madeira';
        $region_name{'PT.11'} = 'Guarda';
        $region_name{'PT.13'} = 'Leiria';
        $region_name{'PT.14'} = 'Lisboa';
        $region_name{'PT.16'} = 'Portalegre';
        $region_name{'PT.17'} = 'Porto';
        $region_name{'PT.18'} = 'Santarem';
        $region_name{'PT.19'} = 'Setubal';
        $region_name{'PT.20'} = 'Viana do Castelo';
        $region_name{'PT.21'} = 'Vila Real';
        $region_name{'PT.22'} = 'Viseu';
        $region_name{'PT.23'} = 'Azores';
        $region_name{'PY.1'} = 'Alto Parana';
        $region_name{'PY.2'} = 'Amambay';
        $region_name{'PY.3'} = 'Boqueron';
        $region_name{'PY.4'} = 'Caaguazu';
        $region_name{'PY.5'} = 'Caazapa';
        $region_name{'PY.6'} = 'Central';
        $region_name{'PY.7'} = 'Concepcion';
        $region_name{'PY.8'} = 'Cordillera';
        $region_name{'PY.10'} = 'Guaira';
        $region_name{'PY.11'} = 'Itapua';
        $region_name{'PY.12'} = 'Misiones';
        $region_name{'PY.13'} = 'Neembucu';
        $region_name{'PY.15'} = 'Paraguari';
        $region_name{'PY.16'} = 'Presidente Hayes';
        $region_name{'PY.17'} = 'San Pedro';
        $region_name{'PY.19'} = 'Canindeyu';
        $region_name{'PY.20'} = 'Chaco';
        $region_name{'PY.21'} = 'Nueva Asuncion';
        $region_name{'PY.23'} = 'Alto Paraguay';
        $region_name{'QA.1'} = 'Ad Dawhah';
        $region_name{'QA.2'} = 'Al Ghuwariyah';
        $region_name{'QA.3'} = 'Al Jumaliyah';
        $region_name{'QA.4'} = 'Al Khawr';
        $region_name{'QA.6'} = 'Ar Rayyan';
        $region_name{'QA.8'} = 'Madinat ach Shamal';
        $region_name{'QA.9'} = 'Umm Salal';
        $region_name{'QA.10'} = 'Al Wakrah';
        $region_name{'QA.11'} = 'Jariyan al Batnah';
        $region_name{'QA.12'} = "Umm Sa'id";
        $region_name{'RO.1'} = 'Alba';
        $region_name{'RO.2'} = 'Arad';
        $region_name{'RO.3'} = 'Arges';
        $region_name{'RO.4'} = 'Bacau';
        $region_name{'RO.5'} = 'Bihor';
        $region_name{'RO.6'} = 'Bistrita-Nasaud';
        $region_name{'RO.7'} = 'Botosani';
        $region_name{'RO.8'} = 'Braila';
        $region_name{'RO.9'} = 'Brasov';
        $region_name{'RO.10'} = 'Bucuresti';
        $region_name{'RO.11'} = 'Buzau';
        $region_name{'RO.12'} = 'Caras-Severin';
        $region_name{'RO.13'} = 'Cluj';
        $region_name{'RO.14'} = 'Constanta';
        $region_name{'RO.15'} = 'Covasna';
        $region_name{'RO.16'} = 'Dambovita';
        $region_name{'RO.17'} = 'Dolj';
        $region_name{'RO.18'} = 'Galati';
        $region_name{'RO.19'} = 'Gorj';
        $region_name{'RO.20'} = 'Harghita';
        $region_name{'RO.21'} = 'Hunedoara';
        $region_name{'RO.22'} = 'Ialomita';
        $region_name{'RO.23'} = 'Iasi';
        $region_name{'RO.25'} = 'Maramures';
        $region_name{'RO.26'} = 'Mehedinti';
        $region_name{'RO.27'} = 'Mures';
        $region_name{'RO.28'} = 'Neamt';
        $region_name{'RO.29'} = 'Olt';
        $region_name{'RO.30'} = 'Prahova';
        $region_name{'RO.31'} = 'Salaj';
        $region_name{'RO.32'} = 'Satu Mare';
        $region_name{'RO.33'} = 'Sibiu';
        $region_name{'RO.34'} = 'Suceava';
        $region_name{'RO.35'} = 'Teleorman';
        $region_name{'RO.36'} = 'Timis';
        $region_name{'RO.37'} = 'Tulcea';
        $region_name{'RO.38'} = 'Vaslui';
        $region_name{'RO.39'} = 'Valcea';
        $region_name{'RO.40'} = 'Vrancea';
        $region_name{'RO.41'} = 'Calarasi';
        $region_name{'RO.42'} = 'Giurgiu';
        $region_name{'RO.43'} = 'Ilfov';
        $region_name{'RU.1'} = 'Adygeya';
        $region_name{'RU.2'} = 'Aginsky Buryatsky AO';
        $region_name{'RU.3'} = 'Gorno-Altay';
        $region_name{'RU.4'} = 'Altaisky krai';
        $region_name{'RU.5'} = 'Amur';
        $region_name{'RU.6'} = "Arkhangel'sk";
        $region_name{'RU.7'} = "Astrakhan'";
        $region_name{'RU.8'} = 'Bashkortostan';
        $region_name{'RU.9'} = 'Belgorod';
        $region_name{'RU.10'} = 'Bryansk';
        $region_name{'RU.11'} = 'Buryat';
        $region_name{'RU.12'} = 'Chechnya';
        $region_name{'RU.13'} = 'Chelyabinsk';
        $region_name{'RU.14'} = 'Chita';
        $region_name{'RU.15'} = 'Chukot';
        $region_name{'RU.16'} = 'Chuvashia';
        $region_name{'RU.17'} = 'Dagestan';
        $region_name{'RU.18'} = 'Evenk';
        $region_name{'RU.19'} = 'Ingush';
        $region_name{'RU.20'} = 'Irkutsk';
        $region_name{'RU.21'} = 'Ivanovo';
        $region_name{'RU.22'} = 'Kabardin-Balkar';
        $region_name{'RU.23'} = 'Kaliningrad';
        $region_name{'RU.24'} = 'Kalmyk';
        $region_name{'RU.25'} = 'Kaluga';
        $region_name{'RU.26'} = 'Kamchatka';
        $region_name{'RU.27'} = 'Karachay-Cherkess';
        $region_name{'RU.28'} = 'Karelia';
        $region_name{'RU.29'} = 'Kemerovo';
        $region_name{'RU.30'} = 'Khabarovsk';
        $region_name{'RU.31'} = 'Khakass';
        $region_name{'RU.32'} = 'Khanty-Mansiy';
        $region_name{'RU.33'} = 'Kirov';
        $region_name{'RU.34'} = 'Komi';
        $region_name{'RU.35'} = 'Komi-Permyak';
        $region_name{'RU.36'} = 'Koryak';
        $region_name{'RU.37'} = 'Kostroma';
        $region_name{'RU.38'} = 'Krasnodar';
        $region_name{'RU.39'} = 'Krasnoyarsk';
        $region_name{'RU.40'} = 'Kurgan';
        $region_name{'RU.41'} = 'Kursk';
        $region_name{'RU.42'} = 'Leningrad';
        $region_name{'RU.43'} = 'Lipetsk';
        $region_name{'RU.44'} = 'Magadan';
        $region_name{'RU.45'} = 'Mariy-El';
        $region_name{'RU.46'} = 'Mordovia';
        $region_name{'RU.47'} = 'Moskva';
        $region_name{'RU.48'} = 'Moscow City';
        $region_name{'RU.49'} = 'Murmansk';
        $region_name{'RU.50'} = 'Nenets';
        $region_name{'RU.51'} = 'Nizhegorod';
        $region_name{'RU.52'} = 'Novgorod';
        $region_name{'RU.53'} = 'Novosibirsk';
        $region_name{'RU.54'} = 'Omsk';
        $region_name{'RU.55'} = 'Orenburg';
        $region_name{'RU.56'} = 'Orel';
        $region_name{'RU.57'} = 'Penza';
        $region_name{'RU.58'} = "Perm'";
        $region_name{'RU.59'} = "Primor'ye";
        $region_name{'RU.60'} = 'Pskov';
        $region_name{'RU.61'} = 'Rostov';
        $region_name{'RU.62'} = "Ryazan'";
        $region_name{'RU.63'} = 'Sakha';
        $region_name{'RU.64'} = 'Sakhalin';
        $region_name{'RU.65'} = 'Samara';
        $region_name{'RU.66'} = 'Saint Petersburg City';
        $region_name{'RU.67'} = 'Saratov';
        $region_name{'RU.68'} = 'North Ossetia';
        $region_name{'RU.69'} = 'Smolensk';
        $region_name{'RU.70'} = "Stavropol'";
        $region_name{'RU.71'} = 'Sverdlovsk';
        $region_name{'RU.72'} = 'Tambovskaya oblast';
        $region_name{'RU.73'} = 'Tatarstan';
        $region_name{'RU.74'} = 'Taymyr';
        $region_name{'RU.75'} = 'Tomsk';
        $region_name{'RU.76'} = 'Tula';
        $region_name{'RU.77'} = "Tver'";
        $region_name{'RU.78'} = "Tyumen'";
        $region_name{'RU.79'} = 'Tuva';
        $region_name{'RU.80'} = 'Udmurt';
        $region_name{'RU.81'} = "Ul'yanovsk";
        $region_name{'RU.82'} = 'Ust-Orda Buryat';
        $region_name{'RU.83'} = 'Vladimir';
        $region_name{'RU.84'} = 'Volgograd';
        $region_name{'RU.85'} = 'Vologda';
        $region_name{'RU.86'} = 'Voronezh';
        $region_name{'RU.87'} = 'Yamal-Nenets';
        $region_name{'RU.88'} = "Yaroslavl'";
        $region_name{'RU.89'} = 'Yevrey';
        $region_name{'RW.1'} = 'Butare';
        $region_name{'RW.2'} = 'Byumba';
        $region_name{'RW.3'} = 'Cyangugu';
        $region_name{'RW.4'} = 'Gikongoro';
        $region_name{'RW.5'} = 'Gisenyi';
        $region_name{'RW.6'} = 'Gitarama';
        $region_name{'RW.7'} = 'Kibungo';
        $region_name{'RW.8'} = 'Kibuye';
        $region_name{'RW.9'} = 'Kigali';
        $region_name{'RW.10'} = 'Ruhengeri';
        $region_name{'SA.2'} = 'Al Bahah';
        $region_name{'SA.3'} = 'Al Jawf';
        $region_name{'SA.5'} = 'Al Madinah';
        $region_name{'SA.6'} = 'Ash Sharqiyah';
        $region_name{'SA.8'} = 'Al Qasim';
        $region_name{'SA.9'} = 'Al Qurayyat';
        $region_name{'SA.10'} = 'Ar Riyad';
        $region_name{'SA.13'} = "Ha'il";
        $region_name{'SA.14'} = 'Makkah';
        $region_name{'SA.15'} = 'Al Hudud ash Shamaliyah';
        $region_name{'SA.16'} = 'Najran';
        $region_name{'SA.17'} = 'Jizan';
        $region_name{'SA.19'} = 'Tabuk';
        $region_name{'SA.20'} = 'Al Jawf';
        $region_name{'SB.3'} = 'Malaita';
        $region_name{'SB.4'} = 'Western';
        $region_name{'SB.5'} = 'Central';
        $region_name{'SB.6'} = 'Guadalcanal';
        $region_name{'SB.7'} = 'Isabel';
        $region_name{'SB.8'} = 'Makira';
        $region_name{'SB.9'} = 'Temotu';
        $region_name{'SC.1'} = 'Anse aux Pins';
        $region_name{'SC.2'} = 'Anse Boileau';
        $region_name{'SC.3'} = 'Anse Etoile';
        $region_name{'SC.4'} = 'Anse Louis';
        $region_name{'SC.5'} = 'Anse Royale';
        $region_name{'SC.6'} = 'Baie Lazare';
        $region_name{'SC.7'} = 'Baie Sainte Anne';
        $region_name{'SC.8'} = 'Beau Vallon';
        $region_name{'SC.9'} = 'Bel Air';
        $region_name{'SC.10'} = 'Bel Ombre';
        $region_name{'SC.11'} = 'Cascade';
        $region_name{'SC.12'} = 'Glacis';
        $region_name{'SC.13'} = "Grand' Anse";
        $region_name{'SC.14'} = "Grand' Anse";
        $region_name{'SC.15'} = 'La Digue';
        $region_name{'SC.16'} = 'La Riviere Anglaise';
        $region_name{'SC.17'} = 'Mont Buxton';
        $region_name{'SC.18'} = 'Mont Fleuri';
        $region_name{'SC.19'} = 'Plaisance';
        $region_name{'SC.20'} = 'Pointe La Rue';
        $region_name{'SC.21'} = 'Port Glaud';
        $region_name{'SC.22'} = 'Saint Louis';
        $region_name{'SC.23'} = 'Takamaka';
        $region_name{'SD.27'} = 'Al Wusta';
        $region_name{'SD.28'} = "Al Istiwa'iyah";
        $region_name{'SD.29'} = 'Al Khartum';
        $region_name{'SD.30'} = 'Ash Shamaliyah';
        $region_name{'SD.31'} = 'Ash Sharqiyah';
        $region_name{'SD.32'} = 'Bahr al Ghazal';
        $region_name{'SD.33'} = 'Darfur';
        $region_name{'SD.34'} = 'Kurdufan';
        $region_name{'SE.1'} = 'Alvsborgs Lan';
        $region_name{'SE.2'} = 'Blekinge Lan';
        $region_name{'SE.3'} = 'Gavleborgs Lan';
        $region_name{'SE.4'} = 'Goteborgs och Bohus Lan';
        $region_name{'SE.5'} = 'Gotlands Lan';
        $region_name{'SE.6'} = 'Hallands Lan';
        $region_name{'SE.7'} = 'Jamtlands Lan';
        $region_name{'SE.8'} = 'Jonkopings Lan';
        $region_name{'SE.9'} = 'Kalmar Lan';
        $region_name{'SE.10'} = 'Dalarnas Lan';
        $region_name{'SE.11'} = 'Kristianstads Lan';
        $region_name{'SE.12'} = 'Kronobergs Lan';
        $region_name{'SE.13'} = 'Malmohus Lan';
        $region_name{'SE.14'} = 'Norrbottens Lan';
        $region_name{'SE.15'} = 'Orebro Lan';
        $region_name{'SE.16'} = 'Ostergotlands Lan';
        $region_name{'SE.17'} = 'Skaraborgs Lan';
        $region_name{'SE.18'} = 'Sodermanlands Lan';
        $region_name{'SE.21'} = 'Uppsala Lan';
        $region_name{'SE.22'} = 'Varmlands Lan';
        $region_name{'SE.23'} = 'Vasterbottens Lan';
        $region_name{'SE.24'} = 'Vasternorrlands Lan';
        $region_name{'SE.25'} = 'Vastmanlands Lan';
        $region_name{'SE.26'} = 'Stockholms Lan';
        $region_name{'SE.27'} = 'Skane Lan';
        $region_name{'SE.28'} = 'Vastra Gotaland';
        $region_name{'SH.1'} = 'Ascension';
        $region_name{'SH.2'} = 'Saint Helena';
        $region_name{'SH.3'} = 'Tristan da Cunha';
        $region_name{'SI.1'} = 'Ajdovscina';
        $region_name{'SI.2'} = 'Beltinci';
        $region_name{'SI.3'} = 'Bled';
        $region_name{'SI.4'} = 'Bohinj';
        $region_name{'SI.5'} = 'Borovnica';
        $region_name{'SI.6'} = 'Bovec';
        $region_name{'SI.7'} = 'Brda';
        $region_name{'SI.8'} = 'Brezice';
        $region_name{'SI.9'} = 'Brezovica';
        $region_name{'SI.11'} = 'Celje';
        $region_name{'SI.12'} = 'Cerklje na Gorenjskem';
        $region_name{'SI.13'} = 'Cerknica';
        $region_name{'SI.14'} = 'Cerkno';
        $region_name{'SI.15'} = 'Crensovci';
        $region_name{'SI.16'} = 'Crna na Koroskem';
        $region_name{'SI.17'} = 'Crnomelj';
        $region_name{'SI.19'} = 'Divaca';
        $region_name{'SI.20'} = 'Dobrepolje';
        $region_name{'SI.22'} = 'Dol pri Ljubljani';
        $region_name{'SI.24'} = 'Dornava';
        $region_name{'SI.25'} = 'Dravograd';
        $region_name{'SI.26'} = 'Duplek';
        $region_name{'SI.27'} = 'Gorenja Vas-Poljane';
        $region_name{'SI.28'} = 'Gorisnica';
        $region_name{'SI.29'} = 'Gornja Radgona';
        $region_name{'SI.30'} = 'Gornji Grad';
        $region_name{'SI.31'} = 'Gornji Petrovci';
        $region_name{'SI.32'} = 'Grosuplje';
        $region_name{'SI.34'} = 'Hrastnik';
        $region_name{'SI.35'} = 'Hrpelje-Kozina';
        $region_name{'SI.36'} = 'Idrija';
        $region_name{'SI.37'} = 'Ig';
        $region_name{'SI.38'} = 'Ilirska Bistrica';
        $region_name{'SI.39'} = 'Ivancna Gorica';
        $region_name{'SI.40'} = 'Izola-Isola';
        $region_name{'SI.42'} = 'Jursinci';
        $region_name{'SI.44'} = 'Kanal';
        $region_name{'SI.45'} = 'Kidricevo';
        $region_name{'SI.46'} = 'Kobarid';
        $region_name{'SI.47'} = 'Kobilje';
        $region_name{'SI.49'} = 'Komen';
        $region_name{'SI.50'} = 'Koper-Capodistria';
        $region_name{'SI.51'} = 'Kozje';
        $region_name{'SI.52'} = 'Kranj';
        $region_name{'SI.53'} = 'Kranjska Gora';
        $region_name{'SI.54'} = 'Krsko';
        $region_name{'SI.55'} = 'Kungota';
        $region_name{'SI.57'} = 'Lasko';
        $region_name{'SI.61'} = 'Ljubljana';
        $region_name{'SI.62'} = 'Ljubno';
        $region_name{'SI.64'} = 'Logatec';
        $region_name{'SI.66'} = 'Loski Potok';
        $region_name{'SI.68'} = 'Lukovica';
        $region_name{'SI.71'} = 'Medvode';
        $region_name{'SI.72'} = 'Menges';
        $region_name{'SI.73'} = 'Metlika';
        $region_name{'SI.74'} = 'Mezica';
        $region_name{'SI.76'} = 'Mislinja';
        $region_name{'SI.77'} = 'Moravce';
        $region_name{'SI.78'} = 'Moravske Toplice';
        $region_name{'SI.79'} = 'Mozirje';
        $region_name{'SI.80'} = 'Murska Sobota';
        $region_name{'SI.81'} = 'Muta';
        $region_name{'SI.82'} = 'Naklo';
        $region_name{'SI.83'} = 'Nazarje';
        $region_name{'SI.84'} = 'Nova Gorica';
        $region_name{'SI.86'} = 'Odranci';
        $region_name{'SI.87'} = 'Ormoz';
        $region_name{'SI.88'} = 'Osilnica';
        $region_name{'SI.89'} = 'Pesnica';
        $region_name{'SI.91'} = 'Pivka';
        $region_name{'SI.92'} = 'Podcetrtek';
        $region_name{'SI.94'} = 'Postojna';
        $region_name{'SI.97'} = 'Puconci';
        $region_name{'SI.98'} = 'Racam';
        $region_name{'SI.99'} = 'Radece';
        $region_name{'SI.101'} = 'Radenci';
        $region_name{'SI.102'} = 'Radlje ob Dravi';
        $region_name{'SI.103'} = 'Radovljica';
        $region_name{'SI.106'} = 'Rogasovci';
        $region_name{'SI.107'} = 'Rogaska Slatina';
        $region_name{'SI.108'} = 'Rogatec';
        $region_name{'SI.111'} = 'Semic';
        $region_name{'SI.112'} = 'Sencur';
        $region_name{'SI.113'} = 'Sentilj';
        $region_name{'SI.114'} = 'Sentjernej';
        $region_name{'SI.116'} = 'Sevnica';
        $region_name{'SI.117'} = 'Sezana';
        $region_name{'SI.118'} = 'Skocjan';
        $region_name{'SI.119'} = 'Skofja Loka';
        $region_name{'SI.121'} = 'Skofljica';
        $region_name{'SI.122'} = 'Slovenj Gradec';
        $region_name{'SI.124'} = 'Slovenske Konjice';
        $region_name{'SI.125'} = 'Smarje pri Jelsah';
        $region_name{'SI.126'} = 'Smartno ob Paki';
        $region_name{'SI.127'} = 'Sostanj';
        $region_name{'SI.128'} = 'Starse';
        $region_name{'SI.129'} = 'Store';
        $region_name{'SI.131'} = 'Sveti Jurij';
        $region_name{'SI.132'} = 'Tolmin';
        $region_name{'SI.133'} = 'Trbovlje';
        $region_name{'SI.134'} = 'Trebnje';
        $region_name{'SI.135'} = 'Trzic';
        $region_name{'SI.136'} = 'Turnisce';
        $region_name{'SI.137'} = 'Velenje';
        $region_name{'SI.138'} = 'Velike Lasce';
        $region_name{'SI.141'} = 'Vipava';
        $region_name{'SI.142'} = 'Vitanje';
        $region_name{'SI.143'} = 'Vodice';
        $region_name{'SI.145'} = 'Vrhnika';
        $region_name{'SI.146'} = 'Vuzenica';
        $region_name{'SI.147'} = 'Zagorje ob Savi';
        $region_name{'SI.149'} = 'Zavrc';
        $region_name{'SI.151'} = 'Zelezniki';
        $region_name{'SI.152'} = 'Ziri';
        $region_name{'SI.153'} = 'Zrece';
        $region_name{'SI.164'} = 'Dobrova-Horjul-Polhov Gradec';
        $region_name{'SI.167'} = 'Domzale';
        $region_name{'SI.174'} = 'Jesenice';
        $region_name{'SI.176'} = 'Kamnik';
        $region_name{'SI.177'} = 'Kocevje';
        $region_name{'SI.182'} = 'Kuzma';
        $region_name{'SI.183'} = 'Lenart';
        $region_name{'SI.185'} = 'Litija';
        $region_name{'SI.186'} = 'Ljutomer';
        $region_name{'SI.187'} = 'Loska Dolina';
        $region_name{'SI.189'} = 'Luce';
        $region_name{'SI.191'} = 'Majsperk';
        $region_name{'SI.192'} = 'Maribor';
        $region_name{'SI.195'} = 'Miren-Kostanjevica';
        $region_name{'SI.197'} = 'Novo Mesto';
        $region_name{'SI.199'} = 'Piran';
        $region_name{'SI.205'} = 'Preddvor';
        $region_name{'SI.207'} = 'Ptuj';
        $region_name{'SI.211'} = 'Ribnica';
        $region_name{'SI.213'} = 'Ruse';
        $region_name{'SI.217'} = 'Sentjur pri Celju';
        $region_name{'SI.218'} = 'Slovenska Bistrica';
        $region_name{'SI.232'} = 'Videm';
        $region_name{'SI.233'} = 'Vojnik';
        $region_name{'SI.235'} = 'Zalec';
        $region_name{'SK.1'} = 'Banska Bystrica';
        $region_name{'SK.2'} = 'Bratislava';
        $region_name{'SK.3'} = 'Kosice';
        $region_name{'SK.4'} = 'Nitra';
        $region_name{'SK.5'} = 'Presov';
        $region_name{'SK.6'} = 'Trencin';
        $region_name{'SK.7'} = 'Trnava';
        $region_name{'SK.8'} = 'Zilina';
        $region_name{'SL.1'} = 'Eastern';
        $region_name{'SL.2'} = 'Northern';
        $region_name{'SL.3'} = 'Southern';
        $region_name{'SL.4'} = 'Western Area';
        $region_name{'SM.1'} = 'Acquaviva';
        $region_name{'SM.2'} = 'Chiesanuova';
        $region_name{'SM.3'} = 'Domagnano';
        $region_name{'SM.4'} = 'Faetano';
        $region_name{'SM.5'} = 'Fiorentino';
        $region_name{'SM.6'} = 'Borgo Maggiore';
        $region_name{'SM.7'} = 'San Marino';
        $region_name{'SM.8'} = 'Monte Giardino';
        $region_name{'SM.9'} = 'Serravalle';
        $region_name{'SN.1'} = 'Dakar';
        $region_name{'SN.3'} = 'Diourbel';
        $region_name{'SN.4'} = 'Saint-Louis';
        $region_name{'SN.5'} = 'Tambacounda';
        $region_name{'SN.7'} = 'Thies';
        $region_name{'SN.8'} = 'Louga';
        $region_name{'SN.9'} = 'Fatick';
        $region_name{'SN.10'} = 'Kaolack';
        $region_name{'SN.11'} = 'Kolda';
        $region_name{'SN.12'} = 'Ziguinchor';
        $region_name{'SO.1'} = 'Bakool';
        $region_name{'SO.2'} = 'Banaadir';
        $region_name{'SO.3'} = 'Bari';
        $region_name{'SO.4'} = 'Bay';
        $region_name{'SO.5'} = 'Galguduud';
        $region_name{'SO.6'} = 'Gedo';
        $region_name{'SO.7'} = 'Hiiraan';
        $region_name{'SO.8'} = 'Jubbada Dhexe';
        $region_name{'SO.9'} = 'Jubbada Hoose';
        $region_name{'SO.10'} = 'Mudug';
        $region_name{'SO.11'} = 'Nugaal';
        $region_name{'SO.12'} = 'Sanaag';
        $region_name{'SO.13'} = 'Shabeellaha Dhexe';
        $region_name{'SO.14'} = 'Shabeellaha Hoose';
        $region_name{'SO.15'} = 'Togdheer';
        $region_name{'SO.16'} = 'Woqooyi Galbeed';
        $region_name{'SR.10'} = 'Brokopondo';
        $region_name{'SR.11'} = 'Commewijne';
        $region_name{'SR.12'} = 'Coronie';
        $region_name{'SR.13'} = 'Marowijne';
        $region_name{'SR.14'} = 'Nickerie';
        $region_name{'SR.15'} = 'Para';
        $region_name{'SR.16'} = 'Paramaribo';
        $region_name{'SR.17'} = 'Saramacca';
        $region_name{'SR.18'} = 'Sipaliwini';
        $region_name{'SR.19'} = 'Wanica';
        $region_name{'ST.1'} = 'Principe';
        $region_name{'ST.2'} = 'Sao Tome';
        $region_name{'SV.1'} = 'Ahuachapan';
        $region_name{'SV.2'} = 'Cabanas';
        $region_name{'SV.3'} = 'Chalatenango';
        $region_name{'SV.4'} = 'Cuscatlan';
        $region_name{'SV.5'} = 'La Libertad';
        $region_name{'SV.6'} = 'La Paz';
        $region_name{'SV.7'} = 'La Union';
        $region_name{'SV.8'} = 'Morazan';
        $region_name{'SV.9'} = 'San Miguel';
        $region_name{'SV.10'} = 'San Salvador';
        $region_name{'SV.11'} = 'Santa Ana';
        $region_name{'SV.12'} = 'San Vicente';
        $region_name{'SV.13'} = 'Sonsonate';
        $region_name{'SV.14'} = 'Usulutan';
        $region_name{'SY.1'} = 'Al Hasakah';
        $region_name{'SY.2'} = 'Al Ladhiqiyah';
        $region_name{'SY.3'} = 'Al Qunaytirah';
        $region_name{'SY.4'} = 'Ar Raqqah';
        $region_name{'SY.5'} = "As Suwayda'";
        $region_name{'SY.6'} = 'Dar';
        $region_name{'SY.7'} = 'Dayr az Zawr';
        $region_name{'SY.8'} = 'Rif Dimashq';
        $region_name{'SY.9'} = 'Halab';
        $region_name{'SY.10'} = 'Hamah';
        $region_name{'SY.11'} = 'Hims';
        $region_name{'SY.12'} = 'Idlib';
        $region_name{'SY.13'} = 'Dimashq';
        $region_name{'SY.14'} = 'Tartus';
        $region_name{'SZ.1'} = 'Hhohho';
        $region_name{'SZ.2'} = 'Lubombo';
        $region_name{'SZ.3'} = 'Manzini';
        $region_name{'SZ.4'} = 'Shiselweni';
        $region_name{'SZ.5'} = 'Praslin';
        $region_name{'TD.1'} = 'Batha';
        $region_name{'TD.2'} = 'Biltine';
        $region_name{'TD.3'} = 'Borkou-Ennedi-Tibesti';
        $region_name{'TD.4'} = 'Chari-Baguirmi';
        $region_name{'TD.5'} = 'Guera';
        $region_name{'TD.6'} = 'Kanem';
        $region_name{'TD.7'} = 'Lac';
        $region_name{'TD.8'} = 'Logone Occidental';
        $region_name{'TD.9'} = 'Logone Oriental';
        $region_name{'TD.10'} = 'Mayo-Kebbi';
        $region_name{'TD.11'} = 'Moyen-Chari';
        $region_name{'TD.12'} = 'Ouaddai';
        $region_name{'TD.13'} = 'Salamat';
        $region_name{'TD.14'} = 'Tandjile';
        $region_name{'TG.1'} = 'Amlame';
        $region_name{'TG.2'} = 'Aneho';
        $region_name{'TG.3'} = 'Atakpame';
        $region_name{'TG.4'} = 'Bafilo';
        $region_name{'TG.5'} = 'Bassar';
        $region_name{'TG.6'} = 'Dapaong';
        $region_name{'TG.7'} = 'Kante';
        $region_name{'TG.8'} = 'Klouto';
        $region_name{'TG.9'} = 'Lama-Kara';
        $region_name{'TG.10'} = 'Lome';
        $region_name{'TG.11'} = 'Mango';
        $region_name{'TG.12'} = 'Niamtougou';
        $region_name{'TG.13'} = 'Notse';
        $region_name{'TG.14'} = 'Kpagouda';
        $region_name{'TG.15'} = 'Badou';
        $region_name{'TG.16'} = 'Sotouboua';
        $region_name{'TG.17'} = 'Tabligbo';
        $region_name{'TG.18'} = 'Tsevie';
        $region_name{'TG.19'} = 'Tchamba';
        $region_name{'TG.20'} = 'Tchaoudjo';
        $region_name{'TG.21'} = 'Vogan';
        $region_name{'TH.1'} = 'Mae Hong Son';
        $region_name{'TH.2'} = 'Chiang Mai';
        $region_name{'TH.3'} = 'Chiang Rai';
        $region_name{'TH.4'} = 'Nan';
        $region_name{'TH.5'} = 'Lamphun';
        $region_name{'TH.6'} = 'Lampang';
        $region_name{'TH.7'} = 'Phrae';
        $region_name{'TH.8'} = 'Tak';
        $region_name{'TH.9'} = 'Sukhothai';
        $region_name{'TH.10'} = 'Uttaradit';
        $region_name{'TH.11'} = 'Kamphaeng Phet';
        $region_name{'TH.12'} = 'Phitsanulok';
        $region_name{'TH.13'} = 'Phichit';
        $region_name{'TH.14'} = 'Phetchabun';
        $region_name{'TH.15'} = 'Uthai Thani';
        $region_name{'TH.16'} = 'Nakhon Sawan';
        $region_name{'TH.17'} = 'Nong Khai';
        $region_name{'TH.18'} = 'Loei';
        $region_name{'TH.20'} = 'Sakon Nakhon';
        $region_name{'TH.21'} = 'Nakhon Phanom';
        $region_name{'TH.22'} = 'Khon Kaen';
        $region_name{'TH.23'} = 'Kalasin';
        $region_name{'TH.24'} = 'Maha Sarakham';
        $region_name{'TH.25'} = 'Roi Et';
        $region_name{'TH.26'} = 'Chaiyaphum';
        $region_name{'TH.27'} = 'Nakhon Ratchasima';
        $region_name{'TH.28'} = 'Buriram';
        $region_name{'TH.29'} = 'Surin';
        $region_name{'TH.30'} = 'Sisaket';
        $region_name{'TH.31'} = 'Narathiwat';
        $region_name{'TH.32'} = 'Chai Nat';
        $region_name{'TH.33'} = 'Sing Buri';
        $region_name{'TH.34'} = 'Lop Buri';
        $region_name{'TH.35'} = 'Ang Thong';
        $region_name{'TH.36'} = 'Phra Nakhon Si Ayutthaya';
        $region_name{'TH.37'} = 'Saraburi';
        $region_name{'TH.38'} = 'Nonthaburi';
        $region_name{'TH.39'} = 'Pathum Thani';
        $region_name{'TH.40'} = 'Krung Thep';
        $region_name{'TH.41'} = 'Phayao';
        $region_name{'TH.42'} = 'Samut Prakan';
        $region_name{'TH.43'} = 'Nakhon Nayok';
        $region_name{'TH.44'} = 'Chachoengsao';
        $region_name{'TH.45'} = 'Prachin Buri';
        $region_name{'TH.46'} = 'Chon Buri';
        $region_name{'TH.47'} = 'Rayong';
        $region_name{'TH.48'} = 'Chanthaburi';
        $region_name{'TH.49'} = 'Trat';
        $region_name{'TH.50'} = 'Kanchanaburi';
        $region_name{'TH.51'} = 'Suphan Buri';
        $region_name{'TH.52'} = 'Ratchaburi';
        $region_name{'TH.53'} = 'Nakhon Pathom';
        $region_name{'TH.54'} = 'Samut Songkhram';
        $region_name{'TH.55'} = 'Samut Sakhon';
        $region_name{'TH.56'} = 'Phetchaburi';
        $region_name{'TH.57'} = 'Prachuap Khiri Khan';
        $region_name{'TH.58'} = 'Chumphon';
        $region_name{'TH.59'} = 'Ranong';
        $region_name{'TH.60'} = 'Surat Thani';
        $region_name{'TH.61'} = 'Phangnga';
        $region_name{'TH.62'} = 'Phuket';
        $region_name{'TH.63'} = 'Krabi';
        $region_name{'TH.64'} = 'Nakhon Si Thammarat';
        $region_name{'TH.65'} = 'Trang';
        $region_name{'TH.66'} = 'Phatthalung';
        $region_name{'TH.67'} = 'Satun';
        $region_name{'TH.68'} = 'Songkhla';
        $region_name{'TH.69'} = 'Pattani';
        $region_name{'TH.70'} = 'Yala';
        $region_name{'TH.72'} = 'Yasothon';
        $region_name{'TH.75'} = 'Ubon Ratchathani';
        $region_name{'TH.76'} = 'Udon Thani';
        $region_name{'TH.78'} = 'Mukdahan';
        $region_name{'TJ.1'} = 'Kuhistoni Badakhshon';
        $region_name{'TJ.2'} = 'Khatlon';
        $region_name{'TJ.3'} = 'Sughd';
        $region_name{'TM.1'} = 'Ahal';
        $region_name{'TM.2'} = 'Balkan';
        $region_name{'TM.3'} = 'Dashoguz';
        $region_name{'TM.4'} = 'Lebap';
        $region_name{'TM.5'} = 'Mary';
        $region_name{'TN.2'} = 'Al Qasrayn';
        $region_name{'TN.3'} = 'Al Qayrawan';
        $region_name{'TN.6'} = 'Jundubah';
        $region_name{'TN.10'} = 'Qafsah';
        $region_name{'TN.14'} = 'Kef';
        $region_name{'TN.15'} = 'Al Mahdiyah';
        $region_name{'TN.16'} = 'Al Munastir';
        $region_name{'TN.17'} = 'Bajah';
        $region_name{'TN.18'} = 'Banzart';
        $region_name{'TN.19'} = 'Nabul';
        $region_name{'TN.22'} = 'Silyanah';
        $region_name{'TN.23'} = 'Susah';
        $region_name{'TN.27'} = 'Bin';
        $region_name{'TN.28'} = 'Madanin';
        $region_name{'TN.29'} = 'Qabis';
        $region_name{'TN.31'} = 'Qibili';
        $region_name{'TN.32'} = 'Safaqis';
        $region_name{'TN.33'} = 'Sidi Bu Zayd';
        $region_name{'TN.34'} = 'Tatawin';
        $region_name{'TN.35'} = 'Tawzar';
        $region_name{'TN.36'} = 'Tunis';
        $region_name{'TN.37'} = 'Zaghwan';
        $region_name{'TN.38'} = 'Ariana';
        $region_name{'TN.39'} = 'Manouba';
        $region_name{'TO.1'} = 'Ha';
        $region_name{'TO.2'} = 'Tongatapu';
        $region_name{'TO.3'} = 'Vava';
        $region_name{'TR.2'} = 'Adiyaman';
        $region_name{'TR.3'} = 'Afyon';
        $region_name{'TR.4'} = 'Agri';
        $region_name{'TR.5'} = 'Amasya';
        $region_name{'TR.7'} = 'Antalya';
        $region_name{'TR.8'} = 'Artvin';
        $region_name{'TR.9'} = 'Aydin';
        $region_name{'TR.10'} = 'Balikesir';
        $region_name{'TR.11'} = 'Bilecik';
        $region_name{'TR.12'} = 'Bingol';
        $region_name{'TR.13'} = 'Bitlis';
        $region_name{'TR.14'} = 'Bolu';
        $region_name{'TR.15'} = 'Burdur';
        $region_name{'TR.16'} = 'Bursa';
        $region_name{'TR.17'} = 'Canakkale';
        $region_name{'TR.19'} = 'Corum';
        $region_name{'TR.20'} = 'Denizli';
        $region_name{'TR.21'} = 'Diyarbakir';
        $region_name{'TR.22'} = 'Edirne';
        $region_name{'TR.23'} = 'Elazig';
        $region_name{'TR.24'} = 'Erzincan';
        $region_name{'TR.25'} = 'Erzurum';
        $region_name{'TR.26'} = 'Eskisehir';
        $region_name{'TR.28'} = 'Giresun';
        $region_name{'TR.31'} = 'Hatay';
        $region_name{'TR.32'} = 'Icel';
        $region_name{'TR.33'} = 'Isparta';
        $region_name{'TR.34'} = 'Istanbul';
        $region_name{'TR.35'} = 'Izmir';
        $region_name{'TR.37'} = 'Kastamonu';
        $region_name{'TR.38'} = 'Kayseri';
        $region_name{'TR.39'} = 'Kirklareli';
        $region_name{'TR.40'} = 'Kirsehir';
        $region_name{'TR.41'} = 'Kocaeli';
        $region_name{'TR.43'} = 'Kutahya';
        $region_name{'TR.44'} = 'Malatya';
        $region_name{'TR.45'} = 'Manisa';
        $region_name{'TR.46'} = 'Kahramanmaras';
        $region_name{'TR.48'} = 'Mugla';
        $region_name{'TR.49'} = 'Mus';
        $region_name{'TR.50'} = 'Nevsehir';
        $region_name{'TR.52'} = 'Ordu';
        $region_name{'TR.53'} = 'Rize';
        $region_name{'TR.54'} = 'Sakarya';
        $region_name{'TR.55'} = 'Samsun';
        $region_name{'TR.57'} = 'Sinop';
        $region_name{'TR.58'} = 'Sivas';
        $region_name{'TR.59'} = 'Tekirdag';
        $region_name{'TR.60'} = 'Tokat';
        $region_name{'TR.61'} = 'Trabzon';
        $region_name{'TR.62'} = 'Tunceli';
        $region_name{'TR.63'} = 'Sanliurfa';
        $region_name{'TR.64'} = 'Usak';
        $region_name{'TR.65'} = 'Van';
        $region_name{'TR.66'} = 'Yozgat';
        $region_name{'TR.68'} = 'Ankara';
        $region_name{'TR.69'} = 'Gumushane';
        $region_name{'TR.70'} = 'Hakkari';
        $region_name{'TR.71'} = 'Konya';
        $region_name{'TR.72'} = 'Mardin';
        $region_name{'TR.73'} = 'Nigde';
        $region_name{'TR.74'} = 'Siirt';
        $region_name{'TR.75'} = 'Aksaray';
        $region_name{'TR.76'} = 'Batman';
        $region_name{'TR.77'} = 'Bayburt';
        $region_name{'TR.78'} = 'Karaman';
        $region_name{'TR.79'} = 'Kirikkale';
        $region_name{'TR.80'} = 'Sirnak';
        $region_name{'TR.81'} = 'Adana';
        $region_name{'TR.82'} = 'Cankiri';
        $region_name{'TR.83'} = 'Gaziantep';
        $region_name{'TR.84'} = 'Kars';
        $region_name{'TR.85'} = 'Zonguldak';
        $region_name{'TR.86'} = 'Ardahan';
        $region_name{'TR.87'} = 'Bartin';
        $region_name{'TR.88'} = 'Igdir';
        $region_name{'TR.89'} = 'Karabuk';
        $region_name{'TR.90'} = 'Kilis';
        $region_name{'TR.91'} = 'Osmaniye';
        $region_name{'TR.92'} = 'Yalova';
        $region_name{'TR.93'} = 'Duzce';
        $region_name{'TT.1'} = 'Arima';
        $region_name{'TT.2'} = 'Caroni';
        $region_name{'TT.3'} = 'Mayaro';
        $region_name{'TT.4'} = 'Nariva';
        $region_name{'TT.5'} = 'Port-of-Spain';
        $region_name{'TT.6'} = 'Saint Andrew';
        $region_name{'TT.7'} = 'Saint David';
        $region_name{'TT.8'} = 'Saint George';
        $region_name{'TT.9'} = 'Saint Patrick';
        $region_name{'TT.10'} = 'San Fernando';
        $region_name{'TT.11'} = 'Tobago';
        $region_name{'TT.12'} = 'Victoria';
        $region_name{'TW.1'} = 'Fu-chien';
        $region_name{'TW.2'} = 'Kao-hsiung';
        $region_name{'TW.3'} = "T'ai-pei";
        $region_name{'TW.4'} = "T'ai-wan";
        $region_name{'TZ.1'} = 'Arusha';
        $region_name{'TZ.2'} = 'Pwani';
        $region_name{'TZ.3'} = 'Dodoma';
        $region_name{'TZ.4'} = 'Iringa';
        $region_name{'TZ.5'} = 'Kigoma';
        $region_name{'TZ.6'} = 'Kilimanjaro';
        $region_name{'TZ.7'} = 'Lindi';
        $region_name{'TZ.8'} = 'Mara';
        $region_name{'TZ.9'} = 'Mbeya';
        $region_name{'TZ.10'} = 'Morogoro';
        $region_name{'TZ.11'} = 'Mtwara';
        $region_name{'TZ.12'} = 'Mwanza';
        $region_name{'TZ.13'} = 'Pemba North';
        $region_name{'TZ.14'} = 'Ruvuma';
        $region_name{'TZ.15'} = 'Shinyanga';
        $region_name{'TZ.16'} = 'Singida';
        $region_name{'TZ.17'} = 'Tabora';
        $region_name{'TZ.18'} = 'Tanga';
        $region_name{'TZ.19'} = 'Kagera';
        $region_name{'TZ.20'} = 'Pemba South';
        $region_name{'TZ.21'} = 'Zanzibar Central';
        $region_name{'TZ.22'} = 'Zanzibar North';
        $region_name{'TZ.23'} = 'Dar es Salaam';
        $region_name{'TZ.24'} = 'Rukwa';
        $region_name{'TZ.25'} = 'Zanzibar Urban';
        $region_name{'UA.1'} = "Cherkas'ka Oblast'";
        $region_name{'UA.2'} = "Chernihivs'ka Oblast'";
        $region_name{'UA.3'} = "Chernivets'ka Oblast'";
        $region_name{'UA.4'} = "Dnipropetrovs'ka Oblast'";
        $region_name{'UA.5'} = "Donets'ka Oblast'";
        $region_name{'UA.6'} = "Ivano-Frankivs'ka Oblast'";
        $region_name{'UA.7'} = "Kharkivs'ka Oblast'";
        $region_name{'UA.8'} = "Khersons'ka Oblast'";
        $region_name{'UA.9'} = "Khmel'nyts'ka Oblast'";
        $region_name{'UA.10'} = "Kirovohrads'ka Oblast'";
        $region_name{'UA.11'} = 'Krym';
        $region_name{'UA.12'} = 'Kyyiv';
        $region_name{'UA.13'} = "Kyyivs'ka Oblast'";
        $region_name{'UA.14'} = "Luhans'ka Oblast'";
        $region_name{'UA.15'} = "L'vivs'ka Oblast'";
        $region_name{'UA.16'} = "Mykolayivs'ka Oblast'";
        $region_name{'UA.17'} = "Odes'ka Oblast'";
        $region_name{'UA.18'} = "Poltavs'ka Oblast'";
        $region_name{'UA.19'} = "Rivnens'ka Oblast'";
        $region_name{'UA.20'} = "Sevastopol'";
        $region_name{'UA.21'} = "Sums'ka Oblast'";
        $region_name{'UA.22'} = "Ternopil's'ka Oblast'";
        $region_name{'UA.23'} = "Vinnyts'ka Oblast'";
        $region_name{'UA.24'} = "Volyns'ka Oblast'";
        $region_name{'UA.25'} = "Zakarpats'ka Oblast'";
        $region_name{'UA.26'} = "Zaporiz'ka Oblast'";
        $region_name{'UA.27'} = "Zhytomyrs'ka Oblast'";
        $region_name{'UG.5'} = 'Busoga';
        $region_name{'UG.8'} = 'Karamoja';
        $region_name{'UG.12'} = 'South Buganda';
        $region_name{'UG.18'} = 'Central';
        $region_name{'UG.20'} = 'Eastern';
        $region_name{'UG.21'} = 'Nile';
        $region_name{'UG.22'} = 'North Buganda';
        $region_name{'UG.23'} = 'Northern';
        $region_name{'UG.24'} = 'Southern';
        $region_name{'UG.25'} = 'Western';
        $region_name{'UG.37'} = 'Kampala';
        $region_name{'UG.65'} = 'Adjumani';
        $region_name{'UG.66'} = 'Bugiri';
        $region_name{'UG.67'} = 'Busia';
        $region_name{'UG.69'} = 'Katakwi';
        $region_name{'UG.73'} = 'Nakasongola';
        $region_name{'UG.74'} = 'Sembabule';
        $region_name{'UG.77'} = 'Arua';
        $region_name{'UG.78'} = 'Iganga';
        $region_name{'UG.79'} = 'Kabarole';
        $region_name{'UG.80'} = 'Kaberamaido';
        $region_name{'UG.81'} = 'Kamwenge';
        $region_name{'UG.82'} = 'Kanungu';
        $region_name{'UG.83'} = 'Kayunga';
        $region_name{'UG.84'} = 'Kitgum';
        $region_name{'UG.85'} = 'Kyenjojo';
        $region_name{'UG.86'} = 'Mayuge';
        $region_name{'UG.87'} = 'Mbale';
        $region_name{'UG.88'} = 'Moroto';
        $region_name{'UG.89'} = 'Mpigi';
        $region_name{'UG.90'} = 'Mukono';
        $region_name{'UG.91'} = 'Nakapiripirit';
        $region_name{'UG.92'} = 'Pader';
        $region_name{'UG.93'} = 'Rukungiri';
        $region_name{'UG.94'} = 'Sironko';
        $region_name{'UG.95'} = 'Soroti';
        $region_name{'UG.96'} = 'Wakiso';
        $region_name{'UG.97'} = 'Yumbe';
        $region_name{'UY.1'} = 'Artigas';
        $region_name{'UY.2'} = 'Canelones';
        $region_name{'UY.3'} = 'Cerro Largo';
        $region_name{'UY.4'} = 'Colonia';
        $region_name{'UY.5'} = 'Durazno';
        $region_name{'UY.6'} = 'Flores';
        $region_name{'UY.7'} = 'Florida';
        $region_name{'UY.8'} = 'Lavalleja';
        $region_name{'UY.9'} = 'Maldonado';
        $region_name{'UY.10'} = 'Montevideo';
        $region_name{'UY.11'} = 'Paysandu';
        $region_name{'UY.12'} = 'Rio Negro';
        $region_name{'UY.13'} = 'Rivera';
        $region_name{'UY.14'} = 'Rocha';
        $region_name{'UY.15'} = 'Salto';
        $region_name{'UY.16'} = 'San Jose';
        $region_name{'UY.17'} = 'Soriano';
        $region_name{'UY.18'} = 'Tacuarembo';
        $region_name{'UY.19'} = 'Treinta y Tres';
        $region_name{'UZ.1'} = 'Andijon';
        $region_name{'UZ.2'} = 'Bukhoro';
        $region_name{'UZ.3'} = 'Farghona';
        $region_name{'UZ.4'} = 'Jizzakh';
        $region_name{'UZ.5'} = 'Khorazm';
        $region_name{'UZ.6'} = 'Namangan';
        $region_name{'UZ.7'} = 'Nawoiy';
        $region_name{'UZ.8'} = 'Qashqadaryo';
        $region_name{'UZ.9'} = 'Qoraqalpoghiston';
        $region_name{'UZ.10'} = 'Samarqand';
        $region_name{'UZ.11'} = 'Sirdaryo';
        $region_name{'UZ.12'} = 'Surkhondaryo';
        $region_name{'UZ.13'} = 'Toshkent';
        $region_name{'UZ.14'} = 'Toshkent';
        $region_name{'VC.1'} = 'Charlotte';
        $region_name{'VC.2'} = 'Saint Andrew';
        $region_name{'VC.3'} = 'Saint David';
        $region_name{'VC.4'} = 'Saint George';
        $region_name{'VC.5'} = 'Saint Patrick';
        $region_name{'VC.6'} = 'Grenadines';
        $region_name{'VE.1'} = 'Amazonas';
        $region_name{'VE.2'} = 'Anzoategui';
        $region_name{'VE.3'} = 'Apure';
        $region_name{'VE.4'} = 'Aragua';
        $region_name{'VE.5'} = 'Barinas';
        $region_name{'VE.6'} = 'Bolivar';
        $region_name{'VE.7'} = 'Carabobo';
        $region_name{'VE.8'} = 'Cojedes';
        $region_name{'VE.9'} = 'Delta Amacuro';
        $region_name{'VE.11'} = 'Falcon';
        $region_name{'VE.12'} = 'Guarico';
        $region_name{'VE.13'} = 'Lara';
        $region_name{'VE.14'} = 'Merida';
        $region_name{'VE.15'} = 'Miranda';
        $region_name{'VE.16'} = 'Monagas';
        $region_name{'VE.17'} = 'Nueva Esparta';
        $region_name{'VE.18'} = 'Portuguesa';
        $region_name{'VE.19'} = 'Sucre';
        $region_name{'VE.20'} = 'Tachira';
        $region_name{'VE.21'} = 'Trujillo';
        $region_name{'VE.22'} = 'Yaracuy';
        $region_name{'VE.23'} = 'Zulia';
        $region_name{'VE.24'} = 'Dependencias Federales';
        $region_name{'VE.25'} = 'Distrito Federal';
        $region_name{'VE.26'} = 'Vargas';
        $region_name{'VN.2'} = 'Bac Thai';
        $region_name{'VN.3'} = 'Ben Tre';
        $region_name{'VN.5'} = 'Cao Bang';
        $region_name{'VN.11'} = 'Ha Bac';
        $region_name{'VN.12'} = 'Hai Hung';
        $region_name{'VN.13'} = 'Hai Phong';
        $region_name{'VN.22'} = 'Lai Chau';
        $region_name{'VN.23'} = 'Lam Dong';
        $region_name{'VN.24'} = 'Long An';
        $region_name{'VN.29'} = 'Quang Nam-Da Nang';
        $region_name{'VN.30'} = 'Quang Ninh';
        $region_name{'VN.32'} = 'Son La';
        $region_name{'VN.33'} = 'Tay Ninh';
        $region_name{'VN.34'} = 'Thanh Hoa';
        $region_name{'VN.35'} = 'Thai Binh';
        $region_name{'VN.37'} = 'Tien Giang';
        $region_name{'VN.39'} = 'Lang Son';
        $region_name{'VN.43'} = 'An Giang';
        $region_name{'VN.44'} = 'Dac Lac';
        $region_name{'VN.45'} = 'Dong Nai';
        $region_name{'VN.46'} = 'Dong Thap';
        $region_name{'VN.47'} = 'Kien Giang';
        $region_name{'VN.48'} = 'Minh Hai';
        $region_name{'VN.49'} = 'Song Be';
        $region_name{'VN.50'} = 'Vinh Phu';
        $region_name{'VN.51'} = 'Ha Noi';
        $region_name{'VN.52'} = 'Ho Chi Minh';
        $region_name{'VN.53'} = 'Ba Ria-Vung Tau';
        $region_name{'VN.54'} = 'Binh Dinh';
        $region_name{'VN.55'} = 'Binh Thuan';
        $region_name{'VN.56'} = 'Can Tho';
        $region_name{'VN.57'} = 'Gia Lai';
        $region_name{'VN.58'} = 'Ha Giang';
        $region_name{'VN.59'} = 'Ha Tay';
        $region_name{'VN.60'} = 'Ha Tinh';
        $region_name{'VN.61'} = 'Hoa Binh';
        $region_name{'VN.62'} = 'Khanh Hoa';
        $region_name{'VN.63'} = 'Kon Tum';
        $region_name{'VN.64'} = 'Lao Cai';
        $region_name{'VN.65'} = 'Nam Ha';
        $region_name{'VN.66'} = 'Nghe An';
        $region_name{'VN.67'} = 'Ninh Binh';
        $region_name{'VN.68'} = 'Ninh Thuan';
        $region_name{'VN.69'} = 'Phu Yen';
        $region_name{'VN.70'} = 'Quang Binh';
        $region_name{'VN.71'} = 'Quang Ngai';
        $region_name{'VN.72'} = 'Quang Tri';
        $region_name{'VN.73'} = 'Soc Trang';
        $region_name{'VN.74'} = 'Thua Thien';
        $region_name{'VN.75'} = 'Tra Vinh';
        $region_name{'VN.76'} = 'Tuyen Quang';
        $region_name{'VN.77'} = 'Vinh Long';
        $region_name{'VN.78'} = 'Yen Bai';
        $region_name{'VU.5'} = 'Ambrym';
        $region_name{'VU.6'} = 'Aoba';
        $region_name{'VU.7'} = 'Torba';
        $region_name{'VU.8'} = 'Efate';
        $region_name{'VU.9'} = 'Epi';
        $region_name{'VU.10'} = 'Malakula';
        $region_name{'VU.11'} = 'Paama';
        $region_name{'VU.12'} = 'Pentecote';
        $region_name{'VU.13'} = 'Sanma';
        $region_name{'VU.14'} = 'Shepherd';
        $region_name{'VU.15'} = 'Tafea';
        $region_name{'VU.16'} = 'Malampa';
        $region_name{'VU.17'} = 'Penama';
        $region_name{'VU.18'} = 'Shefa';
        $region_name{'WS.2'} = 'Aiga-i-le-Tai';
        $region_name{'WS.3'} = 'Atua';
        $region_name{'WS.4'} = 'Fa';
        $region_name{'WS.5'} = 'Gaga';
        $region_name{'WS.6'} = 'Va';
        $region_name{'WS.7'} = 'Gagaifomauga';
        $region_name{'WS.8'} = 'Palauli';
        $region_name{'WS.9'} = 'Satupa';
        $region_name{'WS.10'} = 'Tuamasaga';
        $region_name{'WS.11'} = 'Vaisigano';
        $region_name{'YE.1'} = 'Abyan';
        $region_name{'YE.3'} = 'Al Mahrah';
        $region_name{'YE.4'} = 'Hadramawt';
        $region_name{'YE.5'} = 'Shabwah';
        $region_name{'YE.8'} = 'Al Hudaydah';
        $region_name{'YE.10'} = 'Al Mahwit';
        $region_name{'YE.11'} = 'Dhamar';
        $region_name{'YE.14'} = "Ma'rib";
        $region_name{'YE.15'} = 'Sa';
        $region_name{'YE.16'} = 'San';
        $region_name{'YE.20'} = "Al Bayda'";
        $region_name{'YE.21'} = 'Al Jawf';
        $region_name{'YE.22'} = 'Hajjah';
        $region_name{'YE.23'} = 'Ibb';
        $region_name{'YE.24'} = 'Lahij';
        $region_name{'YE.25'} = 'Ta';
        $region_name{'ZA.2'} = 'KwaZulu-Natal';
        $region_name{'ZA.3'} = 'Free State';
        $region_name{'ZA.5'} = 'Eastern Cape';
        $region_name{'ZA.6'} = 'Gauteng';
        $region_name{'ZA.7'} = 'Mpumalanga';
        $region_name{'ZA.8'} = 'Northern Cape';
        $region_name{'ZA.9'} = 'Limpopo';
        $region_name{'ZA.10'} = 'North-West';
        $region_name{'ZA.11'} = 'Western Cape';
        $region_name{'ZM.1'} = 'Western';
        $region_name{'ZM.2'} = 'Central';
        $region_name{'ZM.3'} = 'Eastern';
        $region_name{'ZM.4'} = 'Luapula';
        $region_name{'ZM.5'} = 'Northern';
        $region_name{'ZM.6'} = 'North-Western';
        $region_name{'ZM.7'} = 'Southern';
        $region_name{'ZM.8'} = 'Copperbelt';
        $region_name{'ZM.9'} = 'Lusaka';
        $region_name{'ZR.1'} = 'Bandundu';
        $region_name{'ZR.2'} = 'Equateur';
        $region_name{'ZR.3'} = 'Kasai-Occidental';
        $region_name{'ZR.4'} = 'Kasai-Oriental';
        $region_name{'ZR.5'} = 'Katanga';
        $region_name{'ZR.6'} = 'Kinshasa';
        $region_name{'ZR.7'} = 'Kivu';
        $region_name{'ZR.8'} = 'Bas-Congo';
        $region_name{'ZR.9'} = 'Orientale';
        $region_name{'ZR.10'} = 'Maniema';
        $region_name{'ZR.11'} = 'Nord-Kivu';
        $region_name{'ZR.12'} = 'Sud-Kivu';
        $region_name{'ZW.1'} = 'Manicaland';
        $region_name{'ZW.2'} = 'Midlands';
        $region_name{'ZW.3'} = 'Mashonaland Central';
        $region_name{'ZW.4'} = 'Mashonaland East';
        $region_name{'ZW.5'} = 'Mashonaland West';
        $region_name{'ZW.6'} = 'Matabeleland North';
        $region_name{'ZW.7'} = 'Matabeleland South';
        $region_name{'ZW.8'} = 'Masvingo';
        $region_name{'ZW.9'} = 'Bulawayo';
        $region_name{'ZW.10'} = 'Harare';
        $region_name{'US.AL'} = 'Alabama';
        $region_name{'US.AK'} = 'Alaska';
        $region_name{'US.AS'} = 'American Samoa';
        $region_name{'US.AZ'} = 'Arizona';
        $region_name{'US.AR'} = 'Arkansas';
        $region_name{'US.CA'} = 'California';
        $region_name{'US.CO'} = 'Colorado';
        $region_name{'US.CT'} = 'Connecticut';
        $region_name{'US.DE'} = 'Delaware';
        $region_name{'US.DC'} = 'District of Columbia';
        $region_name{'US.FM'} = 'Federated States of Micronesia';
        $region_name{'US.FL'} = 'Florida';
        $region_name{'US.GA'} = 'Georgia';
        $region_name{'US.GU'} = 'Guam';
        $region_name{'US.HI'} = 'Hawaii';
        $region_name{'US.ID'} = 'Idaho';
        $region_name{'US.IL'} = 'Illinois';
        $region_name{'US.IN'} = 'Indiana';
        $region_name{'US.IA'} = 'Iowa';
        $region_name{'US.KS'} = 'Kansas';
        $region_name{'US.KY'} = 'Kentucky';
        $region_name{'US.LA'} = 'Louisiana';
        $region_name{'US.ME'} = 'Maine';
        $region_name{'US.MH'} = 'Marshall Islands';
        $region_name{'US.MD'} = 'Maryland';
        $region_name{'US.MA'} = 'Massachusetts';
        $region_name{'US.MI'} = 'Michigan';
        $region_name{'US.MN'} = 'Minnesota';
        $region_name{'US.MS'} = 'Mississippi';
        $region_name{'US.MO'} = 'Missouri';
        $region_name{'US.MT'} = 'Montana';
        $region_name{'US.NE'} = 'Nebraska';
        $region_name{'US.NV'} = 'Nevada';
        $region_name{'US.NH'} = 'New Hampshire';
        $region_name{'US.NJ'} = 'New Jersey';
        $region_name{'US.NM'} = 'New Mexico';
        $region_name{'US.NY'} = 'New York';
        $region_name{'US.NC'} = 'North Carolina';
        $region_name{'US.ND'} = 'North Dakota';
        $region_name{'US.MP'} = 'Northern Mariana Islands';
        $region_name{'US.OH'} = 'Ohio';
        $region_name{'US.OK'} = 'Oklahoma';
        $region_name{'US.OR'} = 'Oregon';
        $region_name{'US.PW'} = 'Palau';
        $region_name{'US.PA'} = 'Pennsylvania';
        $region_name{'US.PR'} = 'Puerto Rico';
        $region_name{'US.RI'} = 'Rhode Island';
        $region_name{'US.SC'} = 'South Carolina';
        $region_name{'US.SD'} = 'South Dakota';
        $region_name{'US.TN'} = 'Tennessee';
        $region_name{'US.TX'} = 'Texas';
        $region_name{'US.UT'} = 'Utah';
        $region_name{'US.VT'} = 'Vermont';
        $region_name{'US.VI'} = 'Virgin Islands';
        $region_name{'US.VA'} = 'Virgina';
        $region_name{'US.WA'} = 'Washington';
        $region_name{'US.WV'} = 'West Virginia';
        $region_name{'US.WI'} = 'Wisconsin';
        $region_name{'US.WY'} = 'Wyoming';
        $region_name{'US.AE'} = 'Armed Forces Africa, Canada, Europe, Middle East';
        $region_name{'US.AA'} = 'Armed Forces Americas';
        $region_name{'US.AP'} = 'Armed Forces Pacific';
}
